#
# spec file for package mesheryctl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mesheryctl
Version:        0.8.57
Release:        1.1
Summary:        CLI for the meshery cloud native management plane
License:        Apache-2.0
URL:            https://github.com/meshery/meshery
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go1.23
BuildRequires:  zsh

%description
Meshery manages the provisioning, configuration and operation of your
Kubernetes clusters, workloads, and service meshes. While supporting hundreds
of different types of cloud native infrastructure integrations.

Meshery also offers a catalog of curated design templates filled with
configuration best practices.

Using a GitOps-centric approach, visually and collaboratively design and manage
your infrastructure and microservices. Use Meshery to interoperate your various
cloud native systems. With both REST and GraphQL APIs, integrating with Meshery
as an extensible platform is facilitated through NATS, CloudEvents, gRPC,
Service Mesh Interface (SMI), and Service Mesh Performance (SMP).

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/layer5io/meshery/mesheryctl/internal/cli/root/constants.version=v%{version} \
   -X github.com/layer5io/meshery/mesheryctl/internal/cli/root/constants.commitsha=v%{version} \
   -X github.com/layer5io/meshery/mesheryctl/internal/cli/root/constants.releasechannel=stable" \
   -o bin/mesheryctl ./mesheryctl/cmd/mesheryctl/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.57:
  * Bump helm.sh/helm/v3 from 3.17.0 to 3.17.3
  * Update mesheryctl/tests/e2e/003-design/01-design-list.bats
  * [Docs] Generated documentation for Integration
  * [Docs] Generated documentation for Integration
  * [Docs] Release Notes for Meshery
  * [Docs] Update mesheryctl docs
  * [Docs] Update table of contents
  * [Docs] Update table of contents and sidebar styles
  * [Docs] Updated test report in Jekyll
  * [Fix] Update event streamer API route and enhance event status
    query logic
  * chore(mesheryctl-e2e): update test regex
  * feat(mesheryctl): add e2e test on system context subcommand
  * fix(mesheryctl-model): fix model export with a non existing
    version raising a panic
* Tue Apr  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.56:
  * General
  - [CI] Reduce Docker Image Size; Upgrade Key Golang Packages
    @leecalcote (#14328)
  - chore(go-mod): fix broken dependency github.com/openshift/api
    version @lekaf974 (#14330)
  - [CI] Remove wrk2 from default Meshery container build
    @leecalcote (#14326)
  - [Chore] Move .dockerignore to project root @leecalcote
    (#14327)
  - cleanup old alas relationships @mrmerlin320 (#14321)
  * Meshery CLI
  - [mesheryctl] feature: 13849: model init command @n2h9
    (#13879)
  - Fix Registry update @mrmerlin320 (#14320)
  - chore(model-export): fix panic server side and error not
    handled properly in cli @lekaf974 (#14318)
  * Bug Fixes
  - chore(model-export): fix panic server side and error not
    handled properly in cli @lekaf974 (#14318)
  * Documentation
  - [mesheryctl] feature: 13849: model init command @n2h9
    (#13879)
* Mon Apr  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.55:
  * General
  - Fix: Dry run for un-deploy not working @souvikinator (#13836)
  - update meshsync and meshkit @amitamrutiya (#14192)
  * Meshery CLI
  - fix(ci): update golangci-lint version and go to 1.24
    @lekaf974 (#14251)
  - refactor: mesheryctl model command using fetch and list
    @lekaf974 (#14171)
  - fix(mesheryctl): prevent panic to raised @lekaf974 (#14169)
  - update model and component csv files @amitamrutiya (#14207)
  - fix(mesheryctl-model): parse model.Category.Name as a string
    to fix b… @lekaf974 (#14196)
  * Maintenance
  - fix: fix logout test flakiness @ianrwhitney (#14301)
  - fix(ci): update golangci-lint version and go to 1.24
    @lekaf974 (#14251)
  - Fix: Optimize Playwright Test Performance in CI/CD @vr-varad
    (#14195)
  - [Chore] Dockerfile alpine and glibc update @theBeginner86
    (#14242)
  - Bump github.com/meshery/schemas from 0.8.5 to 0.8.6
    @dependabot (#14211)
  - Bump @babel/eslint-parser from 7.26.8 to 7.27.0 in
    /provider-ui @dependabot (#14221)
  - Bump next from 13.5.8 to 15.2.4 in /provider-ui @dependabot
    (#14219)
  - feat: added permissions to gh action @ianrwhitney (#14197)
  * Documentation
  - Update CLI/UI test contribution docs with Sheet Views
    @Atharv-16 (#14184)
  - [Docs] Update contributing-schemas.md @miacycle (#14247)
  - fix(mesheryctl): prevent panic to raised @lekaf974 (#14169)
  - docs: add test implementation section in cli e2e contribution
    guide @lekaf974 (#14106)
  - feat: add test report to docs site @ianrwhitney (#14198)
  * Security
  - [Chore] Bump the containerd version @thealberto (#14250)
  - [Dependency] Update Go version from 1.21 to 1.23 in go.mod
    @ritzorama (#14244)
* Tue Apr  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.54:
  * General
  - Add Mia Grenell as a Documentation Maintainer @zihanKuang
    (#14160)
  - fix: dry run errors not showing up @souvikinator (#13835)
  - remove polygon meshery shapes component @amitamrutiya
    (#14156)
  * - Meshery CLI
  - fix(mesheryctl-e2e): create BATS libs folder if not existing
    @lekaf974 (#14185)
  - [mesheryctl] ci e2e bats improvment @lekaf974 (#14133)
  - refactor: mesheryctl add reusable function list function
    @lekaf974 (#14109)
  * - Maintenance
  - fix: jekyll docs update @ianrwhitney (#14170)
  - [mesheryctl] ci e2e bats improvment @lekaf974 (#14133)
  - feat: enable e2e test gh action on master push @ianrwhitney
    (#14153)
  * - Documentation
  - Typo-error in docs @alokdangre (#14174)
  - Added Related Tutorials section to Integrations pages
    @vr-varad (#13937)
  - Update publishing workflow documentation and images
    @zihanKuang (#13955)
  - fix: go.sum missing update @lekaf974 (#14151)
- update to 0.8.53:
  * General
  - bump schemas and meshkit @aabidsofi19 (#14150)
  * Meshery CLI
  - Dockerfile Fix @Chirag-16 (#14135)
  - [mesheryctl] UX: Fix components command · Issue #14077
    @dhiraj-kadam (#14095)
  - Update README.md with cli e2e test url @mishrlaksh (#14137)
  * Maintenance
  - feat: added jekyll test report update gh action @ianrwhitney
    (#13944)
  - Fix: update documentation issue template with navigation sync
    reminder @zihanKuang (#14127)
  * Documentation
  - [CI] Added test for user session logout @Pratik-050 (#13807)
  - [Docs] Fixed Markdown and Code Block Formatting in
    Contributing to UI - Sistent @Sumitsh28 (#14130)
  - Dockerfile Fix @Chirag-16 (#14135)
  - [mesheryctl] UX: Fix components command · Issue #14077
    @dhiraj-kadam (#14095)
* Tue Mar 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.52:
  * Meshery CLI
  - [mesheryctl] bug fix for 00-config.bats @gourav-k-shaw
    (#14108)
  - mesheryctl relationship cleanup @lekaf974 (#13450)
  - [fix]: added variables for dependencies and more
    documentation for local e2e tests @gentcod (#14070)
  * Maintenance
  - Update mesheryctl-e2e.yaml workflow to use ubuntu-24.04
    runner @sangramrath (#14103)
  - Bump github.com/golang-jwt/jwt/v5 from 5.2.1 to 5.2.2
    @dependabot (#14092)
  * Documentation
  - feat: updated testing policy @ianrwhitney (#14102)
  - [fix]: added variables for dependencies and more
    documentation for local e2e tests @gentcod (#14070)
* Fri Mar 21 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.51:
  * General
  - bump schemas and meshkit @aabidsofi19 (#14057)
  * Meshery CLI
  - chore: fix broken link for cli reference design export
    @lekaf974 (#14069)
  - feat: refactored bats setup @ianrwhitney (#14027)
  - [mesheryctl] fix: spelling in model command examples and run
    go mod tidy @n2h9 (#14066)
  - refactor: mesheryctl model command @lekaf974 (#14034)
  - [mesheryctl][meshkit] Refactor and move registry utility
    functions to meshkit @riyaa14 (#13734)
  - [mod-mesheryctl-e2e]: Implemented helper script to run
    end-to-end tests locally @gentcod (#14045)
  - Revert "Add component generation step in the model generate
    wizard" @amitamrutiya (#14053)
  - Add component generation step in the model generate wizard
    @amitamrutiya (#14052)
  * Maintenance
  - chore: fix broken link for cli reference design export
    @lekaf974 (#14069)
  - Adding Privateer files for security scan @sangramrath
    (#14065)
  * Documentation
  - chore: fix broken link for cli reference design export
    @lekaf974 (#14069)
  - [Docs] remove mesheryctl system config for in-cluster Meshery
    on EKS @riyaa14 (#13372)
  - [docs] update instructions on running bats e2e tests locally
    @riyaa14 (#14028)
* Mon Mar 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.50:
  * General
  - update schema imports @aabidsofi19 (#14025)
  - fitz/chore/meetings and archival @fitzergerald (#14036)
  * Meshery CLI
  - Notification UI Enhancements @FaheemOnHub (#13878)
  - chore: add make e2e command @lekaf974 (#14033)
  - [mesheryctl] 13831: fix environment view orgID param @n2h9
    (#13833)
  - feat: mesheryctl components add unit test @lekaf974 (#13912)
  - docs: add mesheryctl e2e contribution guideline @lekaf974
    (#14006)
  * Documentation
  - Notification UI Enhancements @FaheemOnHub (#13878)
* Thu Mar 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.49:
  * no CLI-related changes in this release
- update to 0.8.48:
  * Meshery CLI
  - Specified Kubernetes Context in Logs @Tanishq1604 (#12835)
  * Maintenance
  - chore(deps-dev): bump axios from 1.7.9 to 1.8.2 in
    /provider-ui @dependabot (#13920)
- update to 0.8.47:
  * no CLI-related changes in this release
* Sat Mar  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.46:
  * Meshery CLI
  - [Server] enhance error logs for non-OCI artifacts, empty
    models and invalid schema in model import @riyaa14 (#13609)
  - [mesheryctl] Fix for system reset @Jougan-0 (#13884)
  - feat: mesheryctl e2e bats @lekaf974 (#13763)
  - fix: mesheryctl replace deprecated cobra command @lekaf974
    (#13911)
  * Bug Fixes
  - Refactored design conversion to use files package from
    meshkit @souvikinator (#13613)
  * Maintenance
  - Refactored design conversion to use files package from
    meshkit @souvikinator (#13613)
  - Revert "Bump @xstate/react from 4.1.3 to 5.0.2 in /ui"
    @leecalcote (#13927)
  - Bump @xstate/react from 4.1.3 to 5.0.2 in /ui @dependabot
    (#13818)
  - feat: mesheryctl e2e bats @lekaf974 (#13763)
  - fix: mesheryctl replace deprecated cobra command @lekaf974
    (#13911)
  * Documentation
  - Fix broken link @zihanKuang (#13880)
  - chore(deps-dev): bump uri from 1.0.2 to 1.0.3 in /docs/v0.7
    @dependabot (#13873)
  - chore(deps-dev): bump rack from 3.1.10 to 3.1.11 in
    /docs/v0.7 @dependabot (#13905)
  - Refactor import/export design documentation: removed
    duplicate pages … @zihanKuang (#13813)
- update to 0.8.45:
  * no CLI-related changes in this release
- update to 0.8.44:
  * no CLI-related changes in this release
- update to 0.8.43:
  * no CLI-related changes in this release
- update to 0.8.42:
  * no CLI-related changes in this release
* Fri Feb 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.41:
  * no CLI-related changes in this release
  * Maintenance
  - [CI] Update from ubuntu-20.04 to ubuntu-24.04 as runner
    @shinigami-777 (#13790)
  * Documentation
  - Fix table display issue #13766 @sangramrath (#13772)
  - docs: broken-links @leecalcote (#13793)
  - Delete
    docs/pages/project/contributing/contributing-cypress.md
    @leecalcote (#13791)
  - Leecalcote/docs/broken-links @leecalcote (#13792)
- update to 0.8.40:
  * no CLI-related changes in this release
- update to 0.8.39:
  * no CLI-related changes in this release
- update to 0.8.38:
  * no CLI-related changes in this release
  * General
  - Update README.md @miacycle (#13758)
  * Maintenance
  - Don't lint UI and Provider UI on PRs with only Docs updates.
    @leecalcote (#13745)
  * Documentation
  - Add tutorial - Embedding Designs in Wordpress @sangramrath
    (#13528)
  - Fix/clean lightbox issue @zihanKuang (#13729)
  - Fix broken links in the Overview & Installation section of
    the Meshery documentation @zihanKuang (#13770)
- update to 0.8.37:
  * no CLI-related changes in this release
  * - Maintenance
  - fix: build step failure experiements @ianrwhitney (#13732)
  * - Documentation
  - Bump nokogiri from 1.17.2 to 1.18.3 in /docs/v0.7 @dependabot
    (#13723)
  - Enhance footer styling and layout adjustments for improved
    responsive… @falgunmpatel (#13720)
  - fix: fix shape generic node and polygon @weilirs (#13684)
- update to 0.8.36:
  * no CLI-related changes in this release
  * Maintenance
  - [CI] Tag-name property for Homebrew packages @jamieplu
    (#13712)
  - leecalcote/golang/chore @leecalcote (#13710)
  - [CI] Chore: Upgrade to Ubuntu 24.04 as the runner @leecalcote
    (#13709)
  * Documentation
  - Chore: Avoid deprecated golangci-lint config; Enhance Meshery
    Error Code details @leecalcote (#13708)
- update to 0.8.35:
  * no CLI-related changes in this release
  * Maintenance
  - [CI] Adding workflow_dispatch to Release Drafter workflow
    @jamieplu (#13700)
  - [CI] Use correct secret in release drafter workflow
    @leecalcote (#13699)
  - fix: the secrent in the build-ui-server-reusable-workflow
    @amitamrutiya (#13693)
  - Update build-ui-server-reusable-workflow.yml @leecalcote
    (#13673)
  * Documentation
  - chore(deps-dev): bump nokogiri from 1.17.2 to 1.18.3 in /docs
    @dependabot (#13667)
  - doc: added contributing guide to meshery schema @souvikinator
    (#13421)
- update to 0.8.34:
  * no CLI-related changes in this release
  * Bump Sistent
  * Revert Workflow changes
- update to 0.8.33:
  * No changes
- update to 0.8.32:
  * no CLI-related changes in this release
  * General
  - Fix nil crash @aabidsofi19 (#13627)
  * Documentation
  - [docs/ux] Helm Kanvas Snapshot @theBeginner86 (#13650)
  - fix(docs): remove incorrect diagram from Credentials page
    @zihanKuang (#13633)
* Sun Feb 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.31:
  * General
  - Fix performance test failure in local provider
    @Yashsharma1911 (#13545)
  - Evaluation Optimizations @aabidsofi19 (#13616)
  - chore @vishalvivekm (#13617)
  * Meshery CLI
  - Fixed the duplicate import sub-command @Arpit529Srivastava
    (#13538)
- update to 0.8.30:
  * no CLI-related changes in this release
* Wed Feb 12 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.29:
  * General
  - Manifest to design conversion optimization @aabidsofi19
    (#13560)
  - set capabilities to be empty for declarations @aabidsofi19
    (#13559)
  - Import perf logs @aabidsofi19 (#13553)
  * Meshery CLI
  - [mesheryctl] refactor and enhance mesheryctl design import
    @riyaa14 (#13476)
* Tue Feb 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.28:
  * General
  - fix empty save event @aabidsofi19 (#13552)
  - Fix errors in PR #13420 @riyaa14 (#13547)
  - update event description @aabidsofi19 (#13540)
  - make alias components annotations @aabidsofi19 (#13515)
  * Meshery CLI
  - adds org command @ashish111333 (#13172)
  - [mesheryctl] Fix error logs for non importable files @riyaa14
    (#13420)
  * Documentation
  - adds org command @ashish111333 (#13172)
* Sat Feb  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.27:
  * Meshery CLI
  - ci/chore/more docker repos @miacycle (#13506)
  - Update meshery-linkerd references to use the new repository
    path @miacycle (#13502)
  - [mesheryctl] nit: improve error logging for registry generate
    using csv files from local directory @riyaa14 (#13464)
  - update environment doc links @aabidsofi19 (#13474)
  - Update vendor links @aabidsofi19 (#13475)
- update to 0.8.26:
  * Meshery CLI
  - [mesheryctl relationship] refactoring tests not stored
    properly @lekaf974 (#13393)
  - Add doc functionality to print subcommands list @alphaX86
    (#12953)
  - [CLI UX]: mesheryctl registry generate invalid JWT token
    response @leecalcote (#13358)
  * Documentation
  - [mesheryctl relationship] refactoring tests not stored
    properly @lekaf974 (#13393)
  - Add doc functionality to print subcommands list @alphaX86
    (#12953)
* Tue Jan 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.25:
  * no CLI-related changes in this release
- update to 0.8.24:
  * General
  - fix alias relationships @aabidsofi19 (#13369)
  - leecalcote/go/deps @leecalcote (#13362)
  * Features
  - chore: Enhance registry update error displayed to user
    @lekaf974 (#13359)
  * Meshery CLI
  - chore: Enhance registry update error displayed to user
    @lekaf974 (#13359)
- update to 0.8.23:
  * no CLI-related changes in this release
- update to 0.8.22:
  * no CLI-related changes in this release
* Fri Jan 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.21:
  * General
  - Optimize and enhance matchlabel policy and general evaluation
    @aabidsofi19 (#13341)
  - Enhancement - custom docker image to be used in tutorials
    @sangramrath (#13342)
  * Meshery CLI
  - [mesheryctl] fix: remove arguments check that break
    functionality @lekaf974 (#13338)
  - [mesheryctl] Fix unreachable code and unused variable
    warnings in system/start.go @Tharanishwaran (#13336)
  - fix(meshreyctl): design view tests fail @lekaf974 (#13043)
  - [mesheryctl] Improve mesheryctl registry generate command by
    applying argument check @riyaa14 (#13255)
* Wed Jan 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.20:
  * Meshery CLI
  - fix: golanci-lint failed @lekaf974 (#13327)
  - [mesheryctl] add layout and item-type frontmatter to models
    @vishalvivekm (#13319)
  - [mesheryctl] update models output path @vishalvivekm (#13318)
* Wed Jan 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.19:
  * General
  - add: endpoints to set and get log levels while server is
    running @souvikinator (#13290)
  - Support for K8s manifest kind list while importing
    @souvikinator (#13233)
  * Meshery CLI
  - feat: enhance registry publish cmd to send models to
    mesheryio @vishalvivekm (#13222)
- update to 0.8.18:
  * no CLI-related changes in this release
* Sat Jan 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.17:
  * no CLI-related changes in this release
- update to 0.8.16:
  * no CLI-related changes in this release
- update to 0.8.15:
  * Meshery CLI
  - [mesheryctl] Unit Tests for mesheryctl exp relationships generate command @riyaa14 (#13208)
- update to 0.8.14:
  * no CLI-related changes in this release
* Fri Jan 17 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.13:
  * Meshery CLI
  - [Chore] Docker compatibility in golang packages @leecalcote
    (#13288)
  - meshery dependency version bump @souvikinator (#13286)
- update to 0.8.12:
  * no CLI-related changes in this release
* Tue Jan 14 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.11:
  * no CLI-related changes in this release
- update to 0.8.10:
  * no CLI-related changes in this release
- update to 0.8.9:
  * no CLI-related changes in this release
- update to 0.8.8:
  * no CLI-related changes in this release
- update to 0.8.7:
  * no CLI-related changes in this release
- update to 0.8.6:
  * no CLI-related changes in this release
- update to 0.8.5:
  * no CLI-related changes in this release
- update to 0.8.4:
  * no CLI-related changes in this release
* Wed Jan  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.3:
  * Meshery CLI
  - refactor(mesheryctl): Promote environment command @lekaf974
    (#13033)
  * Documentation
  - refactor(mesheryctl): Promote environment command @lekaf974
    (#13033)
* Tue Dec 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.2:
  * General
  - Update Go toolchain to version 1.23.4 @devhindo (#13062)
  - Update meshkit to v0.8.0 @devhindo (#13061)
  - Eval documentation @aabidsofi19 (#13051)
  - remove design configuration prettification logic @aabidsofi19
    (#13049)
  - bump meshkit @aabidsofi19 (#13048)
  - add support for filtering by labels @aabidsofi19 (#13012)
  * Meshery CLI
  - fix(mesheryctl): Error code workflow is failing @lekaf974
    (#13037)
  - Remove the word "successfully" @weilirs (#12932)
* Fri Dec 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.1:
  * Meshery CLI
  - [RESOLVED] system config error @Tanishq1604 (#12650)
* Sun Dec 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.8.0:
  * no CLI-related changes in this release
* Sat Dec 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.172:
  * General
  - Fix and enhance Deployment enrichment @aabidsofi19 (#12918)
  - bump meshkit @aabidsofi19 (#12917)
  * Meshery CLI
  - replace pattern and catalog endpoint trim params with the populate params
    @amitamrutiya (#12914)
- update to 0.7.171:
  * no CLI-related changes in this release
- update to 0.7.170:
  * no CLI-related changes in this release
* Sun Dec 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.169:
  * General
  - Meshsync api enhancement @aabidsofi19 (#12870)
  - Removed a trailing slash in README.md @Ajay-singh1 (#12865)
  * Meshery CLI
  - Create tests for mesheryctl exp relationship command
    @yaten2302 (#12792)
* Tue Dec 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.168:
  * Meshery CLI
  - Meshsync apis and extension enhancements @aabidsofi19
    (#12807)
  - mesheryctl: add filter for not publishing to meshery
    relationship @jerensl (#12826)
- update to 0.7.167:
  * no CLI-related changes in this release
* Fri Nov 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.166:
  * no CLI-related changes in this release
- update to 0.7.165:
  * no CLI-related changes in this release
* Fri Nov 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.164:
  * Meshery CLI
  - remove tests @Jougan-0 (#12779)
* Fri Nov 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.163:
  * no CLI-related changes in this release
* Wed Nov 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.162:
  * Meshery CLI
  - Add comment @Jougan-0 (#12756)
  * Maintenance
  - fix: permission keys pull 404 pages @jerensl (#12765)
  - Bump path-to-regexp and serve in /ui @dependabot (#12748)
  - Bump dawidd6/action-download-artifact from 2 to 6 in
    /.github/workflows @dependabot (#12758)
* Tue Nov 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.161:
  * no CLI-related changes in this release
- update to 0.7.160:
  * no CLI-related changes in this release
- update to 0.7.159:
  * no CLI-related changes in this release
- update to 0.7.158:
  * no CLI-related changes in this release
* Wed Nov 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.157:
  * Meshery CLI
  - [Chore} fix minor typo @Alero-Awani (#12692)
  - update mesheryctl registry generate multiwritier log
    @Jougan-0 (#12694)
* Wed Nov 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.156:
  * Meshery CLI
  - Update generate.go @Jougan-0 (#12683)
  - fix empty commit w/signoff @Jougan-0 (#12681)
* Tue Nov 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.155:
  * no CLI-related changes in this release
* Tue Nov 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.154:
  * no CLI-related changes in this release
* Tue Nov 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.153:
  * Meshery CLI
  - revert crd name and apiversion changes @aabidsofi19 (#12667)
  * Documentation
  - add catalog links @Alero-Awani (#12670)
  - revert crd name and apiversion changes @aabidsofi19 (#12667)
* Tue Nov 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.152:
  * Meshery CLI
  - update the model name for relationships w/signoff @Jougan-0
    (#12661)
* Fri Nov 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.151:
  * Meshery CLI
  - Generate cmd @Jougan-0 (#12146)
  * Documentation
  - Generate cmd @Jougan-0 (#12146)
  - fix formatting on meshery models contributing guide @Touriist
    (#12660)
* Thu Nov 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.150:
  * Meshery CLI
  - update templates for model generation w/signoff @Jougan-0
    (#12659)
* Thu Nov 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.148:
  * no CLI-related changes in this release
- update to 0.7.149:
  * no CLI-related changes in this release
* Thu Nov 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.147:
  * General
  - add new trim params for catalog api @amitamrutiya (#12642)
  - [Local Provider] Bundle catalog data with meshery docker
    image @Yashsharma1911 (#12632)
  - fix network rel w/signoff @Jougan-0 (#12641)
  * Meshery CLI
  - replace meshery.layer5.io with cloud.layer5.io @aabidsofi19
    (#12638)
* Wed Nov 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.146:
  * no CLI-related changes in this release
* Wed Nov 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.145:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.144:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.143:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.142:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.141:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.140:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.139:
  * General
  - Fix redirects @Jougan-0 (#12607)
  * Meshery CLI
  - [mesheryctl] Add some prereq checks for system config gke
    command @hexxdump (#12584)
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.138:
  * General
  - bump go sum w/signoff @Jougan-0 (#12605)
  * Meshery CLI
  - update rego to support heirachical parent annotation
    w/signoff @Jougan-0 (#12604)
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.137:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.136:
  * no CLI-related changes in this release
* Tue Nov 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.135:
  * no CLI-related changes in this release
* Mon Nov  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.134:
  * no CLI-related changes in this release
* Mon Nov  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.133:
  * no CLI-related changes in this release
* Sat Nov  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.132:
  * no CLI-related changes in this release
* Thu Oct 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.131:
  * no CLI-related changes in this release
* Thu Oct 31 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.130:
  * no CLI-related changes in this release
* Wed Oct 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.129:
  * General
  - remove generic node from the shapes @amitamrutiya (#12517)
  - add missing components w/signoff @Jougan-0 (#12505)
  - Bump http-proxy-middleware from 2.0.4 to 2.0.7 in
    /install/docker-extension/ui @dependabot (#12479)
  * Meshery CLI
  - fix: update parsinggithub test to prevent failing issue
    @lekaf974 (#12371)
  - Minify and flatten Kubeconfig on Meshery UI @Alero-Awani
    (#11987)
* Tue Oct 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.128:
  * no CLI-related changes in this release
* Fri Oct 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.127:
  * no CLI-related changes in this release
* Fri Oct 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.126:
  * no CLI-related changes in this release
* Wed Oct 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.125:
  * Meshery CLI
  - error handling for Panic in mesheryctl env create
    @pranjalg1331 (#12332)
* Sat Oct 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.124:
  * no CLI-related changes in this release
* Thu Oct 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.123:
  * General
  - bump meshkit w/signoff @Jougan-0 (#12422)
  - update relationship def w/singoff @Jougan-0 (#12417)
  * Meshery CLI
  - Figure environment create command panic error#11314
    @JianMinTang (#12384)
* Wed Oct 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.122:
  * General
  - Add trim param in meshmodels API @Yashsharma1911 (#12367)
  - rego policies for relationships w/singoff @Jougan-0 (#12351)
  - Allow getting entities by ids @Yashsharma1911 (#12361)
  - Fix environment connections not getting fetched in local
    provider @Yashsharma1911 (#12349)
  * Meshery CLI
  - fix: unit test / integration test issue due to console
    special characters @lekaf974 (#12327)
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.121:
  * General
  - [CI] Enhance make target for port as an argument @leecalcote
    (#12324)
  * Meshery CLI
  - fix: connections commands description fixed w/signoff
    @rahulrana701 (#11373)
  * Documentation
  - fix: connections commands description fixed w/signoff
    @rahulrana701 (#11373)
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.120:
  * General
  - bump meshkit w/signoff @Jougan-0 (#12323)
  - update comps and remove hardcoding w/singoff @Jougan-0
    (#12322)
  - [Server] Enhance redirection based on release channels.
    @MUzairS15 (#12315)
  * Meshery CLI
  - [CI] Goreleaser upgrade to v2 and cleanup of repo root
    @leecalcote (#12321)
  - fix: Update golden file causing panic @lekaf974 (#12314)
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.119:
  * no CLI-related changes in this release
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.118:
  * Meshery CLI
    update rels w/singoff @Jougan-0 (#12302)
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.117:
  * no CLI-related changes in this release
* Fri Oct 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.116:
  * no CLI-related changes in this release
* Sun Oct  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.115:
  * no CLI-related changes in this release
  * General
  - [GraphQL] Regenerate graphql @MUzairS15 (#12283)
* Sun Oct  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.114:
  * Meshery CLI
  - Rename pattern to design in mesheryctl @alphaX86 (#11051)
  * Documentation
  - Rename pattern to design in mesheryctl @alphaX86 (#11051)
* Sun Oct  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.113:
  * no CLI-related changes in this release
* Sun Oct  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.112:
  * no CLI-related changes in this release
* Sun Oct  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.111:
  * General
  - remove redudant models and components w/signoff @Jougan-0
    (#12225)
  - [chore] Upgrade meshkit to v0.7.79 @MUzairS15 (#12257)
  - Remove duplicate and mismatch shapes @amitamrutiya (#12178)
  - set Matthieu EVRIN as Independent @lekaf974 (#12201)
  * Meshery CLI
  - update only latest version w/signoff @Jougan-0 (#12271)
  - Relationship generate @Jougan-0 (#12223)
* Thu Oct  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.110:
  * no CLI-related changes in this release
  * General
  - [Docs] MAINTAINERS: Update maintainer list @Vaibhav701161
    (#12167)
  - [chore] Fix failing go static check. @MUzairS15 (#12126)
  - [Docs] Add Field Descriptions Meshery CRDs
    @TomiwaAribisala-git (#11674)
* Mon Sep 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.109:
  * General
  - Move to independent maintainer @Alero-Awani (#12164)
  - fix reference to meshmates page @codered-lgtm (#12161)
  - [Server] Assign unique names for generated declaration.
    @MUzairS15 (#12153)
  - Fix not able to ping k8s connection in local provider
    @Yashsharma1911 (#12148)
  - Seed design from locally present designs in local provider
    @Yashsharma1911 (#12144)
  * Meshery CLI
  - changes in error shown @pranjalg1331 (#12141)
  * Maintenance
  - [bugfix] First-timer: Use GH_ACCESS_TOKEN, not GITHUB_TOKEN
    @leecalcote (#12160)
  - Bump github.com/open-policy-agent/opa from 0.67.1 to 0.68.0
    @dependabot (#12100)
  * Documentation
  - [Doc]Fix catalog schema link @CalebZoe (#12145)
* Fri Sep 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.108:
  * General
  - improve check for export format @MUzairS15 (#12109)
  - To stop seeding sample applications @vaishnaviadhau (#11910)
  * Meshery CLI
  - Support Generating Models and Components from Local CSV Files
    @Aijeyomah (#12051)
  * Maintenance
  - update if condition @vishalvivekm (#12106)
  * Documentation
  - fix the wrong command 'mesheryctl mesh' @JianMinTang (#12084)
* Wed Sep 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.107:
  * no CLI-related changes in this release
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.106:
  * Meshery CLI
  - proper error logs and event w/singoff @Jougan-0 (#11354)
  * Documentation
  - proper error logs and event w/singoff @Jougan-0 (#11354)
  - [docs] Overview: Update feature section title to h3
    @hamza-mohd (#12091)
  - [Docs] Simplify presentation of feature overview @jamieplu
    (#12081)
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.105:
  * no CLI-related changes in this release
- update to 0.7.104:
  * no CLI-related changes in this release
- update to 0.7.103:
  * no CLI-related changes in this release
- update to 0.7.102:
  * no CLI-related changes in this release
* Sat Sep 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.101:
  * General
  - Provider interface @MUzairS15 (#12043)
  - initialize usercapabilities persister @MUzairS15 (#12031)
  - [Models] New model: meshery-dev-icons @leecalcote (#11984)
  * Meshery CLI
  - Add version flag support on model export command @lekaf974
    (#11934)
  - Update model.go @vishalvivekm (#11986)
  * Documentation
  - create a empty folder entitled week-of-09-23-2024 w/signoff
    @JianMinTang (#12027)
  - configure meshery ui before building @codeSafari10 (#12035)
  - Add version flag support on model export command @lekaf974
    (#11934)
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.100:
  * General
  - fix broken schema w/signoff @Jougan-0 (#11983)
  * Meshery CLI
  - no CLI-related changes in this release
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.99 (no releases between 0.7.95 and this):
  * General
  - Chore: Upgrade golang package dependencies @leecalcote
    (#11968)
  - Revert "Chore: update golang dependencies" @leecalcote
    (#11966)
  - Chore: update golang dependencies @leecalcote (#11964)
  * Meshery CLI
  - no CLI-related changes in this release
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.95:
  * General
  - Bump path-to-regexp and express in
    /install/docker-extension/ui @dependabot (#11954)
  * Meshery CLI
  - Update meshery simple line icons @Jougan-0 (#11956)
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.94:
  * General
  - [Relationships] Remove container relationship @MUzairS15
    (#11946)
  - [Relationships] Remove relationships between internal K8s
    resources. @MUzairS15 (#11935)
  - [Model] Simple Line Icons: Add styling capabilities to Doc,
    Folder, and ArrowUp components @leecalcote (#11927)
  - [Models] Add meshery-simple-line-icons model @leecalcote
    (#11926)
  - [Fix]: build and release docker extension @jerensl (#11924)
  * Meshery CLI
  - update component w/signoff @Jougan-0 (#11923)
  * Documentation
  - Change mesheyctl to mesheryctl @Alero-Awani (#11948)
  - [docs] Update the dead link in Contribute to Models page
    @Vijaykv5 (#11931)
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.93:
  * General
  - deprecated version property fix @Raghav1783 (#11903)
  - chore(deps): bump webpack from 5.76.1 to 5.94.0 in
    /install/docker-extension/ui @dependabot (#11815)
  - Fix handling of connection API response from remote provider
    @MUzairS15 (#11909)
  - ensure comp schema is not added and id is based on time of
    eval @MUzairS15 (#11901)
  * Meshery CLI
  - [mesheryctl] Return trimmed response for latest mesheryctl
    version @MUzairS15 (#11912)
  - [meshreyctl] Use central function to determine latest
    version. @MUzairS15 (#11891)
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.92:
  no CLI-related changes
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.91:
  * General
  - [chore] update schemas package to v0.7.31 and meshkit to
    v0.7.73 @MUzairS15 (#11894)
  - update hierarchical parent relationship @MUzairS15 (#11893)
  - Support addition of nodes during evaluation based on
    relationship definition @MUzairS15 (#11832)
  - [Models] [Relationships] AWS RDS Controller @Jougan-0
    (#11703)
  - Add external Link Interceptor for Docker Extension
    @sudhanshutech (#11858)
  - [Server] Include updated relationships in the design file
    diff. @MUzairS15 (#11856)
  - Add rule for evaluating deny selectors. @MUzairS15 (#11848)
  - fix handling of capabilities @MUzairS15 (#11855)
  - Remove unneeded test design files. @MUzairS15 (#11831)
  - Corrected the port number of Nighthawk in README.md
    @KunyueXing (#11824)
  - fix: flowchart component missing attributes
    @rishabhsharma1997 (#11822)
  - [Server] Fix design drawer not updating with latest design
    @MUzairS15 (#11819)
  - Change GetK8sContext according to new API response change
    @shubham251972 (#11818)
  - bump schemas @codeSafari10 (#11803)
  - [Docs] Readme language regarding star @marblom007 (#11798)
  - track relationships that are updated by evaluator as trace
    @MUzairS15 (#11796)
  - Add fallback when mapping model related details for meshery
    curated models @MUzairS15 (#11793)
  - Update edge-firewall.json @Jougan-0 (#11789)
  - bump meshkit w/signoff @Jougan-0 (#11786)
  - bump meshkit w/signoff @Jougan-0 (#11780)
  - add missing transitions w/signoff @Jougan-0 (#11779)
  - [Relationships] ACK S3 @Jougan-0 (#11706)
  - Bump micromatch from 4.0.4 to 4.0.8 in
    /install/docker-extension/ui @dependabot (#11767)
  - chore: Update github.com/meshery/schemas to v0.7.25
    @leecalcote (#11772)
  * Meshery CLI
  - [mesheryctl] Chore: point new release version message to
    docs.meshery.io @leecalcote (#11889)
  - Update command and fix minor bug w/signoff @Jougan-0 (#11791)
  - Update logs to be right @Jougan-0 (#11770)
  * Documentation
  - docs: update docs on installing minikube out of clusters
    @jerensl (#11890)
  - [CI][Docs] Identity prereleases @leecalcote (#11888)
  - [docs]: Document Catalog Publishing Workflow in Meshery
    @Kevin222004 (#11680)
  - Fix [Docs] Sistent Page Bugs - Text and Link errors #11553
    @kaushiktak19 (#11842)
  - Fix Duplicated Kubernetes Subheading in home/guides/tutorials
    of Docs @devbird007 (#11809)
  - [Docs] Enhance Error Codes reference page with links to
    Troubleshooting Guides @leecalcote (#11570)
  - docs: Fix extra spacing in architecture.md @ChinoUkaegbu
    (#11790)
  - remove older docs version from exclude @vishalvivekm (#11785)
  - [Docs]:Edge shape documentation added @SAHU-01 (#11701)
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.90:
  * General
  - add Style w/signoff @Jougan-0 (#11769)
  - Fix config update policy failing to update/resolve refs for
    some relationships. @MUzairS15 (#11768)
  - Default capability @MUzairS15 (#11765)
  - Fix aggressive matchlabels rels @MUzairS15 (#11757)
  - [Server] Fix design save error for clone operation @MUzairS15
    (#11748)
  - Remove%%sfromevent log @Jougan-0 (#11733)
  * Meshery CLI
  - update styles with styleoverides w/signoff @Jougan-0 (#11751)
  - fix: missing metadata error w/signoff @Jougan-0 (#11734)
  * Documentation
  - Fixed broken links in "Meshery Operator, MeshSync, Broker
    Troubleshooting Guide" @khabdrick (#11754)
  - Update providers.md @a-singh02 (#11746)
  - Update playground.md @a-singh02 (#11747)
* Sun Sep 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.89:
  * General
  - add source_uri for models whose components have the data
    w/signoff @Jougan-0 (#11730)
  - remove extra isNamespace w/signoff @Jougan-0 (#11732)
  - add left components w/signoff @Jougan-0 (#11731)
  - Add is namespace @Jougan-0 (#11723)
  - use latest kubernetes model version from registry for helm
    dry run. @MUzairS15 (#11720)
  - [Server] Format the eval results correctly. @MUzairS15
    (#11719)
  - [Server] Fix download API returning design in string format.
    @MUzairS15 (#11718)
  - [chore] update meshkit package to v0.7.66 @MUzairS15 (#11711)
  - bump meshkit w/signoff @Jougan-0 (#11699)
  - [Server] Send componentsUpdated as part of evaluation in the
    trace. @MUzairS15 (#11695)
  - update rels to contain subType and refractor to lowercase
    w/signoff @Jougan-0 (#11678)
  - upgrade models and comp @MUzairS15 (#11677)
  - build(deps): bump axios from 1.6.0 to 1.7.4 in
    /install/docker-extension/ui @dependabot (#11634)
  - Refactor: Add proper event description for design handler
    @singh1203 (#11548)
  - [Docker Extension] Make Catalog Items Clickable @humblenginr
    (#11599)
  - Update the design file in OCI package to design.yml
    @ctcarrier (#11595)
  * Meshery CLI
  - remove prerun for subcommands w/signoff @Jougan-0 (#11713)
  - Assign source_uri to model metadata. @MUzairS15 (#11709)
  - [UI] Fix Tab Navigation Issue on Create Modal
    @UtkarshAhuja2003 (#11578)
  - [Server] Supporting v1beta1 constructs. @MUzairS15 (#11583)
  - [mesheryctl] Rename mesh command to adapter @lekaf974
    (#11507)
  * Documentation
  - chore: add reusable include for extension guides
    @vishalvivekm (#11707)
  - [Docs] Build and Release notes on mesheryctl @leecalcote
    (#11608)
  - [Docs] Deploying WordPress And MySql With Persistent Volumes
    with Meshery tutorial @Alero-Awani (#11100)
  - [Docs] Adding generic legends @SAHU-01 (#11508)
  - [mesheryctl] Rename mesh command to adapter @lekaf974
    (#11507)
  - chore(docs): remove duplicaiton off components command
    @lekaf974 (#11623)
  - [Docs] Fix broken hyperlink in "Contributing to Model
    Relationships" section @rohitsrma (#11614)
  - [Docs] Fix Getting Started Broken Link @rohitsrma (#11582)
  - added new secrets to the docs @rishabhsharma1997 (#11602)
  - Fix: Close sidebar nav when clicking outside @shreyasinghX
    (#11594)
* Fri Aug  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.88:
  * General
  - Upgrade Meshkit and Silence Registration Errors in Console
    @humblenginr (#11584)
  - fix: missing model.json file for kubernetes w/signoff
    @Jougan-0 (#11576)
  - Move svg helper functions to meshkit. @MUzairS15 (#11575)
  - Bug: Return environments for each connection in local
    provider @Aijeyomah (#11559)
  - minor: correction of comment @Kevin222004 (#11544)
  - Fix unique key constraint error coming on boot @shubham251972
    (#11542)
  * Meshery CLI
  - Test: Increase Test Coverage of Doc File @amitamrutiya
    (#11579)
  - Refactor Entity Registration Logic @humblenginr (#11385)
  - [mesheryctl] Enhance User Experience of model export Command
    @humblenginr (#11563)
  * Meshery UI
  - [UI[ Fix k8s icon in the context switcher @MUzairS15 (#11577)
  - fix typo in playwright e2e @manzil-infinity180 (#11551)
  - fix: registry relationships tree bugs @dottharun (#11555)
  - Refactor Entity Registration Logic @humblenginr (#11385)
  - fix bug of publish filter @sudhanshutech (#11564)
  - Replace all checkboxes with Sistent @sudhanshutech (#11556)
  * Maintenance
  - Refactor Entity Registration Logic @humblenginr (#11385)
  - [CI] Chore: upgrade multi-plaform actions @leecalcote
    (#11543)
  * Documentation
  - fix typo in playwright e2e @manzil-infinity180 (#11551)
  - refactor: the url for catalog page @rishabhsharma1997
    (#11571)
  - Refactor Entity Registration Logic @humblenginr (#11385)
  - [mesheryctl] Enhance User Experience of model export Command
    @humblenginr (#11563)
  - sidebar-menu @vaishnaviadhau (#11467)
  - Working with Tags page added @iArchitSharma (#11240)
* Sat Aug  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- udpate to 0.7.87:
  * General
  - upgrade go mod w/signoff @Jougan-0 (#11541)
  - [Server] Boottime: add registrant's name for Model
    registration log @alloydm (#11511)
* Sat Aug  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.86:
  * General
  - Add workspace support for local provider @Yashsharma1911
    (#11482)
  - add missing subType w/signoff @Jougan-0 (#11481)
  - Add environment support for local provider @Yashsharma1911
    (#11464)
  - add missing displayName w/signoff @Jougan-0 (#11485)
  * Meshery CLI
  - feat: generate model based on model name w/signoff @Jougan-0
    (#11498)
  - fix linting for svg update w/signoff @Jougan-0 (#11519)
  - Updated filter view command docs @Aviral0702 (#11500)
  - Meshkit upgrade @humblenginr (#11509)
  * Meshery UI
  - Bump @mui/styles from 5.15.19 to 5.16.6 in /ui @dependabot
    (#11532)
  - Bump cypress from 13.8.1 to 13.13.2 in /provider-ui
    @dependabot (#11534)
  - Bump eslint-plugin-cypress from 2.13.3 to 3.4.0 in /ui
    @dependabot (#11531)
  - Bump start-server-and-test from 2.0.3 to 2.0.5 in
    /provider-ui @dependabot (#11533)
  - Bump eslint-plugin-cypress from 3.3.0 to 3.4.0 in
    /provider-ui @dependabot (#11537)
  - Bump @emotion/react from 11.11.3 to 11.13.0 in /provider-ui
    @dependabot (#11535)
  - Bump sistent package version @sudhanshutech (#11523)
  - fix typo in schema @sudhanshutech (#11524)
  - schema migrate for environments and workspace to sistent
    @sudhanshutech (#11483)
  - Meshkit upgrade @humblenginr (#11509)
  - Some UX fix in dashboard tables @sudhanshutech (#11449)
  - fix: Regression Rerendering due to duplicates button
    @dottharun (#11480)
  - Get Help modal for extensions @sudhanshutech (#11004)
  * Maintenance
  - Bump @mui/styles from 5.15.19 to 5.16.6 in /ui @dependabot
    (#11532)
  - Bump cypress from 13.8.1 to 13.13.2 in /provider-ui
    @dependabot (#11534)
  - Bump eslint-plugin-cypress from 2.13.3 to 3.4.0 in /ui
    @dependabot (#11531)
  - Bump start-server-and-test from 2.0.3 to 2.0.5 in
    /provider-ui @dependabot (#11533)
  - Bump google.golang.org/grpc from 1.64.1 to 1.65.0 @dependabot
    (#11528)
  - Bump github.com/fatih/color from 1.16.0 to 1.17.0 @dependabot
    (#11530)
  - Bump eslint-plugin-cypress from 3.3.0 to 3.4.0 in
    /provider-ui @dependabot (#11537)
  - Bump @emotion/react from 11.11.3 to 11.13.0 in /provider-ui
    @dependabot (#11535)
  - [CI] Update Mesheryctl GitHub Actions Workflow to Latest
    Versions @singh1203 (#11520)
  - fix: change to proper working directory @humblenginr (#11510)
  - [CI] Pull Changes Before auto-commit Action @humblenginr
    (#11489)
  * Documentation
  - Bump rexml from 3.3.2 to 3.3.3 in /docs @dependabot (#11538)
  - Update contributing-sever-events.md @humblenginr (#11522)
  - [Docs] fix pattern rowspan @dusdjhyeon (#11491)
  - [Docs] update custom meshkit code usage in meshery-server
    docs @alloydm (#11492)
  - [Server] Adding POST Capability to /api/events/ @boku13
    (#11190)
* Mon Jul 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.85:
  * General
  - Enhance Error Handling for Component Configuration in Design
    Handler @singh1203 (#11340)
  - update models @codeSafari10 (#11457)
  - Run regal linter against WASM policy and fix errors
    @ctcarrier (#11309)
  - Fix connection APIs for local provider @Yashsharma1911
    (#11023)
  * Meshery CLI
  - pattern import log statement improved/signoff @rahulrana701
    (#11438)
  - fixed filter list logging the endpoint @Aviral0702 (#11399)
  * Meshery UI
  - UI: fix registry lazy fetch and InfiniteScrolling -v2
    @dottharun (#11469)
  - (fix): fixed zIndex of Navbar @senthil-athiban (#11322)
  - Support redirection to correct UI page after auth instead of
    landing on home page. @MUzairS15 (#11450)
  - theme for toolbar components @sudhanshutech (#11459)
  - RTK migration: filters @dottharun (#11452)
  - Migrate designs to rtk @sudhanshutech (#11413)
  * Documentation
  - Bump rexml from 3.2.8 to 3.3.2 in /docs @dependabot (#11435)
  - fix: [Docs] Link not working @Shreshthaaa (#11451)
* Tue Jul 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.84:
  * General
  - [Relationship] Add edge-annotation relationship for all
    components @MUzairS15 (#11442)
  - update components @codeSafari10 (#11432)
  - animate edge relationships @codeSafari10 (#11415)
  - add type to wasm relationships @codeSafari10 (#11397)
  - [Relationships]: add istio relationship and fix subType to
    type in e… @innocentrda (#11272)
  * Meshery CLI
  - mesheryctl: fix relationships view command unmarshall error
    @alloydm (#11387)
  * Meshery UI
  - [chore] Bump sistent @dragon-slayer875 (#11448)
  - Fix registry styles @shubham251972 (#11447)
  - update settings UI @MUzairS15 (#11443)
  - Expose info modal to extension @shubham251972 (#11330)
  - ench: visibility option in info modal @rishabhsharma1997
    (#11427)
  - Revert "fix: rtk warning for hooks field" @dottharun (#11424)
  - Lifecycle search placeholders modified @Hackmey (#11409)
  - add maxwidth property to transferlist modal @sudhanshutech
    (#11403)
  - Fix and add meaningful notification on toggle of extensions
    @sudhanshutech (#11396)
  - [fix] Update Design action icon component and replace onClick
    function @dragon-slayer875 (#11400)
  - fix: rtk warning for hooks field @dottharun (#11374)
  - [UI] add the version in InfoModal @Kevin222004 (#11378)
  - UI: fix - settings/registry styles @dottharun (#11394)
  * Maintenance
  - add missing pull statemnt w/signoff @Jougan-0 (#11436)
  - Workflow update @Jougan-0 (#11434)
  - Update email to contain more detail w/singoff @Jougan-0
    (#11404)
  * Documentation
  - [Docs]: Fix markdown syntax issue @innocentrda (#11440)
  - [Docs]: Updating Meshery docs @innocentrda (#11426)
  - [Documentation]: Missing 'help-wanted label' hyperlink
    updated @SAHU-01 (#11417)
  - Add contribution docs for sistent in meshery ui
    @sudhanshutech (#11392)
  - Amended transcription @ENUMERA8OR (#11391)
* Tue Jul 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.83:
  * General
  - add sistent docs @codeSafari10 (#11393)
  - move dapr relationship to model folder @codeSafari10 (#11388)
  * Meshery CLI
  - Updated filter view command to accept multi-word filters and
    filter ID @Aviral0702 (#11336)
* Sat Jul 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.82:
  * Meshery UI
  - Revert "Bump @reduxjs/toolkit from 1.9.5 to 2.2.6 in /ui"
    @Yashsharma1911 (#11383)
* Sat Jul 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.81:
  * General
  - Replace the repetitive logic with handler pagination
    @singh1203 (#11255)
  - fix wasm filter relationships @codeSafari10 (#11375)
  - fix and add dapr rels for other components @codeSafari10
    (#11365)
  - Init dapr sidecar relationships @leecalcote (#11364)
  * Meshery UI
  - [Chore] UI: Upgrade dependent package Sistent to v0.14.65
    @leecalcote (#11379)
  - fix: eslint rollback to 8.x.x @dottharun (#11372)
  - remove operator switch @MUzairS15 (#11376)
  - Added end-to-end playwright tests for UI/Connections
    component @DevRish (#11220)
  * Maintenance
  - fix commit issue w/signoff @Jougan-0 (#11366)
  - Added end-to-end playwright tests for UI/Connections
    component @DevRish (#11220)
  * Documentation
  - Update component-shape-guide.md @nwanduka (#10621)
  - Update Secrets list in Build and Release @Jacobojijo (#11359)
  - Corrected Spelling Mistakes @ENUMERA8OR (#11371)
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.80:
  * General
  - Bump ejs from 3.1.7 to 3.1.10 in /install/docker-extension/ui
    @dependabot (#10830)
  - [Cert-manager]: Sync upstream master and add cert-manager
    relationships @innocentrda (#10986)
  - update go.sum w/signoff @Jougan-0 (#11356)
  * Meshery CLI
  - [mesheryctl] consistent mesheryctl pattern list @dusdjhyeon
    (#11264)
  - fix concurent write error w/signoff @Jougan-0 (#11361)
  - [Feat] mesheryctl model export command @humblenginr (#11338)
  - [Mesheryctl] model import command @Jougan-0 (#11332)
  - [Models] Update models to reflect the correct schemaVersion.
    @MUzairS15 (#11344)
  * Meshery UI
  - Bump @reduxjs/toolkit from 1.9.5 to 2.2.6 in /ui @dependabot
    (#11290)
  - Bump eslint from 8.57.0 to 9.6.0 in /provider-ui @dependabot
    (#11281)
  - [chore] Update styles @dragon-slayer875 (#11341)
  - chore: bump sistent @dottharun (#11360)
  - fix width issues of stepper modal @sudhanshutech (#11343)
  - fix: setting registry tree view @surajgjadhav (#11335)
  - Support for rjsf form in sistent modal and migrate all modals
    @sudhanshutech (#11163)
  * Maintenance
  - Update integrations-updater.yml @vishalvivekm (#11362)
  - Bump @reduxjs/toolkit from 1.9.5 to 2.2.6 in /ui @dependabot
    (#11290)
  - Bump eslint from 8.57.0 to 9.6.0 in /provider-ui @dependabot
    (#11281)
  - Bump google.golang.org/grpc from 1.64.0 to 1.64.1 @dependabot
    (#11355)
  * Documentation
  - [mesheryctl] consistent mesheryctl pattern list @dusdjhyeon
    (#11264)
  - Spelling Mistakes Correction @ENUMERA8OR (#11347)
  - [Mesheryctl] model import command @Jougan-0 (#11332)
  - docs: added NPM_TOKEN details under secrets section
    @surajgjadhav (#11350)
* Wed Jul 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.79:
  * General
  - [Relationships] Dapr: Add dapr relationships @innocentrda
    (#11058)
  * Meshery CLI
  - pattern export command for mesheryctl @Jougan-0 (#11270)
  * Meshery UI
  - remove validation error truncating @aabidsofi19 (#11333)
  - Move prompt component to sistent modal @sudhanshutech
    (#11317)
  - Bump relay-compiler from 16.2.0 to 17.0.0 in /ui @dependabot
    (#11279)
  - Fix info modal validation issues @shubham251972 (#11308)
  * Maintenance
  - Bump relay-compiler from 16.2.0 to 17.0.0 in /ui @dependabot
    (#11279)
  - Bump google.golang.org/api from 0.169.0 to 0.187.0
    @dependabot (#11298)
  - Update cncf-staging-playground-deploy-meshery.yaml @MUzairS15
    (#11328)
  - [CI] Pull Request Labeler: Update labeler to include matching
    of *.rego files @leecalcote (#11327)
  * Documentation
  - pattern export command for mesheryctl @Jougan-0 (#11270)
  - Updated extension points link in FAQ.md @Aviral0702 (#11325)
  - Fix docs build failing @shubham251972 (#11326)
* Wed Jul  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.78:
  * General
  - [chore] Dep upgrades @MUzairS15 (#11323)
  - bump schemas to v0.7.42 @MUzairS15 (#11296)
  - Fix pattern and filter API for local provider @shubham251972
    (#11295)
  - rename wasm folder to policies @leecalcote (#11287)
  - [Fix] Fix makefile test-setup-ui command @dragon-slayer875
    (#11274)
  - split Relationship and update schemaVersion w/signoff
    @Jougan-0 (#11266)
  * Meshery CLI
  - [mesheryctl] Support PROVIDER_URLS env in system start,
    update command @MUzairS15 (#11310)
  - [Integrations] Fallback to model svgs @MUzairS15 (#11299)
  - Warning mesheryctl start @Jougan-0 (#10997)
  - [mesheryctl]: fixes the panic issue of mesheryctl filter list
    @briheet (#11265)
  - Extentsion to logs @Jougan-0 (#11267)
  - fixed upgrade meshery cli broken links w/signoff @STAR-173
    (#11269)
  - [mesheryctl] Addition of relationship search @Jougan-0
    (#10956)
  - [Docs] Updating the docs for mesheryctl exp command #11204
    @dusdjhyeon (#11225)
  * Meshery UI
  - Bump @babel/eslint-parser from 7.23.10 to 7.24.7 in
    /provider-ui @dependabot (#11282)
  - Bump eslint-config-next from 14.1.4 to 14.2.4 in /provider-ui
    @dependabot (#11280)
  - [FIx] Fix PROVIDER_TOKEN fallback logic for e2e tests
    @dragon-slayer875 (#11294)
  - Extentsion to logs @Jougan-0 (#11267)
  - [Docs] Updating the docs for mesheryctl exp command #11204
    @dusdjhyeon (#11225)
  - Bump react-countdown-clock from 2.10.0 to 2.11.0 in /ui
    @dependabot (#11278)
  - update styles @codeSafari10 (#11273)
  * Maintenance
  - Bump github.com/gorilla/websocket from 1.5.1 to 1.5.3
    @dependabot (#11292)
  - Bump github.com/spf13/cobra from 1.8.0 to 1.8.1 @dependabot
    (#11293)
  - Bump @babel/eslint-parser from 7.23.10 to 7.24.7 in
    /provider-ui @dependabot (#11282)
  - Bump eslint-config-next from 14.1.4 to 14.2.4 in /provider-ui
    @dependabot (#11280)
  - Bump fortio.org/fortio from 1.63.5 to 1.65.0 @dependabot
    (#11297)
  - [FIx] Fix PROVIDER_TOKEN fallback logic for e2e tests
    @dragon-slayer875 (#11294)
  - [CI] Remove scripts folder and go packages from dependabot
    config @leecalcote (#11288)
  - Extentsion to logs @Jougan-0 (#11267)
  - [Docs] GitHub Issue Template: Add contrib instructions for
    Meshery Components @leecalcote (#11245)
  - [Docs] Updating the docs for mesheryctl exp command #11204
    @dusdjhyeon (#11225)
  - Bump github.com/briandowns/spinner from 1.23.0 to 1.23.1
    @dependabot (#11276)
  - Bump react-countdown-clock from 2.10.0 to 2.11.0 in /ui
    @dependabot (#11278)
  - [CI] Enable staging playground workflow @cpepper96 (#11285)
  * Documentation
  - fix: the error image in integration @rishabhsharma1997
    (#11300)
  - Updated Meshery installation link in FAQ.md @Aviral0702
    (#11301)
  - Update contributing-models.md @aabidsofi19 (#11303)
  - Warning mesheryctl start @Jougan-0 (#10997)
  - fixed upgrade meshery cli broken links w/signoff @STAR-173
    (#11269)
  - [Docs] Updating the docs for mesheryctl exp command #11204
    @dusdjhyeon (#11225)
  - Updated Meshkit logger docs @Aviral0702 (#11202)
  - chore: remove commented out GitHub link in navigation.yml
    @leecalcote (#11259)
* Wed Jul  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.77:
  * General
  - delete stuck pods in valid_namespaces @MUzairS15 (#10904)
  * Meshery CLI
  - Set source-type flag required @lekaf974 (#11020)
  * Meshery UI
  - Deployment lifecycle refactor @codeKraken19 (#11060)
  - Set source-type flag required @lekaf974 (#11020)
  * Maintenance
  - Set source-type flag required @lekaf974 (#11020)
  - workflow fix @iArchitSharma (#11054)
  * Documentation
  - Set source-type flag required @lekaf974 (#11020)
* Sat Jun 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.76:
  * Meshery UI
  - [UI]: Add a new Catalog page and it's menu item @dottharun
    (#11050)
  - fix(ui): InfoModal bug in designs-page DataTable @dottharun
    (#11177)
  - Fix hover over avatar @EleisonC (#11165)
  - migrated cypress tests to playwright @DevRish (#11095)
  * Maintenance
  - chore(deps): Bump
    github.com/Azure/azure-sdk-for-go/sdk/azidentity from 1.4.0
    to 1.6.0 @dependabot (#11153)
  - [CI] Update Staging Playground Workflow @cpepper96 (#11213)
  - fix directory address w/signoff @Jougan-0 (#11215)
  - workflow update for proper logs w/signoff @Jougan-0 (#11214)
  * Documentation
  - Bug: Fixed the logic to not show the components when it is
    empty @ayushrakesh (#11221)
* Sat Jun 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.75:
  * General
  - [chore] migrate /bin/bash shebangs to /usr/bin/env bash
    @aabidsofi19 (#11209)
  - [Relationships]: Nginx ingress relationships @innocentrda
    (#11121)
  - remove Logrus with meshkit logger w/signoff @Jougan-0
    (#11176)
  * Meshery CLI
  - workflow update to mail error log w/signoff @Jougan-0
    (#11156)
  - Aijeyomah/feature/list exp relationship @Jougan-0 (#11101)
  - refactor(components): Promote component command @lekaf974
    (#11135)
  * Meshery UI
  - Registry log dynamic @Jougan-0 (#11065)
  - [Chore] Add permission check for reset database
    @dragon-slayer875 (#11193)
  * Maintenance
  - workflow update to mail error log w/signoff @Jougan-0
    (#11156)
  - Update build-and-release-edge.yml @MUzairS15 (#11199)
  - Bump golang.org/x/oauth2 from 0.16.0 to 0.20.0 @dependabot
    (#10879)
  * Documentation
  - [chore] migrate /bin/bash shebangs to /usr/bin/env bash
    @aabidsofi19 (#11210)
  - Update ui.md - enhanced /docs/pages/extensibility/ui.md
    @ayushrakesh (#11200)
  - [Docs] Partial: Instructions for Creating a New Component
    with UI Schema @leecalcote (#11201)
  - Updated mesheryctl command for applying WASM Filter
    @Aviral0702 (#11197)
  - [Docs] Refinement of the description of relationships and
    models @leecalcote (#11195)
  - refactor(components): Promote component command @lekaf974
    (#11135)
* Sat Jun 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.74:
  * General
  - [Dosc] Revert removal of line return to ensure README
    hyperlinks show as intended. @jameshorton2337 (#11182)
  * Meshery CLI
  - fix: logs to have same current model and extracted model
    @Jougan-0 (#11118)
  * Meshery UI
  - fix notistack crash @codeSafari10 (#11186)
  - fix height of registry section @sudhanshutech (#10642)
  - remove unwanted styling add tooltip for unpublish
    confirmation @sudhanshutech (#11172)
  - [bug] fix crash of connections page @sudhanshutech (#11171)
  - Revert "Revert "Bump and migrate notistack according new
    version"" @sudhanshutech (#11160)
  * Bug Fixes
  - add missing action func to infomodal @sudhanshutech (#11173)
  - [bug] fix crash of connections page @sudhanshutech (#11171)
  * Maintenance
  - Bump github.com/vektah/gqlparser/v2 from 2.5.11 to 2.5.14
    @dependabot (#11167)
  * Documentation
  - Updated the installation link of Meshery by Minikube using
    Helm @Aviral0702 (#11181)
* Thu Jun 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.73:
  * General
  - [Server] Pkg generation during download of design. @MUzairS15
    (#11162)
  - Bump braces from 3.0.2 to 3.0.3 in
    /install/docker-extension/ui @dependabot (#11155)
  * Meshery CLI
  - fix ratelimit artifacthub w/signoff @Jougan-0 (#11144)
  - [mesheryctl] Fix list --count is not returning the total when
    page flag is present @lekaf974 (#11143)
  * Meshery UI
  - Move ProgressBar to useSnackbar and convert to react
    functional component @sudhanshutech (#11159)
  - Move Schema Validation Actor to WebWorker @codeSafari10
    (#11141)
  - Revert "Bump and migrate notistack according new version"
    @aabidsofi19 (#11158)
  - Bump braces from 3.0.2 to 3.0.3 in /provider-ui @dependabot
    (#11154)
  - Bump and migrate notistack according new version
    @sudhanshutech (#11147)
  - Fix filters not getting fetched locally @shubham251972
    (#11150)
  - fix(ui): dashboard-only responsiveness @dottharun (#11152)
  - Make CASL CAN case insensitive @dragon-slayer875 (#11148)
  - [UI] use connection metadata to get context @codeSafari10
    (#11145)
  * Maintenance
  - Bump braces from 3.0.2 to 3.0.3 in /provider-ui @dependabot
    (#11154)
  - added issue/docs-needed @milinddethe15 (#11151)
* Tue Jun 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.72:
  * General
  - [Server] Format deployment events @MUzairS15 (#11102)
  * Meshery UI
  - fix connections page break @sudhanshutech (#11138)
  - Deployment lifecycle enhancement @codeSafari10 (#11094)
  - added sistentprovider to components @captain-Akshay (#11136)
  - [Chore] UI: Upgrade to 0.14.48 Sistent @leecalcote (#11134)
  * Documentation
  - chore(docs): Add model reference documentation @lekaf974
    (#11132)
  - Leecalcote/docs/mesheryctl-model @leecalcote (#11128)
* Fri Jun  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.71:
  * General
  - [Server] Support performing upgrades for existing dependent
    resources. @MUzairS15 (#11127)
  - us default eval query if no query is specified in rel def
    @MUzairS15 (#11099)
  * Meshery CLI
  - [mesheryctl] Promote model command @lekaf974 (#11114)
  * Documentation
  - [mesheryctl] Promote model command @lekaf974 (#11114)
  - chore(deps-dev): Bump actiontext from 7.0.8.1 to 7.1.3.4 in
    /docs @dependabot (#11126)
  - Add cursor to table rows @iArchitSharma (#11111)
* Wed Jun  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.70:
  * General
  - [Server] Policy for Hierarchical Parent relationship.
    @MUzairS15 (#11098)
  * Meshery UI
  - Enhance rtk and redux global injection @codeSafari10 (#11108)
  - fix:offset fix w/signoff @Jougan-0 (#11064)
  * Maintenance
  - Create staging playground deploy workflow and other updates
    @cpepper96 (#11079)
  * Documentation
  - Add Key ID & Monikers @iArchitSharma (#11074)
* Mon Jun  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.69 (.68 does not exist):
  * General
  - [Relationships]: Add kube-prometheus-stack relationships
    @innocentrda (#11072)
  - [Server] Remove hardcoded registrant/host @MUzairS15 (#11073)
  - generate view link for the deployed design @MUzairS15
    (#11071)
  * Meshery UI
  - Revert "chore(deps-dev): Bump eslint from 8.57.0 to 9.4.0 in
    /provider-ui" @leecalcote (#11092)
  - chore(deps-dev): Bump eslint from 8.57.0 to 9.4.0 in
    /provider-ui @dependabot (#11085)
  - chore(deps): Bump cron-time-generator from 1.3.2 to 2.0.3 in
    /ui @dependabot (#11080)
  - chore(deps-dev): Bump @cypress/code-coverage from 3.12.26 to
    3.12.39 in /provider-ui @dependabot (#11084)
  - chore(deps-dev): Bump @storybook/addon-interactions from
    6.5.16 to 8.1.5 in /ui @dependabot (#11083)
  - chore(deps-dev): Bump @cypress/code-coverage from 3.12.16 to
    3.12.39 in /ui @dependabot (#11082)
  - chore(deps-dev): Bump eslint-plugin-cypress from 2.15.1 to
    3.3.0 in /provider-ui @dependabot (#11087)
  - chore(deps): Bump react-dom from 18.2.0 to 18.3.1 in
    /provider-ui @dependabot (#11088)
  - Alignment of Notification Center and backdrop on Open
    @captain-Akshay (#11078)
  - missing permission page @captain-Akshay (#11076)
  - Replace tooltips with sistent tooltips @dragon-slayer875
    (#11067)
  * Maintenance
  - chore(deps): Bump github.com/prometheus/common from 0.45.0 to
    0.53.0 @dependabot (#11090)
  - chore(deps-dev): Bump eslint from 8.57.0 to 9.4.0 in
    /provider-ui @dependabot (#11085)
  - chore(deps): Bump cron-time-generator from 1.3.2 to 2.0.3 in
    /ui @dependabot (#11080)
  - chore(deps-dev): Bump @cypress/code-coverage from 3.12.26 to
    3.12.39 in /provider-ui @dependabot (#11084)
  - chore(deps-dev): Bump @storybook/addon-interactions from
    6.5.16 to 8.1.5 in /ui @dependabot (#11083)
  - chore(deps-dev): Bump @cypress/code-coverage from 3.12.16 to
    3.12.39 in /ui @dependabot (#11082)
  - chore(deps-dev): Bump eslint-plugin-cypress from 2.15.1 to
    3.3.0 in /provider-ui @dependabot (#11087)
  - chore(deps): Bump react-dom from 18.2.0 to 18.3.1 in
    /provider-ui @dependabot (#11088)
  - chore(deps): Bump github.com/spf13/viper from 1.17.0 to
    1.18.2 @dependabot (#11091)
  * Documentation
  - Categorization of Permissions @iArchitSharma (#11053)
  - [Docs] Meshery Registry @leecalcote (#11069)
* Thu May 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.67:
  * General
  - delete stuck pods in valid_namespaces @MUzairS15 (#10904)
  * Meshery CLI
  - Set source-type flag required @lekaf974 (#11020)
  * Meshery UI
  - Deployment lifecycle refactor @codeKraken19 (#11060)
  - Set source-type flag required @lekaf974 (#11020)
  * Maintenance
  - Set source-type flag required @lekaf974 (#11020)
  - workflow fix @iArchitSharma (#11054)
  * Documentation
  - Set source-type flag required @lekaf974 (#11020)
* Thu May 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.66:
  * Meshery UI
  - fix connection states not available @MUzairS15 (#11059)
* Thu May 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.65:
  * General
  - [Server] Do not perform encode/decode of token when making
    requests to Provider @MUzairS15 (#11057)
  - [Server] Lazy conversion from design formats to
    meshery-design @MUzairS15 (#11022)
  * Meshery CLI
  - fix:use sprintf to provide proper logs w/signoff @Jougan-0
    (#11046)
  - [mesheryctl] registry generate: fix logs @leecalcote (#11035)
  - [Generator] Assign default metadata for newly generated
    comps. @MUzairS15 (#11043)
  * Meshery UI
  - Revert "Replace tooltips with sistent tooltips"
    @dragon-slayer875 (#11056)
  - Replace tooltips with sistent tooltips @dragon-slayer875
    (#11052)
  - update rjsf form props @codeKraken19 (#11044)
  * Maintenance
  - Updated label commenter to new docs @krishantt (#11031)
  * Documentation
  - docs: remove application docs w/signoff @Jougan-0 (#11017)
* Fri May 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.64:
  * Meshery UI
  - missing state @captain-Akshay (#11030)
* Thu May 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.63:
  * Meshery UI
  - [Extension Point] Disable footer and padding for fullscreen
    extensions @codeKraken19 (#11027)
* Thu May 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.62:
  * General
  - [Argo CD]: Add argocd AppProject-ApplicationSet-Application
    relationships @innocentrda (#10920)
  * Meshery UI
  - bump sistent package @sudhanshutech (#11018)
* Wed May 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.61:
  * Meshery UI
  - fix eslint check @sudhanshutech (#11014)
  * Maintenance
  - Keys table added @iArchitSharma (#10756)
  * Documentation
  - Keys table added @iArchitSharma (#10756)
* Wed May 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.60:
  * General
  - fix nil pointer dereference @code-sleuth (#10932)
  - [Server] handling of token and cookies, auth and session
    middleware @MUzairS15 (#11003)
  * Meshery CLI
  - Mesheryctl's unit tests fix @Jougan-0 (#11002)
  - Revert "Revert "[mesheryctl] Bug fixes in mesheryctl system
    start"" @MUzairS15 (#10993)
  * Meshery UI
  - [Navigator.js] Equalized the height of Meshery logo container
    @Aryakoste (#10982)
  - bump sistent @captain-Akshay (#11001)
  - Convert class to functional component in
    management/service-mesh @JeevaRamanathan (#10981)
  - Feat: Implement new missing permissions page
    @dragon-slayer875 (#10969)
* Sat May 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.59:
  * Meshery CLI
  - Revert "[mesheryctl] Bug fixes in mesheryctl system start"
    @leecalcote (#10992)
  * Documentation
  - docs: Replaced mesheryctl app & onboard commands @singh1203
    (#10972)
* Sat May 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.58:
  * General
  - [Server] Fix k8s manifest to pattern conversion logic
    @MUzairS15 (#10973)
  - new feature on roadmap @captain-Akshay (#10964)
  - [server]fix missing services attribute for empty design
    @MUzairS15 (#10968)
  - fix: fix provider lint step in make ui-build
    @dragon-slayer875 (#10957)
  * Meshery CLI
  - [mesheryctl] Bug fixes in mesheryctl system start @MUzairS15
    (#10961)
  * Meshery UI
  - responsive v1 @captain-Akshay (#10985)
  - Initialize Playwright testing @codeKraken19 (#10930)
  - without css baseline @captain-Akshay (#10955)
  - fixes#10910: @MUzairS15 (#10967)
  - Bump sistent & cleanup packages @sudhanshutech (#10963)
  * Maintenance
  - Initialize Playwright testing @codeKraken19 (#10930)
  * Documentation
  - Bump rexml from 3.2.6 to 3.2.8 in /docs @dependabot (#10984)
  - Initialize Playwright testing @codeKraken19 (#10930)
  - Eliminate duplication of tutorials listing on homepage
    @vishalvivekm (#10983)
  - Update error-codes.md @leecalcote (#10959)
* Tue May 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update ot 0.7.57:
  No changes according to the changelog
  https://github.com/meshery/meshery/releases/tag/v0.7.57
* Tue May 14 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.56:
  * General
  - [Server] Add API to convert from multiple design formats to
    meshery-design @MUzairS15 (#10928)
  * Meshery CLI
  - [mesheryctl] support setting of provider with context create
    and system re/start command. @MUzairS15 (#10921)
  - Mesheryctl: Add interactive pagination for filter list
    @Aijeyomah (#10732)
  * Meshery UI
  - Workspace and org @captain-Akshay (#10884)
  - Bump @open-policy-agent/opa-wasm from 1.8.0 to 1.8.1 in /ui
    @dependabot (#10838)
  - [UI] enhance dry run formatting and events . @codeKraken19
    (#10952)
  - [Provider UI] Fix broken Meshery provider logo image
    @dragon-slayer875 (#10944)
  - [UI] Broken image link in Provider modal. #10909 @SparshDusad
    (#10919)
  - Remove boolean values from selectablerows prop @sudhanshutech
    (#10912)
  - add info icon to kubernetes connections @sudhanshutech
    (#10911)
  - [UI] Use correct pagesize for APIs used to render
    Configuration charts in Dashboard UI. @MUzairS15 (#10906)
  * Bug Fixes
  - Fix seeding default org in "Local Provider" @Yashsharma1911
    (#10899)
  * Maintenance
  - Bump @open-policy-agent/opa-wasm from 1.8.0 to 1.8.1 in /ui
    @dependabot (#10838)
  - Bump gonum.org/v1/gonum from 0.14.0 to 0.15.0 @dependabot
    (#10844)
  * Documentation
  - [Docs] Update multiple-of-the-same-adapter.md @leecalcote
    (#10947)
  - Bump nokogiri from 1.16.2 to 1.16.5 in /docs @dependabot
    (#10945)
  - [Docs]: Reduce font size in Meshery REST API page @jasonmokk
    (#10914)
  - padding fix for mobile view @iArchitSharma (#10897)
  - Add Related models category name @iArchitSharma (#10896)
* Thu May  9 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.55:
  * General
  - [CI] Minor updates to playground cleanup @cpepper96 (#10802)
  - fix nil pointer refrernce @MUzairS15 (#10892)
  * Meshery UI
  - ui: mention SMIResults has been deprecated @dottharun
    (#10893)
  - remove unused vars @codeKraken19 (#10882)
  - Bump @emotion/styled from 11.11.0 to 11.11.5 in /provider-ui
    @dependabot (#10840)
  - Bump @4tw/cypress-drag-drop from 2.2.3 to 2.2.5 in /ui
    @dependabot (#10837)
  - Bump cypress from 13.7.1 to 13.8.1 in /provider-ui
    @dependabot (#10842)
  * Maintenance
  - [CI] Fix .github/labeler.yml upgrade to actions/labeler@v5
    problem @tico88612 (#10817)
  - Bump @emotion/styled from 11.11.0 to 11.11.5 in /provider-ui
    @dependabot (#10840)
  - Bump @4tw/cypress-drag-drop from 2.2.3 to 2.2.5 in /ui
    @dependabot (#10837)
  - Bump cypress from 13.7.1 to 13.8.1 in /provider-ui
    @dependabot (#10842)
  * Documentation
  - Fix sidebar top @abhishekmmgn (#10765)
  - add: Relationship between pod and other k8s resources[high
    level] @RipulHandoo (#10332)
  - [docker-extension.md] Single line commands formatted.
    @Aryakoste (#10866)
* Wed May  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.54:
  * General
  - Update README.md @MUzairS15 (#10876)
  - [Server] Feat: Move to v1beta1 @MUzairS15 (#10623)
  * Meshery UI
  - Subscribe header component to CASL ability update @betelgeuse-code (#10869)
  - sistent bump and valid component @captain-Akshay (#10872)
  - [UI] fix design configurator @MUzairS15 (#10871)
  - Bump sistent @aabidsofi19 (#10870)
  - [UI] Account Menu Extension Enhancements @codeKraken19 (#10854)
  * Documentation
  - migrate to v1beta1 @MUzairS15 (#10623)
* Sun May  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.53:
  * Meshery UI
  - fix broken connection path @codeKraken19 (#10858)
  - Fix pagination issues with registrant tab @Yashsharma1911
    (#10859)
  * Maintenance
  - Update models.md @MUzairS15 (#10868)
  * Documentation
  - Model include added in integrations layout @iArchitSharma
    (#10759)
  - [Docs] Quick Start enhancements; mesheryctl install
    @leecalcote (#10865)
  - [Docs] Shorten quick start guide @leecalcote (#10852)
  - remove meshery-operator line from docs @vishalvivekm (#10850)
* Thu May  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.52:
  * General
  - [chore] Bump meshkit to v0.7.25 @MUzairS15 (#10829)
  - [Server] Add support to fetch connection by id. @MUzairS15
    (#10801)
  - [Server] fix pagination logic @MUzairS15 (#10824)
  - Bump next_error_code to fix test that failing @lekaf974
    (#10818)
  * Meshery CLI
  - [Bug] Fix import pattern command @betelgeuse-code (#10847)
  * Meshery UI
  - Add notification for import of design/filter @sudhanshutech
    (#10831)
  - Update validation modal font weight @dragon-slayer875
    (#10835)
  - Bump react from 18.2.0 to 18.3.1 in /provider-ui @dependabot
    (#10841)
  - Bump @mui/icons-material from 5.15.14 to 5.15.16 in
    /provider-ui @dependabot (#10839)
  - Bump universal-cookie from 4.0.4 to 7.1.4 in /ui @dependabot
    (#10846)
  - Enhance Deployement Environment Step @codeKraken19 (#10821)
  - Fix issue of assigning design to workspace @sudhanshutech
    (#10828)
  - [UI] Fix MeshSync datatable. @MUzairS15 (#10823)
  * Maintenance
  - Bump react from 18.2.0 to 18.3.1 in /provider-ui @dependabot
    (#10841)
  - Bump @mui/icons-material from 5.15.14 to 5.15.16 in
    /provider-ui @dependabot (#10839)
  - Bump github.com/go-openapi/runtime from 0.26.2 to 0.28.0
    @dependabot (#10843)
  - Bump universal-cookie from 4.0.4 to 7.1.4 in /ui @dependabot
    (#10846)
  * Documentation
  - Updated relationships include file @ritiksaxena124 (#10833)
  - Updated relationships docs to include links to designs
    representing relationships @ritiksaxena124 (#10827)
  - add redirect_from @dextrot (#10820)
  - docs: Updated CLI command reference @singh1203 (#10807)
* Tue Apr 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.51:
  * General
  - [Server] Fix nil pointer dereference @MUzairS15 (#10809)
  - [Server] Change logs verbosity for design resources @MUzairS15 (#10768)
  - update descriptions for heirarchical relationships @codeKraken19 (#10781)
  - [Server][Events] Add support to persist events to remote provider. @MUzairS15 (#10782)
  * Meshery CLI
  - [Server] Add support for retrieving metrics for designs. @MUzairS15 (#10800)
  - feat: environment command @RipulHandoo (#10663)
  * Meshery UI
  - Bump axios from 0.27.2 to 1.6.8 in /ui @dependabot (#10813)
  - fix(WorkspaceCards): fix card background color @dragon-slayer875 (#10803)
  - [UI] remove dead code @codeKraken19 (#10794)
  - Code kraken modals @codeKraken19 (#10792)
  - [UI] Fix Styling and add documentation @codeKraken19 (#10790)
  - [Docs] Add Jsdoc Comments to components @codeKraken19 (#10786)
  - [UI] Add Jsdoc to data formatters @codeKraken19 (#10788)
  - [UI] Fix types in connection helpers @codeKraken19 (#10789)
  - [UI] remove redundant logs @codeKraken19 (#10787)
  - remove redundant notifications from ui @codeKraken19 (#10785)
  - Convert environment makestyles with styled components @betelgeuse-code (#10780)
  * Maintenance
  - Bump axios from 0.27.2 to 1.6.8 in /ui @dependabot (#10813)
  - Set overwrite flag to true for the upload-artifact action @code-sleuth (#10811)
  * Documentation
  - [Tutorial] ConfigMaps and Secrets with Meshery @sangramrath (#10744)
  - Fix Editable include @iArchitSharma (#10804)
  - update reading list @dextrot (#10779)
  - [Docs] Typo fixes @ShivamCoder23 (#10778)
* Wed Apr 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.50:
  * General
  - add capabilities to nodegroupwallet @aabidsofi19 (#10763)
  - Fix deployment failures @MUzairS15 (#10767)
  * Meshery CLI
  - feat: workspace command @RipulHandoo (#10634)
  - Add proper meshkit sytle error logging for ClearLine function
    @Aijeyomah (#10556)
  - Fix behavior to display helper function @lekaf974 (#10685)
  * Meshery UI
  - Fix not able to download design @Yashsharma1911 (#10766)
  * Documentation
  - [Fix Docs] Tutorial: Exploring Kubernetes CronJobs with
    Meshery Playground @sandramsc (#10107)
* Fri Apr 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.49:
  * Meshery UI
  - Disable permission check for now @dragon-slayer875 (#10749)
  - Fix wrong key in permission constant file for preferences
    @Yashsharma1911 (#10748)
* Thu Apr 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.48:
  * Meshery UI
  - Meshery UI permissions addition/fix @dragon-slayer875
    (#10728)
* Wed Apr 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.47:
  * Meshery CLI
  - Ripul handoo/mesheryctl/args error @RipulHandoo (#10726)
  - [Chore] Update copyright holder in project license
    @leecalcote (#10729)
  - [CI] fix: Mesheryctl lint checks failing test @singh1203
    (#10643)
  - Revert "Fix mesheryctl publish to remote provider command"
    @Yashsharma1911 (#10715)
  - Fix mesheryctl publish to remote provider command
    @Yashsharma1911 (#10714)
  * Meshery UI
  - feat: enhance deployment flow @aabidsofi19 (#10733)
  - expose remote provider capabilities @Aseem22 (#10575)
  - ui bugs and enchanment @captain-Akshay (#10641)
  - chore(Popup): change primary button color @dragon-slayer875
    (#10727)
  - Bump tar from 6.1.15 to 6.2.1 in /ui @dependabot (#10718)
  * Maintenance
  - [Chore] Update copyright holder in project license
    @leecalcote (#10729)
  - change integration output path to `_models` collection
    @vishalvivekm (#10717)
  - Bump tar from 6.1.15 to 6.2.1 in /ui @dependabot (#10718)
  - [CI] fix: Mesheryctl lint checks failing test @singh1203
    (#10643)
  * Documentation
  - Missing "s" in hyperlink @leecalcote (#10737)
  - Fix the docs to import designs in meshery @11happy (#10676)
  - [Chore] Update copyright holder in project license
    @leecalcote (#10729)
  - Reduced font size to 0.9rem in  @abhishekmmgn (#10722)
* Sat Apr 13 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.46:
  * General
  - [Cleanup] Remove unnecessary files added by publish workflow
    @Yashsharma1911 (#10684)
  - bump meshkit to v0.7.21 @MUzairS15 (#10682)
  * Meshery CLI
  - [Bug][Server] Fix nil pointer error when importing Helm chart
    @Yashsharma1911 (#10707)
  - remove extra strings from integration docs body @vishalvivekm
    (#10698)
  - [CI][CLI] Include Cloud as a Target in the Publish Workflow
    @Yashsharma1911 (#10683)
  - [mesheryctl] Fix publish command failure @MUzairS15 (#10681)
  * Meshery UI
  - MeshModelComponent.js Component search fixed @Aryakoste
    (#10686)
  - Make tabs scrollable for mobile screens @sudhanshutech
    (#10689)
  - fix improper passing and usage of props @MUzairS15 (#10674)
  - [Bug][Server] Fix nil pointer error when importing Helm chart
    @Yashsharma1911 (#10707)
  - fix : Local Provider: Designs fail to load @Adarsh-jaiss
    (#10692)
  - [CI][CLI] Include Cloud as a Target in the Publish Workflow
    @Yashsharma1911 (#10683)
  * Maintenance
  - Update cleanup script to check for "Terminating" namespaces
    and patch finalizers field @cpepper96 (#10680)
  - Fix cloud path in integration workflow @Yashsharma1911
    (#10696)
  - [CI][CLI] Include Cloud as a Target in the Publish Workflow
    @Yashsharma1911 (#10683)
  * Documentation
  - Update to contributing-docs for issue #9976 @sangramrath
    (#10533)
  - update css for mobile view @vishalvivekm (#10706)
  - Update Relationship documentation. @RipulHandoo (#10690)
  - Revert "Create enhanced.html" @vishalvivekm (#10697)
  - update integrations pages to use integration layout
    @vishalvivekm (#10695)
  - Create enhanced.html @vishalvivekm (#10688)
* Sat Apr  6 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.45:
  * Meshery CLI
  - feat: Relationship cmd @RipulHandoo (#10640)
* Fri Apr  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.44:
  * General
  - Revert "upgrade alpine from 3.15.3 to 3.18.5 to solve
    vulnerabilities " @MUzairS15 (#10673)
* Fri Apr  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.43:
  * General
  - Add missing space causing bash issue @lekaf974 (#10666)
  * Meshery UI
  - Convert MesheryChart and MesheryChartDialog to functional
    component. @Aseem22 (#10358)
  * Security
  - upgrade alpine from 3.15.3 to 3.18.5 to solve vulnerabilities
    @deepak4566 (#10624)
* Wed Apr  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.42:
  * General
  - edge annotation arrow head color @aabidsofi19 (#10667)
  - Fix Edge Annotation Relation @aabidsofi19 (#10665)
  * Meshery CLI
  - feat: generate relationship docs @RipulHandoo (#10670)
  * Meshery UI
  - Bump eslint from 8.52.0 to 8.57.0 in /ui @dependabot (#10654)
  - upgrade tar from 6.1.15 to 6.2.1 @deepak4566 (#10647)
  - Bump @babel/traverse from 7.23.9 to 7.24.1 in /ui @dependabot
    (#10656)
  - Bump cypress from 13.6.4 to 13.7.1 in /provider-ui
    @dependabot (#10659)
  - chore: replace dashboard popup image @dragon-slayer875
    (#10668)
  - fix: dashboard charts @aabidsofi19 (#10669)
  * Maintenance
  - Bump eslint from 8.52.0 to 8.57.0 in /ui @dependabot (#10654)
  - Bump fortio.org/fortio from 1.63.2 to 1.63.5 @dependabot
    (#10653)
  - Bump github.com/gosimple/slug from 1.13.1 to 1.14.0
    @dependabot (#10651)
  - Bump @babel/traverse from 7.23.9 to 7.24.1 in /ui @dependabot
    (#10656)
  - Bump cypress from 13.6.4 to 13.7.1 in /provider-ui
    @dependabot (#10659)
  * Documentation
  - Remove meshery-perf references @lekaf974 (#10644)
  - feat: generate relationship docs @RipulHandoo (#10670)
  * Security
  - upgrade tar from 6.1.15 to 6.2.1 @deepak4566 (#10647)
* Wed Apr  3 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.41:
  * General
  - update parent child rels @aabidsofi19 (#10649)
  * Meshery UI
  - Bump postcss from 8.4.31 to 8.4.38 in /ui @dependabot
    (#10657)
  - Bump @mui/icons-material from 5.14.19 to 5.15.14 in
    /provider-ui @dependabot (#10660)
  - Bump eslint-config-next from 14.1.3 to 14.1.4 in /provider-ui
    @dependabot (#10661)
  * Maintenance
  - Bump gorm.io/gorm from 1.25.5 to 1.25.9 @dependabot (#10655)
  - Bump postcss from 8.4.31 to 8.4.38 in /ui @dependabot
    (#10657)
  - Bump @mui/icons-material from 5.14.19 to 5.15.14 in
    /provider-ui @dependabot (#10660)
  - Bump eslint-config-next from 14.1.3 to 14.1.4 in /provider-ui
    @dependabot (#10661)
  * Documentation
  - hide radio buttons on api-ref @vishalvivekm (#10664)
  - fix docs search field @vishalvivekm (#10650)
* Sat Mar 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.40:
  * General
  - Relationship between AWS FieldExport and k8s resources.
    @RipulHandoo (#10535)
  - Add meshery-nighthawk helm chart @lekaf974 (#10581)
  * Meshery CLI
  - feat: Mesheryctl Connections command @RipulHandoo (#10516)
  * Meshery UI
  - Improve some UI elements in dashboard @sudhanshutech (#10628)
  - UI Extension: GitHub Action - Performance Analysis
    @leecalcote (#10625)
  - [RTK] Migrate User component to rtk @dottharun (#10270)
  - fix(MesheryPatterns): update designs data when updating
    information through info modal @dragon-slayer875 (#10620)
  * Documentation
  - feat(docs): add error code name to search link (#10635)
    @elasticspoon (#10638)
  - [DOCS] replace backticks with bold formatting @iArchitSharma
    (#10633)
  - [Docs]: Updating Docs for Contributing to Model Relationships
    @pandeyshubham03 (#10627)
  - Suggested Reading added in default Layout @iArchitSharma
    (#10611)
* Sat Mar 30 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.39:
  * Meshery UI
  - Revert "Bump react-dom from 17.0.2 to 18.2.0 in /ui"
    @Yashsharma1911 (#10622)
* Tue Mar 26 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.38:
  * General
  - Bump express from 4.17.3 to 4.19.2 in
    /install/docker-extension/ui @dependabot (#10618)
  - feat: Relationship between Workspace and other
    aws-prometheusservice-controller components @RipulHandoo
    (#10493)
  - Downgrade to MeshKit v0.7.19 @leecalcote (#10614)
  - Update pattern API to support visibility change
    @Yashsharma1911 (#10612)
  - fix edge annotation relationship @MUzairS15 (#10609)
  - Create hierarchical_parent.json @MUzairS15 (#10607)
  - Create edge_annotation.json @MUzairS15 (#10608)
  * Meshery CLI
  - consolidate mesheryctl app into pattern @RipulHandoo (#10590)
  * Meshery UI
  - Bump express from 4.18.2 to 4.19.2 in /ui @dependabot
    (#10617)
  - Bump react-dom from 17.0.2 to 18.2.0 in /ui @dependabot
    (#10466)
  * Maintenance
  - Bump express from 4.18.2 to 4.19.2 in /ui @dependabot
    (#10617)
  - Bump github.com/gorilla/websocket from 1.5.0 to 1.5.1
    @dependabot (#10471)
  - Bump react-dom from 17.0.2 to 18.2.0 in /ui @dependabot
    (#10466)
  - Upgrade GitHub Action dorny/paths-filter@v3 @leecalcote
    (#10613)
  - Upgrade to MeshKit v0.7.20 @leecalcote (#10606)
  * Documentation
  - consolidate mesheryctl app into pattern @RipulHandoo (#10590)
  - Upgrade GitHub Action dorny/paths-filter@v3 @leecalcote
    (#10613)
  - Consolidate Tasks with Guides @leecalcote (#10610)
* Sun Mar 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.37:
  * Documentation
  - selectors snipeet backing relationships @RipulHandoo (#10596)
* Sun Mar 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.36:
  * General
  - Bump webpack-dev-middleware from 5.3.1 to 5.3.4 in
    /install/docker-extension/ui @dependabot (#10600)
  - Remove comment schema from Meshery definitions @leecalcote
    (#10604)
  - [Add]: Relationship between KubeArmorPolicy and Kubernetes
    Components @pandeyshubham03 (#10534)
  * Meshery UI
  - Upgrade to Sistent v0.14.18 @leecalcote (#10605)
  - fix cancel search button @Aseem22 (#10528)
  * Documentation
  - [Docs] Commands visibility fix @ritiksaxena124 (#10601)
  - Update patterns.md @leecalcote (#10587)
  - [Docs]: Add a new contrib docs page for Model Relationships
    @pandeyshubham03 (#10540)
  - [Fix Docs] Improve code formatting for ALL code blocks
    @sandramsc (#10598)
* Wed Mar 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.35:
  * General
  - Remove 0.7.1 directory for core models @Yashsharma1911
    (#10589)
* Tue Mar 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.34:
  * General
  - fix model registration getting blocked due to error
    @MUzairS15 (#10584)
  * Meshery CLI
  - Feat: Update model generator @Yashsharma1911 (#10576)
* Mon Mar 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.33:
  * General
  - feat: relationship between Limit-range and other components
    @RipulHandoo (#10070)
  - Bump follow-redirects from 1.15.4 to 1.15.6 in
    /install/docker-extension/ui @dependabot (#10571)
  - [Add]: Relationship between KubeArmorHostPolicy and k8s
    components @pandeyshubham03 (#10553)
  * Features
  - Move all components to sistent single package @sudhanshutech
    (#10548)
  * Meshery CLI
  - Fix exp components cmd bugs @alphaX86 (#10337)
  * Meshery UI
  - Move all components to sistent single package @sudhanshutech
    (#10548)
  - Bump follow-redirects from 1.15.4 to 1.15.6 in /ui
    @dependabot (#10572)
  - Bump follow-redirects from 1.15.4 to 1.15.6 in /provider-ui
    @dependabot (#10570)
  - Simplify the Environment assign in connections table
    @sudhanshutech (#10552)
  * Maintenance
  - Bump github.com/99designs/gqlgen from 0.17.42 to 0.17.45
    @dependabot (#10573)
  - Bump follow-redirects from 1.15.4 to 1.15.6 in /ui
    @dependabot (#10572)
  - Bump follow-redirects from 1.15.4 to 1.15.6 in /provider-ui
    @dependabot (#10570)
  - [chore] fix integrations updater workflow @MUzairS15 (#10547)
  - Bump google.golang.org/protobuf from 1.31.0 to 1.33.0
    @dependabot (#10561)
  - Bump github.com/jackc/pgx/v5 from 5.4.3 to 5.5.4 @dependabot
    (#10568)
  * Documentation
  - solves hover effect issue in dark mode @ayush844 (#10402)
  - Update jekyll docker image to 4.0 in Makefile @sangramrath
    (#10545)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.32:
  * General
  - fix parent child relation with section @codeKraken19 (#10566)
  - delete core comps generated due to incorrect source url
    @MUzairS15 (#10550)
  - skip schema validation if schema is empty and comp is an
    annotation @MUzairS15 (#10549)
  * Meshery UI
  - [Fix]: Connections page env assignment bugs @codeKraken19
    (#10551)
  * Documentation
  - Rearrange Logging Section @yash37158 (#10554)
  - [Docs] Relationships page update @ritiksaxena124 (#10524)
  - Add kubernetes pods tutorial using playground @sangramrath
    (#10456)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.31:
  * General
  - bump meshkit to v0.7.18 @MUzairS15 (#10532)
  * Meshery UI
  - bump sistent @captain-Akshay (#10529)
  - Bump eslint-config-next from 14.1.0 to 14.1.3 in /provider-ui
    @dependabot (#10527)
  * Maintenance
  - Bump eslint-config-next from 14.1.0 to 14.1.3 in /provider-ui
    @dependabot (#10527)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.30:
  * General
  - feat: Relationship between Volume attachment and
    PersistentVolume @RipulHandoo (#10481)
  - Delete unused file: custom.hbs @leecalcote (#10475)
  - Delete unused redocly.yaml file from repo root @leecalcote
    (#10476)
  - Update README.md @leecalcote (#10519)
  - add make target for using remote provider in staging
    environment @MUzairS15 (#10521)
  - [Server] Regenerate error codes for meshery server @MUzairS15
    (#10520)
  * Meshery CLI
  - [mesheryctl] Fix Registry usage error message link @tico88612
    (#10522)
  - Fixing the test failure @Althaf66 (#10484)
  * Meshery UI
  - Bump eslint-plugin-prettier from 5.0.0 to 5.1.3 in /ui
    @dependabot (#10467)
  - Bump @cypress/code-coverage from 3.12.19 to 3.12.26 in
    /provider-ui @dependabot (#10462)
  - Bump @mui/icons-material from 5.11.16 to 5.15.11 in /ui
    @dependabot (#10468)
  - Bump @mui/material from 5.15.7 to 5.15.11 in /provider-ui
    @dependabot (#10459)
  - [chore] Flatten the metadata and update UI. @MUzairS15
    (#10525)
  * Maintenance
  - Bump eslint-plugin-prettier from 5.0.0 to 5.1.3 in /ui
    @dependabot (#10467)
  - Bump @cypress/code-coverage from 3.12.19 to 3.12.26 in
    /provider-ui @dependabot (#10462)
  - Bump @mui/icons-material from 5.11.16 to 5.15.11 in /ui
    @dependabot (#10468)
  - Bump @mui/material from 5.15.7 to 5.15.11 in /provider-ui
    @dependabot (#10459)
  - [Models]: Updating Issue Template @pandeyshubham03 (#10523)
  * Documentation
  - [Docs] Meshery Docs Contributing summarization @leecalcote
    (#10500)
  - add id for error codes @vishalvivekm (#10526)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.29:
  * General
  - [Add]: Relationship between Kubernetes Components
    @pandeyshubham03 (#10482)
  - [Server] Fix intermodel relationship registration and eval.
    @MUzairS15 (#10517)
  - Update Makefile @MUzairS15 (#10511)
  * Meshery CLI
  - Update reference table in docs @alphaX86 (#10518)
  - [Docs] Mesheryctl Docs Update fixes #10503 @westcalcote
    (#10505)
  * Meshery UI
  - Fix layout and theme in layout @sudhanshutech (#10515)
  * Documentation
  - Update reference table in docs @alphaX86 (#10518)
  - Update index.md @vishalvivekm (#10508)
  - [Docs] Mesheryctl Docs Update fixes #10503 @westcalcote
    (#10505)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.28 (0.7.27 does not exist):
  * General
  - [Server] Fix manifests separated using yaml-separator being
    not parsed correctly @MUzairS15 (#10497)
  * Meshery CLI
  - [mesheryctl] Fix redirection to error page when performing
    auth @MUzairS15 (#10499)
  - assign model shape to generated comps @MUzairS15 (#10496)
  - [mesheryctl] Update model generator. @MUzairS15 (#10487)
  * Meshery UI
  - Show relationship description in models tab @Yashsharma1911
    (#10491)
  - [chore] fix UI lint issues. @MUzairS15 (#10492)
  - [chore] Bump meshkit to v0.7.16 @MUzairS15 (#10489)
  - Inject Sistent Into remote components @codeKraken19 (#10480)
  - Bump eslint from 8.55.0 to 8.57.0 in /provider-ui @dependabot
    (#10463)
  * Maintenance
  - Bump github.com/fatih/color from 1.15.0 to 1.16.0 @dependabot
    (#10473)
  - Create Bill of Materials and Licenses @jameshorton2337
    (#10477)
  - Bump eslint from 8.55.0 to 8.57.0 in /provider-ui @dependabot
    (#10463)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.26:
  * General
  - [GraphQL Plugin] Extract plugin related logic @MUzairS15
    (#10441)
  - Revert "store token and session on domain instead of
    subdomain" @MUzairS15 (#10448)
  - Docs :- information regarding a new command. @surajvast1
    (#10407)
  - [Add]: Relationship between PriorityClass and other k8s
    components @pandeyshubham03 (#10376)
  - fix incorrect design save events @MUzairS15 (#10424)
  * Meshery CLI
  - [Chore] Code base cleanup of "service mesh" @leecalcote
    (#10429)
  - append comps at end to ensure core model sourceuri stays the
    same @MUzairS15 (#10447)
  * Meshery UI
  - [Server] Eliminate dead code and Improvements for
    controllers/dataHandlers. @MUzairS15 (#10389)
  - Migrate registration stepper api to rtk @sudhanshutech
    (#10451)
  - Add empty state for no result found in Registry
    @Yashsharma1911 (#10443)
  - Inject structured data formatter in Remote Extension
    @codeKraken19 (#10439)
  - Support ignoring models in Registry @Yashsharma1911 (#10171)
  * Documentation
  - [Chore] Code base cleanup of "service mesh" @leecalcote
    (#10429)
  - Bump rails from 7.0.5 to 7.0.8.1 in /docs @dependabot
    (#10428)
  - Vishalvivekm patch 1 @vishalvivekm (#10425)
  - Tutorials layout @vishalvivekm (#9868)
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.25:
  * No changes
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.24:
  * General
  - store token and session on domain instead of subdomain
    @MUzairS15 (#10419)
  - [Add]: Relationship between StorageClass and other k8s
    components @pandeyshubham03 (#10357)
  - [Add]: Relationship between Job and other k8s resources
    @pandeyshubham03 (#10380)
  - [Docker] Fix failing docker build @MUzairS15 (#10397)
  - Ripul handoo/relationship/pod distribution budget
    @RipulHandoo (#10273)
  - add: Relationship for IngressClass and other k8s resources
    @RipulHandoo (#10355)
  - add: Relationship between Controller revision and other k8s
    resources @RipulHandoo (#10299)
  - Updated the version in meshery-nsm-deployment.yaml
    @anirudh-hegde (#10388)
  * Meshery CLI
  - regenerate error codes for mesheryctl @MUzairS15 (#10405)
  - fix: failing golint-ci test for mesheryctl @RipulHandoo
    (#10384)
  * Meshery UI
  - [bug] Fix patterns filtering @sudhanshutech (#10363)
  - Update theme @aabidsofi19 (#10409)
  - Complete Rtk migration for Connections @sudhanshutech
    (#10362)
  - [Adapter] Add support for Nighthawk @leecalcote (#10361)
  - [UI] Enhance title and description of Environments #10364
    @izuca (#10395)
  * Bug Fixes
  - [bug] Fix patterns filtering @sudhanshutech (#10363)
  * Maintenance
  - add: defined relationship link @RipulHandoo (#10401)
  - [chore] update golangci-lint action to v4 @MUzairS15 (#10400)
  - [Adapter] Add support for Nighthawk @leecalcote (#10361)
  * Documentation
  - Bugs Fix @iArchitSharma (#10411)
  - chore: remove anchor tags from frontmatter variable abstract
    @dextrot (#10403)
  - [Adapter] Add support for Nighthawk @leecalcote (#10361)
  - [Docs] Enhance Build and Release page with link to test plan
    @leecalcote (#10383)
  - Update Dockerfile @MUzairS15 (#10390)
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.23:
  * General
  - Bump ip from 1.1.5 to 1.1.9 in /install/docker-extension/ui
    @dependabot (#10368)
  * Meshery CLI
  - [mesheryctl] Add support to update spreadsheet during model
    generation. @MUzairS15 (#10378)
  - upadte svg string @MUzairS15 (#10379)
  - [chore] mesheryctl: rename registry import to registry
    generate @leecalcote (#10365)
  * Maintenance
  - workflow miss @captain-Akshay (#10374)
  - [chore] mesheryctl: rename registry import to registry
    generate @leecalcote (#10365)
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.22:
  * General
  - add: Add description for relationship @RipulHandoo (#10308)
  - updated kompose version @anirudh-hegde (#10354)
  - [Docs] Initialize logical concepts page for Registry
    @leecalcote (#10349)
  * Meshery CLI
  - Fix more SQL injections @gyohuangxin (#10280)
  * Meshery UI
  - fixed the export modal @captain-Akshay (#10342)
  - [Rtk] Migrate meshsync section to rtk @sudhanshutech (#10243)
  - [Server] Fix events API. @MUzairS15 (#10353)
  * Documentation
  - [Fix Docs] Improve code formatting @sandramsc (#9911)
  - [Docs] Updated FAQ for design invisibility issues in catalog
    @saurabh100ni (#9704)
  - Fixed one broken link issue #9957 @neerajmanivarnan (#9958)
  - #9935 changed the link from
    /guides/configuration-management/creating… @muthu9594 (#9938)
  - [Docs] fix: Compatibility Matrix test result for Components
    and typo's @singh1203 (#10338)
  - [Docs] Modify help text for Meshery Catalog @hamza-mohd
    (#10341)
  - [DOCS] Missing Abstract added in pages @iArchitSharma
    (#10336)
  - [Docs] Contributing: Models and Relationships @leecalcote
    (#10348)
  - suggested reading cache fix @iArchitSharma (#10328)
  - [Docs] Add abstract to the Extensions page @leecalcote
    (#10322)
  * Security
  - Fix more SQL injections @gyohuangxin (#10280)
* Tue Feb 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.21:
  * General
  - delete generator and updater scripts @MUzairS15 (#10326)
  - Bump helm.sh/helm/v3 from 3.13.2 to 3.14.1 in
    /scripts/component_updater @dependabot (#10315)
  - upgrade meshkit to v0.7.13 @MUzairS15 (#10317)
  - fix: rename meshery-flowcharts to meshery-flowchart in
    relation @aabidsofi19 (#10305)
  * Meshery UI
  - [Fix UI] Change menu text @sandramsc (#10325)
  * Maintenance
  - Fix server build error coming on boot @Yashsharma1911
    (#10276)
  - Create playground.md @leecalcote (#10309)
  * Documentation
  - docs: visualizations for logical relationships @leecalcote
    (#10323)
  - [Docs] Format
  - with HTML tag not markdown - Update contributing-models.md ()
  - chore: fix-cached-links @vishalvivekm (#10319)
  - Fix head caching issue @iArchitSharma (#10313)
* Fri Feb 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.20:
  * General
  - [Server] Design upload events. @MUzairS15 (#10306)
  * Meshery CLI
  - [chore] fix mesheryctl lint issue @MUzairS15 (#10307)
* Thu Feb 15 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.19:
  * General
  - [Server] Fix connection status getting overriden during
    import of K8s connection. @MUzairS15 (#10303)
  - Ripul handoo/relationships/pod template @RipulHandoo (#10271)
  - add: Relationship between Replication Controller and other
    k8s resources @RipulHandoo (#10274)
  - add: relationship between k8s lease and other k8s
    components[high-level] @RipulHandoo (#10244)
  - run component updater @MUzairS15 (#10286)
  - feat: Relationship between HPA and other k8s components.
    @RipulHandoo (#10126)
  - add: Relationship between csi-driver and other k8s resources
    @RipulHandoo (#10262)
  - feat: relationship between kubernetes secret and other
    resources @RipulHandoo (#9880)
  * Meshery CLI
  - fix conflicts @MUzairS15 (#10285)
  - Feature/exp components command @RipulHandoo (#9726)
  - [Meshmodel] Update Components @aabidsofi19 (#10277)
  * Meshery UI
  - [fix] remove xstate/inspect @aabidsofi19 (#10302)
  - fix hover of hyperlink @sudhanshutech (#10288)
  - [Meshmodel] Update Components @aabidsofi19 (#10277)
  - Fix the React Warnings in Meshery UI Build @MeenuyD (#10266)
  - Testing small change @sudhanshutech (#10265)
  * Maintenance
  - Bump github.com/onsi/ginkgo/v2 from 2.13.1 to 2.15.0
    @dependabot (#10148)
  * Documentation
  - [Docs] Relationships and Policies @MUzairS15 (#10253)
  - Fixed text color in swagger layout @iArchitSharma (#10279)
  - error table liquid fix @iArchitSharma (#10283)
  - Reference added to error table @iArchitSharma (#10281)
  - [Docs] Remove deprecated adapters from toc sidebar
    @leecalcote (#10257)
  - [Docs] Enhance enhanced layout with optional
    suggested-reading list @leecalcote (#10256)
  - Fix missing list @iArchitSharma (#10260)
* Sat Feb 10 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.18:
  no structured changelog, just a list of commits, see
  https://github.com/meshery/meshery/releases/tag/v0.7.18
* Thu Feb  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.17:
  * General
  - [Meshmodel] Update pod,replicaset,job,cronjob to have
    genealogy parent @aabidsofi19 (#10248)
  - updated pencil node @captain-Akshay (#10225)
  - add: Relationship between Event component and other k8s
    components @RipulHandoo (#10194)
  - change log severity to debug @MUzairS15 (#10221)
  * Meshery CLI
  - [bug] Fix pattern apply @theBeginner86 (#10142)
  - Fix golangci-lint issues in mesheryctl. @gyohuangxin (#10226)
  * Meshery UI
  - Fix icon color @sudhanshutech (#10245)
  - leecalcote/docs/connections delete modal @leecalcote (#10236)
  - [UI] Global Navigation Menu Tooltip Enhancement
    @ChetanPatil12 (#10219)
  - [Enhancement][UI] Reduced font size of Metadata Labels in
    small viewport @cesartheroman (#10222)
  - [Server] Enhance Design Import Notification @ASK-03 (#10223)
  - [UI] Registry UI issues @Yashsharma1911 (#10208)
  - Update existing queries and add rtk client for
    performance-profile api's @sudhanshutech (#10220)
  * Bug Fixes
  - [bug] Fix pattern apply @theBeginner86 (#10142)
  * Maintenance
  - update: issue_template for model @RipulHandoo (#10188)
  * Documentation
  - [Docs] Deleting Environments @leecalcote (#10237)
  - [Docs] Jekyll Build Cache @leecalcote (#10239)
  - suggested reading edit @mgurrie (#10213)
  - #10145 Added two suggeste d reading links to Docs
    Contributing page @suguslove10 (#10230)
  * Security
  - Fix SQL injection in /api/system/meshsync/resources
    @gyohuangxin (#10207)
* Wed Feb  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.16:
  * General
  - [Relationship] Support chaining of inventory items.
    @MUzairS15 (#10218)
  - [server] Server policy eval improvements. @MUzairS15 (#10216)
  - [Policies] Add support for building incomplete json paths
    @MUzairS15 (#10182)
  - [Connection] Add Connection definition for Github. @MUzairS15
    (#10186)
  - add pencil component @aabidsofi19 (#10169)
  * Meshery UI
  - Add rtk client for meshSync api's @sudhanshutech (#10217)
  - add info and replace tooltips @sudhanshutech (#10214)
  - [Typo] - Environments and workspaces @senali-d (#10211)
  - [Extension] Add Info Icon on Export Design Modal @AjaxAueleke
    (#10008)
  - Migrate dashboard to rtk and cleanups @sudhanshutech (#10122)
  * Maintenance
  - Bump github.com/docker/go-connections from 0.4.0 to 0.5.0
    @dependabot (#10150)
  - Bump fortio.org/fortio from 1.60.3 to 1.63.2 @dependabot
    (#10147)
  - Bump google.golang.org/api from 0.154.0 to 0.161.0 in
    /scripts/component_generation @dependabot (#10152)
  - Bump github.com/prometheus/client_golang from 1.17.0 to
    1.18.0 @dependabot (#10149)
  - Bump github.com/layer5io/meshkit from 0.7.2 to 0.7.11 in
    /scripts/component_generation @dependabot (#10154)
  * Documentation
  - [Feat Docs] Added Contributing to docs using Gitpod
    @MonalikaPatnaik (#10196)
  - docs: fix broken image on models contributing page
    @shravan562 (#10200)
* Mon Feb  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.15:
  * Meshery UI
  - Bump @babel/traverse from 7.23.6 to 7.23.9 in /ui @dependabot
    (#10159)
  - replace icon in header @sudhanshutech (#10168)
  - Start sourcing icons from Sistent (1st phase) @sudhanshutech
    (#10128)
  - Bump @cypress/code-coverage from 3.12.17 to 3.12.19 in
    /provider-ui @dependabot (#10160)
  - Bump @emotion/react from 11.10.8 to 11.11.3 in /ui
    @dependabot (#10155)
  - Bump eslint-config-prettier from 9.0.0 to 9.1.0 in /ui
    @dependabot (#10157)
  - Bump @mui/material from 5.15.2 to 5.15.7 in /provider-ui
    @dependabot (#10162)
  - Bump eslint-config-next from 14.0.4 to 14.1.0 in /provider-ui
    @dependabot (#10163)
  - Bump @babel/eslint-parser from 7.22.15 to 7.23.10 in
    /provider-ui @dependabot (#10161)
  - Bump cypress from 13.6.2 to 13.6.4 in /provider-ui
    @dependabot (#10164)
  * Maintenance
  - Bump @babel/traverse from 7.23.6 to 7.23.9 in /ui @dependabot
    (#10159)
  - Bump @cypress/code-coverage from 3.12.17 to 3.12.19 in
    /provider-ui @dependabot (#10160)
  - Bump @emotion/react from 11.10.8 to 11.11.3 in /ui
    @dependabot (#10155)
  - Bump eslint-config-prettier from 9.0.0 to 9.1.0 in /ui
    @dependabot (#10157)
  - Bump @mui/material from 5.15.2 to 5.15.7 in /provider-ui
    @dependabot (#10162)
  - Bump eslint-config-next from 14.0.4 to 14.1.0 in /provider-ui
    @dependabot (#10163)
  - Bump @babel/eslint-parser from 7.22.15 to 7.23.10 in
    /provider-ui @dependabot (#10161)
  - Bump cypress from 13.6.2 to 13.6.4 in /provider-ui
    @dependabot (#10164)
  * Documentation
  - fix: remove direct link to the source code @RipulHandoo
    (#10166)
* Mon Feb  5 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.14:
  * General
  - [chore] upgrade meshkit to v0.7.11 @MUzairS15 (#10144)
  - [relationships] update selectors to represent correct path
    @MUzairS15 (#10103)
  * Meshery CLI
  - [docs/mesheryctl] Fix annotations of exp command
    @theBeginner86 (#10113)
  - [docs] Fix mesheryctl exp @theBeginner86 (#10112)
  - [mesheryctl] Registry command init @theBeginner86 (#10053)
  * Meshery UI
  - [RTK] Settings - Reset database @senali-d (#10135)
  - [RTK] Environments and Workspaces @senali-d (#10131)
  - [chore] upgrade relay-compiler to 16.2.0 @MUzairS15 (#10127)
  - [Bug] Transfer list component @senali-d (#10124)
  - fix text case style in modal @sudhanshutech (#10123)
  - Alter icon @sudhanshutech (#10121)
  - Descriptive info inside tooltip @sudhanshutech (#10120)
  - Prevent lossing technology in infoModal @Yashsharma1911
    (#10098)
  - Fix casing for displayName in publish payload @Yashsharma1911
    (#10095)
  * Bug Fixes
  - [Bug] Transfer list component @senali-d (#10124)
  - [docs/mesheryctl] Fix annotations of exp command
    @theBeginner86 (#10113)
  * Maintenance
  - Bump github.com/opencontainers/runc from 1.1.9 to 1.1.12
    @dependabot (#10139)
  - Update meshmap.yml @MUzairS15 (#10136)
  - [CI] fixes E2E Test workflow. @singh1203 (#10114)
  - Update integrations-updater.yml @theBeginner86 (#10097)
  - Update integrations-updater.yml @theBeginner86 (#10096)
  * Documentation
  - [Docs] Components: remove source hyperlink @leecalcote
    (#10140)
  - Add: Managing Events with Notification Center abstract
    @RipulHandoo (#10134)
  - [Docs] Concepts: Logical policies @leecalcote (#10138)
  - Redirects @vishalvivekm (#10132)
  - readd-meshmodel-folder @vishalvivekm (#10129)
  - add-redirect @vishalvivekm (#10115)
  - [docs] Fix mesheryctl exp @theBeginner86 (#10112)
  - docs fix quick start copy to clipboard button @ranjeetxsingh
    (#10100)
  - [Docs] Relocate Contrib-Community location in TOC @leecalcote
    (#10093)
  - Feature/add selectors documentation @RipulHandoo (#10035)
  - [bug] Fix broken links for /concepts/ to /concept/logical/
    @theBeginner86 (#10101)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.13:
  * General
  - Add new entry for AYA Innovation Labs as adopter
    @Yashsharma1911 (#10092)
  * Meshery CLI
  - [chore] run gofmt on server. @MUzairS15 (#10084)
  - feat: responsive pagination for mesheryctl exp list cmd
    @RipulHandoo (#10069)
  - [bug/mesheryctl] Fix Import/Onboard @theBeginner86 (#10065)
  * Meshery UI
  - [UI] Update publish catalog request payload @Yashsharma1911
    (#10091)
  - [General] - Dark mode issue in transfer modal @senali-d
    (#10088)
  - add missing tooltip and refactor its styling @sudhanshutech
    (#10086)
  - Fix CASL typo from actions to action in performance page
    @Yashsharma1911 (#10087)
  - [Components] Improve default field descriptions @leecalcote
    (#10067)
  * Bug Fixes
  - [bug/mesheryctl] Fix Import/Onboard @theBeginner86 (#10065)
  * Maintenance
  - Revert "Update error-codes-updater.yaml" @MUzairS15 (#10090)
  - Update error-codes-updater.yaml @MUzairS15 (#10089)
  - add conditional to use token only on master branch for
    error-code-util @MUzairS15 (#10085)
  - use GitHub PAT for checkoing out repo @MUzairS15 (#10083)
  - Bump Screenshot Service version @theBeginner86 (#10081)
  - Update generate_keys.yml @MUzairS15 (#10064)
  - Update generate_keys.yml @MUzairS15 (#10063)
  - [CI] Enhance Keys workflow with published CSV @leecalcote
    (#10062)
  * Documentation
  - [Docs] Error Code Reference Layout @leecalcote (#10075)
  * Security
  - [CI] Enhance Keys workflow with published CSV @leecalcote
    (#10062)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.12:
  * General
  - added capabilities for edges @captain-Akshay (#10048)
  - update meshsync crd @MUzairS15 (#10057)
  - [Relationships] Add selectors sets in relationships.
    @MUzairS15 (#9987)
  - Update grafana_helper.go @eltociear (#9981)
  - [Server] Fix remote pattern upload @MUzairS15 (#10014)
  - [Server] Validate userid and handle remote provider responses
    on failure correctly. @MUzairS15 (#10015)
  - [bug] Fix Remote Design file upload @theBeginner86 (#10013)
  * Meshery UI
  - Fix developer warnings @JyothiSwaroopReddy07 (#10029)
  - Added new icons for Kubernetes components @nwanduka (#9866)
  - [WIP] Migrate registry page to use RTK @Yashsharma1911
    (#10007)
  - [NOTIFICATION] Added visual indication for notification
    center @captain-Akshay (#10030)
  - fix grammer issue in popup ui comopnents @amitamrutiya2210
    (#10028)
  - [UI] Refactor tooltip and its behaviour in dashboard cards
    @sudhanshutech (#10042)
  - [RTK] Connections api migrate to rtk @senali-d (#9992)
  - [UI] Fix publishing design @Yashsharma1911 (#9990)
  - [MeshModel Category] Database category icon added
    @ritiksaxena124 (#10006)
  * Maintenance
  - Update meshmap.yml @theBeginner86 (#10055)
  - [chore] Update meshmap.yml @MUzairS15 (#10054)
  - [Bug] Reinitialise models and keys registration on Database
    reset. @MUzairS15 (#10024)
  - [models] Consolidate Meshery Docs Generator @theBeginner86
    (#9941)
  * Documentation
  - broken link fixed w/signoff @prathyushmadhu (#9960)
  - #9935 changed the link from
    /guides/configuration-management/creating-a-meshrey-design to
    /guides/creating-a-meshrey-design @muthu9594 (#9982)
  - [Fixed Docs Cloud Native app Configuration] - Grammar
    adjustment @shourya2002-geek (#10012)
  - v0.4, v0.5, v0.6 added to excludes @iArchitSharma (#10051)
  - Fix developer warnings @JyothiSwaroopReddy07 (#10029)
  - [DOCS] Suggested Reading bug fix @iArchitSharma (#10020)
  - modified provider urls @JyothiSwaroopReddy07 (#10027)
  - [DOCS] MeshModel to Model fix @iArchitSharma (#10031)
  - [docs] fix "Managing Events with Notification Center" link
    not working properly @dottharun (#10044)
  - [Docs] Relationships: Grammar fix in the "Design
    Relationships and Restrictions" section @neerajmanivarnan
    (#10003)
  - [Docs Designs] Removed Repeated Phrase #9995 Fixed @ASK-03
    (#10001)
  - Added mesherycli cheatsheet @Dhanush0369 (#10022)
  - [docs] Fix YAML issue in Meshery Docs @theBeginner86 (#10021)
  - [models] Consolidate Meshery Docs Generator @theBeginner86
    (#9941)
  - Made grammatical changes for the paragraph under 'Importing
    Applications'. @ayushgml (#10018)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.11:
  * General
  - Generic Annotation Node @aabidsofi19 (#9974)
  - [chore] fix unwanted warning on save @theBeginner86 (#9977)
  - update: update Maintainer.md @RipulHandoo (#9972)
  - [chore] Fix Failing MeshKit Error Util @theBeginner86 (#9962)
  - [Docs] New make target for non-incremental serving of site
    @leecalcote (#9945)
  - [Permission] Update permission spreadsheet @Yashsharma1911
    (#9948)
  - [bug] Fix Error Message on K8s Manifest Upload @theBeginner86
    (#9940)
  - [Relationships] AWS RDS DBCluster to IAM Role @leecalcote
    (#9666)
  - [chore] fix models @theBeginner86 (#9921)
  * Meshery UI
  - Fix naming convention @sudhanshutech (#9993)
  - Fix horizontal line alignment in registry tree view
    @Yashsharma1911 (#9989)
  - fixed the dropdown icon bug across modals @captain-Akshay
    (#9983)
  - [UI] Enhance the Meshery UI registry @Yashsharma1911 (#9939)
  - fix controller version logic @MUzairS15 (#9975)
  - [Env/Workspace] - Remove org selector from create environment
    and workspace modal @senali-d (#9961)
  - Feat: Import/Export Design as OCI Artifact @theBeginner86
    (#9861)
  - [UI] Filter support for Designs and Filters @sudhanshutech
    (#9918)
  - Fix Id formatter and empty data UX @sudhanshutech (#9933)
  - solved icons cutoff issue @Aniket-76 (#9907)
  - [UI] Fix dark mode issues in error component @Yashsharma1911
    (#9924)
  - [UI] Fix dysfunctional Metrics tab. @MUzairS15 (#9915)
  * Maintenance
  - [docs] Enhance Component Docs Updater Script @theBeginner86
    (#9934)
  * Documentation
  - [DOCS] Fixed broken links @MonalikaPatnaik (#9988)
  - [Docs] Add GitHub link to main navigation menu @leecalcote
    (#9970)
  - [Docs] Chore: Additional 404 error messages @leecalcote
    (#9956)
  - [Docs] Redirects for Adapters @leecalcote (#9955)
  - fixed broken link issue in configuration-management.md
    @prathyushmadhu (#9954)
  - [Docs] Revise integrations on homepage @leecalcote (#9946)
  - fix: meshery.io integrations link @leecalcote (#9944)
  - Feat: Import/Export Design as OCI Artifact @theBeginner86
    (#9861)
  - solved issue #9913 @AkashMeheta (#9927)
  - [Docs] Enhanced Integrations list @leecalcote (#9937)
  - [Docs] Add menu toggle. Collapsed by default @leecalcote
    (#9902)
  - [Doc] Extensibility CASL @Yashsharma1911 (#9898)
  - Fixed many links including the issue #9892 @Conqxeror (#9923)
  - Update deploying-sample-apps.md @chiragbiradar (#9930)
  - [Docs] Categorization and partial restructure @leecalcote
    (#9920)
  - [Docs] feat: add google tag manager @leecalcote (#9912)
  - [Docs] Restructure proposal @leecalcote (#9887)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.10:
  * General
  - chore(deps): Bump follow-redirects from 1.15.3 to 1.15.4 in
    /install/docker-extension/ui @dependabot (#9909)
  * Meshery UI
  - [Bug] - Fix workspace and environment required field
    validation @senali-d (#9917)
  - chore(deps): Bump follow-redirects from 1.15.2 to 1.15.4 in
    /ui @dependabot (#9903)
  - [UI] Fix CASL issues @Yashsharma1911 (#9904)
  - chore(deps): Bump follow-redirects from 1.15.2 to 1.15.4 in
    /provider-ui @dependabot (#9905)
  - [Enhancement] - Workspace and environments @senali-d (#9890)
  - fix tooltip styling @sudhanshutech (#9906)
  - resolved label cutoff issue @Aniket-76 (#9900)
  - [fix] Some ui fixes in env and workspaces @sudhanshutech
    (#9896)
  * Maintenance
  - chore(deps): Bump follow-redirects from 1.15.2 to 1.15.4 in
    /ui @dependabot (#9903)
  - chore(deps): Bump follow-redirects from 1.15.2 to 1.15.4 in
    /provider-ui @dependabot (#9905)
  * Documentation
  - [Docs] Sitemap with URLs @leecalcote (#9908)
  - feat: build a provider @leecalcote (#9889)
  - [Docs] New Suggested Reading layout @leecalcote (#9891)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.9:
  * General
  - fix: broken 'Security' category @leecalcote (#9884)
  - Remove schemas from meshery/meshery. @MUzairS15 (#9876)
  - [Models] Update connection transitions and middleware.
    @MUzairS15 (#9881)
  * Meshery UI
  - Reuse tooltip @sudhanshutech (#9885)
  - Bump @rjsf/utils from 5.8.1 to 5.15.1 in /ui @dependabot
    (#9803)
  * Maintenance
  - Bump @rjsf/utils from 5.8.1 to 5.15.1 in /ui @dependabot
    (#9803)
  - chore(deps): Bump github.com/cloudflare/circl from 1.3.3 to
    1.3.7 @dependabot (#9878)
  * Documentation
  - docs: rearrange extensions @leecalcote (#9883)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.8:
  * General
  - [LocalProvider] Cleanup keys when server is shutdown.
    @MUzairS15 (#9879)
  - [Models] Rename relationships.reqo_query to
    relationships.evaluationQuery. @MUzairS15 (#9875)
  - [Server] Auto Register for Connections @MUzairS15 (#9785)
  - [Models] Add support to update component capabilities.
    @MUzairS15 (#9848)
  - [Docker Extension] chore: update ui deps @leecalcote (#9841)
  * Meshery CLI
  - chore: remove mesheryctl unit test assertions @leecalcote
    (#9853)
  * Meshery UI
  - [UI] Fix connection page crash @Yashsharma1911 (#9871)
  - Enhance dashboard ui elements @sudhanshutech (#9872)
  - [bug] fix null check for environment @sudhanshutech (#9860)
  - [FIX] Sorting in designs and filters and fix some UI issues
    @sudhanshutech (#9859)
  - [WIP] Enforced CASL in UI @Yashsharma1911 (#9778)
  - [FIX] Routing error in workspace @sudhanshutech (#9852)
  * Bug Fixes
  - [bug] fix null check for environment @sudhanshutech (#9860)
  * Documentation
  - fix: fixed broken link @ameeetgaikwad (#9874)
  - Docs: Relocate Adapters Under Extensibility @leecalcote
    (#9855)
  - docs: refresh overview and structure @leecalcote (#9854)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.7:
  * General
  - chore(deps): Bump github.com/containerd/containerd from 1.7.6
    to 1.7.11 in /scripts/component_updater @dependabot (#9682)
  - [relationships] Fix incorrect query in hierarchical_config
    relationship definition. @MUzairS15 (#9837)
  - [Models] Relationships for Kubernetes ConfigMap using
    Environment Variables @leecalcote (#9816)
  * Meshery CLI
  - Fix experimental model command in mesheryctl @LakshyaSatpal
    (#9813)
  - add reference link in mesheryctl @Althaf66 (#9707)
  - fix the grammatical issue #9810 @Althaf66 (#9811)
  * Meshery UI
  - Add Postgres Database Icon @Akshun-01 (#9674)
  - Added icons for Kubernetes Node Metrics component @nwanduka
    (#9760)
  - Fix connection page issues @sudhanshutech (#9838)
  - Fix Environment options update and undefined bug in
    connections @sudhanshutech (#9831)
  - [UI] Add info icon to prompt component @Yashsharma1911
    (#9826)
  - Bump @cypress/code-coverage from 3.12.7 to 3.12.17 in
    /provider-ui @dependabot (#9814)
  - Bump @mui/material from 5.14.19 to 5.15.2 in /provider-ui
    @dependabot (#9792)
  - Prevent common modal from rerender @Yashsharma1911 (#9822)
  * Bug Fixes
  - Fix Environment options update and undefined bug in
    connections @sudhanshutech (#9831)
  * Maintenance
  - [chore] Bump MeshMap Snapshot @theBeginner86 (#9836)
  - [Server] Seed keys for local provider @Yashsharma1911 (#9771)
  - Bump @cypress/code-coverage from 3.12.7 to 3.12.17 in
    /provider-ui @dependabot (#9814)
  - Bump @mui/material from 5.14.19 to 5.15.2 in /provider-ui
    @dependabot (#9792)
  - Bump github.com/onsi/gomega from 1.27.10 to 1.30.0
    @dependabot (#9799)
  - Bump github.com/spf13/cobra from 1.7.0 to 1.8.0 @dependabot
    (#9798)
  - [Chore] GH Issue Template: Update and rename meshmodel.md to
    models.md @leecalcote (#9820)
  * Documentation
  - Fixed mobile search results @Savio629 (#9613)
  - Adding consistent font-weight for list-structure @yash37158
    (#9759)
  - fix v0.6 navbar dropdown and details marker in v0.6 meshery
    docs @Aniket-76 (#9835)
  - add reference link in mesheryctl @Althaf66 (#9707)
  - [Docs] Update docs for configuring logs at runtime.
    @MUzairS15 (#9827)
  - docs: logical concepts update @leecalcote (#9808)
  - [Docs] Relationships: Missing color for info/tip/note Alerts
    + Models: Missing color @brandonkylely (#9823)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.6:
  * General
  - [Server] Handle connection update events impacting
    performance. @MUzairS15 (#9786)
  - [bug] Fix Relationships Registration Process @theBeginner86
    (#9783)
  - [server] Revert unneeded changes @MUzairS15 (#9784)
  - [Server] Organise packages and use of mutexes. @MUzairS15
    (#9779)
  - [ci] Fix MeshKit Error Utility @theBeginner86 (#9777)
  - [bug] Fix application type @theBeginner86 (#9765)
  - [Docs] Fix integration docs updater @MUzairS15 (#9756)
  * Meshery CLI
  - [Server] Add support to change log levels at runtime
    @MUzairS15 (#9815)
  - [mesheryctl] Fix mesheryctl app + unit tests @theBeginner86
    (#9776)
  - Fix app import failure. @shanukun (#9738)
  * Meshery UI
  - [Popup.js] fixed popup zindex and spacing issue
    @prabhjeevnijjar (#9767)
  - Bump @emotion/react from 11.11.1 to 11.11.3 in /provider-ui
    @dependabot (#9793)
  - Bump eslint-config-next from 14.0.3 to 14.0.4 in /provider-ui
    @dependabot (#9791)
  - Bump cypress from 13.6.1 to 13.6.2 in /provider-ui
    @dependabot (#9795)
  - Bump @cypress/code-coverage from 3.12.5 to 3.12.16 in /ui
    @dependabot (#9796)
  - Bump @mui/styles from 5.14.3 to 5.15.2 in /ui @dependabot
    (#9805)
  - Bump uuid from 9.0.0 to 9.0.1 in /ui @dependabot (#9802)
  - Bump graphql-ws from 5.11.2 to 5.14.3 in /ui @dependabot
    (#9804)
  - [UI] fix: Update style for cursor @OmAximani0 (#9788)
  - [Environments/Workspaces] - Scroll loading support for
    transfer list modal @senali-d (#9806)
  - Fix issue in registry @sudhanshutech (#9774)
  - [Workspaces] - Workspaces page @senali-d (#9722)
  - Fix technology not showing in info modal @Yashsharma1911
    (#9763)
  - [UI] - Environment card button arrow position @senali-d
    (#9768)
  - [FIX] k8s icon and connection transition naming @aabidsofi19
    (#9764)
  - fix row expansion on selecting env @sudhanshutech (#9762)
  - [UI] Filter support for Meshsync and Connections
    @sudhanshutech (#9717)
  * Maintenance
  - chore(deps): Bump github.com/containerd/containerd from 1.7.6
    to 1.7.11 in /scripts/component_generation @dependabot
    (#9681)
  - Bump github.com/layer5io/meshkit from 0.7.0 to 0.7.2 in
    /scripts/component_generation @dependabot (#9790)
  - Bump @emotion/react from 11.11.1 to 11.11.3 in /provider-ui
    @dependabot (#9793)
  - Bump eslint-config-next from 14.0.3 to 14.0.4 in /provider-ui
    @dependabot (#9791)
  - Bump cypress from 13.6.1 to 13.6.2 in /provider-ui
    @dependabot (#9795)
  - Bump @cypress/code-coverage from 3.12.5 to 3.12.16 in /ui
    @dependabot (#9796)
  - Bump @mui/styles from 5.14.3 to 5.15.2 in /ui @dependabot
    (#9805)
  - Bump github.com/99designs/gqlgen from 0.17.39 to 0.17.42
    @dependabot (#9800)
  - Bump uuid from 9.0.0 to 9.0.1 in /ui @dependabot (#9802)
  - Bump google.golang.org/api from 0.152.0 to 0.154.0 in
    /scripts/component_generation @dependabot (#9789)
  - Bump github.com/go-openapi/runtime from 0.26.0 to 0.26.2
    @dependabot (#9797)
  - Bump github.com/jinzhu/copier from 0.3.5 to 0.4.0 @dependabot
    (#9801)
  - Bump graphql-ws from 5.11.2 to 5.14.3 in /ui @dependabot
    (#9804)
  - [mesheryctl] Fix mesheryctl app + unit tests @theBeginner86
    (#9776)
  - fix-command-to-get-latest-Meshery-release-tag @vishalvivekm
    (#9761)
  - Bump github.com/layer5io/service-mesh-performance from 0.3.4
    to 0.6.1 @dependabot (#9533)
  * Documentation
  - docs: Fix ruby version in contributing-docs page
    @LakshyaSatpal (#9812)
  - docs: pattern init @leecalcote (#9809)
  - [API/Docs] Support for returning unassigned entities
    @theBeginner86 (#9780)
  - fixed details-marker @Aniket-76 (#9770)
  - [Docs] Fix integrations docs page. @MUzairS15 (#9757)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.5:
  * General
  - [HELM] Fix Ingress Resource of Meshery @theBeginner86 (#9755)
  - preload kubernetes_resource_object_meta @MUzairS15 (#9753)
  * Meshery UI
  - [Connection Register] - Register MeshSync data as a
    connection @senali-d (#9548)
  * Bug Fixes
  - [bug] Fix Searching + Preloading Issue @theBeginner86 (#9754)
  * Documentation
  - [Docs] enhance: Customizing Meshery's Installation with
    values.yaml @leecalcote (#9747)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.4:
  * General
  - chore: version: 0.7.0 @leecalcote (#9748)
  - [bug] Fix searching in MeshSync resources @theBeginner86
    (#9737)
  - [Server] Added filters in connections API @Yashsharma1911
    (#9729)
  - Fix nil pointer errors and updated the keys new URL path
    @Yashsharma1911 (#9731)
  - [typo] Update sibling_matchlabels.rego @theBeginner86 (#9734)
  - chore(deps): Bump golang.org/x/crypto from 0.14.0 to 0.17.0
    in /scripts/component_updater @dependabot (#9669)
  - [server][chore]: drop dead code @VihasMakwana (#9609)
  - [MeshSync API]add API to delete resources by ID @MUzairS15
    (#9728)
  - update schemas and structs @MUzairS15 (#9723)
  - fix meshkit error utiltiy @MUzairS15 (#9724)
  - [Server] Handle database conflicts when persisting MeshSync
    data. @MUzairS15 (#9718)
  - [bug/rego] Fixes Tag Set Relationship Evaluation
    @theBeginner86 (#9714)
  - [Relationships] Add Environment Hierarchical Parent
    Relationship @theBeginner86 (#9677)
  * Features
  - Add Routing To Dashboard tabs @aabidsofi19 (#9687)
  * Meshery CLI
  - [CI] Remove mesheryctl dependency for Helm Chart release
    @leecalcote (#9746)
  * Meshery UI
  - Bump lint-staged from 13.2.3 to 15.1.0 in /ui @dependabot
    (#9530)
  - Enhancements and fixes in Registry @sudhanshutech (#9732)
  - [ci] Fix Eslint @theBeginner86 (#9742)
  - Fix routing issue in settings page @senali-d (#9736)
  - [UI] Feat: Assign Connection to Envs @theBeginner86 (#9637)
  - fix name in expansion row @sudhanshutech (#9720)
  - [Environments] - Dark mode support and RTK migration
    @senali-d (#9705)
  - Fix cols and add resizeable support @sudhanshutech (#9713)
  - Prevent expansion on chip @sudhanshutech (#9703)
  - Added logic of HTML entity encoding in RJSF Text fields
    widget @Yashsharma1911 (#9702)
  - Enhancements in RJSF select widget @Yashsharma1911 (#9699)
  - [UI] fix kubernetes icon @aabidsofi19 (#9690)
  - Add Routing To Dashboard tabs @aabidsofi19 (#9687)
  * Maintenance
  - Bump lint-staged from 13.2.3 to 15.1.0 in /ui @dependabot
    (#9530)
  - Bump github.com/go-git/go-git/v5 from 5.9.0 to 5.11.0
    @dependabot (#9733)
  - [CI] Remove mesheryctl dependency for Helm Chart release
    @leecalcote (#9746)
  - [Helm] chore: dependency upgrade to Ingress v1 @leecalcote
    (#9745)
  - chore(deps): Bump golang.org/x/crypto from 0.15.0 to 0.17.0
    @dependabot (#9668)
  - chore(deps): Bump golang.org/x/crypto from 0.16.0 to 0.17.0
    in /scripts/component_generation @dependabot (#9667)
  - Update build-and-release-stable.yml @theBeginner86 (#9711)
  - Bump meshkit to v0.7.1 @Yashsharma1911 (#9709)
  - [snapshot] Update meshmap.yml @theBeginner86 (#9701)
  - Update meshmap.yml @theBeginner86 (#9700)
  - [snapshot] Update meshmap.yml @theBeginner86 (#9698)
  - [CI] Update meshmap.yml to v0.1.3 @leecalcote (#9697)
  - chore(deps): Bump github.com/containerd/containerd from 1.7.6
    to 1.7.11 @dependabot (#9683)
  * Documentation
  - [Docs] Updated the width of the single column in responsive
    view @Aniumbott (#9727)
  - [Docs] Added Meshery CLI to the list of architectural
    components @PrathumP (#9629)
  - [Docs] Events Management: Remove duplicate page title (h1)
    @leecalcote (#9743)
  - Add OpenAPI Schema Links to concepts on docs @LakshyaSatpal
    (#9708)
  - Adding consistent color to list-structure @yash37158 (#9740)
  - sidebar-list-restructure @vishalvivekm (#9710)
  - [meshsync] GET MeshSync Resources Kinds @theBeginner86
    (#9730)
  - [UI] Feat: Assign Connection to Envs @theBeginner86 (#9637)
  - [CI] feat: Dedicated URL for latest Meshery release tag
    @leecalcote (#9725)
  - Feat: Workspaces @theBeginner86 (#9654)
  - Sidebar Unordered Lists Restructure @yash37158 (#9611)
  - [bug] Fix support for exporting designs @theBeginner86
    (#9692)
  - [Docs] Update for each page's abstract @leecalcote (#9685)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.3:
  * Meshery UI
  - [bug] Fix Unnecessary re-rendering of Dashboard
    @theBeginner86 (#9684)
  - Use rtk query in environments page @aabidsofi19 (#9679)
  - fix connection status duplication and hide workspaces
    allocation @aabidsofi19 (#9678)
  - update route for service-mesh @aabidsofi19 (#9675)
  - Fix Lifecycle routing @aabidsofi19 (#9673)
  - Add Postgres Autoscalar Icon @Akshun-01 (#9672)
  - fix broken imports in environments @aabidsofi19 (#9671)
  * Bug Fixes
  - [bug] Fix Unnecessary re-rendering of Dashboard
    @theBeginner86 (#9684)
* Sun Feb  4 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 0.7.2:
  * General
  - [bug] Fix env component @theBeginner86 (#9659)
  - [server][meshmodel] chore: add aws controllers @VihasMakwana
    (#9650)
  - [Model] AWS EKS: Model and Component metadata @leecalcote
    (#9649)
  - chore: add aws eks controller statically @VihasMakwana
    (#9638)
  * Meshery UI
  - [Environments] Environments page @senali-d (#9647)
  - [UI] Correct indicators for context switcher. @MUzairS15
    (#9645)
  - Upgrade Performance table to sistent table @sudhanshutech
    (#9648)
  - update mdeditor @aabidsofi19 (#9646)
  - [UI] - Prompt Component button color @senali-d (#9644)
  * Maintenance
  - chore(build-and-release-stable): ignore rc releases
    @chenrui333 (#9642)
  - chore(ci/cd): Update e2e tests with newer k8s versions
    @webstradev (#9665)
  - [environments] Add API to Get Connections for Environment
    @theBeginner86 (#9651)
  * Documentation
  - [environments] Add API to Get Connections for Environment
    @theBeginner86 (#9651)
* Mon Dec 18 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.7.1:
  * General
  - Bump axios from 0.26.1 to 1.6.0 in
    /install/docker-extension/ui @dependabot (#9340)
  - [chore] upgrade to meshkit v0.7.0 @MUzairS15 (#9606)
  * Meshery CLI
  - [feat] add enhancements, fix latency while searching models
    @VihasMakwana (#9573)
  * Meshery UI
  - [UI] Changed User.js from class based component to functional
    component @Mohith234 (#8918)
  - [feat] add enhancements, fix latency while searching models
    @VihasMakwana (#9573)
  * Bug Fixes
  - [server][fix]: don't exit in case of context is persisted
    @VihasMakwana (#9608)
* Mon Dec 18 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.7.0:
  * General
  - fix gcp icons @aabidsofi19 (#9605)
  - [Meshmodel] Update Annotations and add capabities
    @aabidsofi19 (#9603)
  - [Relationships] Update relationships definitions to include
    RoleBinding to Service Account mapping. @MUzairS15 (#9601)
  - add capabilities to flow chart shapes @aabidsofi19 (#9596)
  - chore: relocate and rename conn and cred @leecalcote (#9559)
  - [Model] Flowchart Shapes: Document, MultipleDocuments,
    Process, StoredData @leecalcote (#9563)
  - [server][meshsync] hard reset database @VihasMakwana (#9545)
  * Meshery UI
  - [UI] Fix K8s formatter for meshery controller statuses.
    @MUzairS15 (#9597)
  - Fix Issue #9590 in component "DashboardComponent" in UI.
    @Dananjay996 (#9594)
  - Bump @babel/types from 7.23.0 to 7.23.5 in /ui @dependabot
    (#9528)
  - [Fixes - Documentation] update the CONTRIBUTING.md with
    Issues & Pull Requests sections @sandramsc (#9579)
  - Bump cypress from 13.4.0 to 13.6.1 in /provider-ui
    @dependabot (#9591)
  - [UI] Dashboard: Styling for details view in grids @leecalcote
    (#9593)
  - [UI] Dashboard enhancement @theBeginner86 (#9589)
  - fix: fix bug where node name is empty @VihasMakwana (#9511)
  - [UI] Fixes eslint warnings/errors in Provider UI @Pushkarm029
    (#9576)
  * Maintenance
  - Bump github.com/prometheus/client_golang from 1.16.0 to
    1.17.0 @dependabot (#9534)
  - Bump @babel/types from 7.23.0 to 7.23.5 in /ui @dependabot
    (#9528)
  - Bump cypress from 13.4.0 to 13.6.1 in /provider-ui
    @dependabot (#9591)
  * Documentation
  - Added about uninstalling meshery using a Docker Extension
    platform @Srishtihere (#8638)
  - [Docs] Add code for additional alert types and eliminate
    duplicate entries @coder12git (#9225)
  - Updated creating-a-meshery-design.md @nwanduka (#9507)
  - Add setup instructions for using WSL2 on contributing UI page
    w/signoff @gyancodes (#9585)
* Thu Nov 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.185:
  * General
  - updated polygons @aabidsofi19 (#9500)
  - update comp generator @MUzairS15 (#9492)
  - Delete binding.rego @MUzairS15 (#9491)
  * Meshery CLI
  - [cli][system][fix]: return error if detected while creating
    manifests folder @VihasMakwana (#9469)
  * Meshery UI
  - [MeshSync] Fix Sorting MeshSync table @senali-d (#9498)
  - [bug] Resolve connections bug and UI @sudhanshutech (#9488)
  * Documentation
  - Docs Meshsync CRD @KiptoonKipkurui (#9463)
  - Remove broken links in project/index.md @dmarcoux (#9499)
  - [Docs] Meshery Operator, MeshSync, Broker Troubleshooting
    Guide @leecalcote (#9479)
* Thu Nov 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.184:
  * Meshery UI
  - [bug] Update config.js @theBeginner86 (#9486)
  * Bug Fixes
  - [bug] Update config.js @theBeginner86 (#9486)
* Thu Nov 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.183:
  * Meshery UI
  - fix node tab crash ( missing null checks) @aabidsofi19
    (#9483)
  - [fix] missing dashboard overview charts @aabidsofi19 (#9482)
* Thu Nov 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.182:
  * What's Changed
  - [CI] fix eslint issue failing lint check by @sudhanshutech in
    [#9454]
  - [dashboard] fix opacity for view all span by @sudhanshutech
    in #9455
  - [UI] Add hide/unhide support in search for mobile compatible
    by @sudhanshutech in #9456
  - [UI] fix zindex issues by @sudhanshutech in #9462
  - [Server] Update MeshModel components API. by @MUzairS15 in
    [#9464]
  - [UI] Enhance Meshmodel Registry UI by @sudhanshutech in #9465
  - [Server] MeshSync fingerprinting support. by @MUzairS15 in
    [#9442]
  - [utility] Custom infiniteScroll utility function by
    @sudhanshutech in #9466
  - [FIXED] mesheryctl golangci_lint failure by @zakisk in #9468
  - Added feature: mesheryctl exp model search [query-text]
    command by @zakisk in #9436
  - [Feature] Model: aws shape components by @leecalcote in #9457
  - Add Config Map Icon by @ShatilKhan in #8829
  - Add pod metrics icons by @Akshun-01 in #9330
  - add list item hover in theme by @aabidsofi19 in #9475
  - [Meshmodel] Use capabilites by @aabidsofi19 in #9474
  - [UI] FIx UI Dashboard Crash by @MUzairS15 in #9477
  - Meshmodel capabilites by @aabidsofi19 in #9478
  - [Meshmodel] meshery operator by @aabidsofi19 in #9480
  - [Meshmodel] remove ellipse and roundbarrel by @aabidsofi19 in
    [#9481]
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.181:
  * General
  - [policy] Add Sibling Policy @theBeginner86 (#9410)
  - [Helm] Update MeshSync chart @MUzairS15 (#9421)
  - [Playground] Add troubleshooting steps for playground
    environment. @MUzairS15 (#9422)
  * Meshery CLI
  - [ADDED] system model command @zakisk (#8284)
  - fix: Prevent Manually Added Content in CLI Docs to be
    Overwritten @aboobakersiddiqr63 (#9125)
  * Meshery UI
  - Meshmodel Postgres & Kubernetes Component @ptdatta (#8767)
  - Enhance dashboard UI @sudhanshutech (#9428)
  - [Connections] - Enhancements to connections @senali-d (#9441)
  - Fix registry models sorting @ptdatta (#9420)
  - Analytics logo added @ritiksaxena124 (#9425)
  - [Icon] Analytics Category @leecalcote (#9424)
  - [UI] Fixed registry not sorting models alphabetically
    @Shiva953 (#9406)
  - Add icons for whoAmI @Akshun-01 (#9329)
  - [Connections] Status transitions @senali-d (#9405)
  - [bug] Add missing optional chaining in Dashboard
    @theBeginner86 (#9411)
  * Bug Fixes
  - [bug] Add missing optional chaining in Dashboard
    @theBeginner86 (#9411)
  * Maintenance
  - Chore: Remove kuttl library @leecalcote (#9450)
  * Documentation
  - Fixed a typo @vikram-kangotra (#9447)
  - [Server] Add annotations as query param to meshmodel APIs.
    @MUzairS15 (#9443)
  - fix: Prevent Manually Added Content in CLI Docs to be
    Overwritten @aboobakersiddiqr63 (#9125)
  - [Docs] Architecture update @leecalcote (#9419)
  - update @leecalcote (#9417)
  - [Docs] WASM Filter Mgmt update @leecalcote (#9416)
  - [Docs] SMI Removal @leecalcote (#9415)
  - [Docs] Managing Events with Notification Center @leecalcote
    (#9414)
  - [Docs] Models uplift @leecalcote (#9412)
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.180:
  * General
  - [Connection] Add connection & credential definitions for
    Meshery model. @MUzairS15 (#9409)
  - [Server] Perform transitions in a separate routine @MUzairS15
    (#9407)
  * Meshery CLI
  - [chore] Run gofmt. @MUzairS15 (#9408)
  * Meshery UI
  - [chore] rm comments @theBeginner86 (#9404)
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.179:
  * General
  - [Server] update status at the end of the final state
    @MUzairS15 (#9402)
  - [Server] Handle events emitted by Execute funcs properly.
    @MUzairS15 (#9397)
  - Add New shapes (Polygons) @aabidsofi19 (#9374)
  * Meshery UI
  - Enhance Dashboard @theBeginner86 (#9352)
  - fix ui bug in dark mode of modal @vaibhavpnimkar (#9389)
  - Registryui @ptdatta (#9370)
  - [Connections] Connection State Management @MUzairS15 (#9383)
  * Maintenance
  - Bump golang.org/x/oauth2 from 0.12.0 to 0.14.0 @dependabot
    (#9341)
  * Documentation
  - [Docs] Managing infrastructure with Meshery. @MUzairS15
    (#9391)
  * Security
  - Filter "order by" parameter to fix sql inject vuln @phant0ms
    (#9372)
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.178:
  * General
  - [Model] Add connection definition for kubernetes model
    @MUzairS15 (#9368)
  - [chore] Bump MeshKit v0.6.85 @theBeginner86 (#9380)
  - Added MAINTAINERS.md @ankushbhardwaj408 (#9365)
  - make isAnnotation update dynamic @MUzairS15 (#9366)
  - [Extensions] Enhance Meshery Docker Extension UI @senali-d
    (#9377)
  * Meshery UI
  - fix width of connection chip @sudhanshutech (#9386)
  - Reuse connections chip @sudhanshutech (#9382)
  - Color of FavIcon in the footer is changed to keppel green
    @VivekBaldha0712 (#9039)
  - fixed prettier error @captain-Akshay (#9381)
  - [bug] Fix URL import @theBeginner86 (#9378)
  - Bump the npm_and_yarn at /ui security update group in /ui
    with 1 update @dependabot (#9234)
  * Maintenance
  - Bump the npm_and_yarn at /ui security update group in /ui
    with 1 update @dependabot (#9234)
  * Documentation
  - [Docs] Update connections.md @leecalcote (#9373)
* Mon Nov 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.177:
  * General
  - [Model] Add connection definition for kubernetes model
    @MUzairS15 (#9368)
  - [chore] Bump MeshKit v0.6.85 @theBeginner86 (#9380)
  - Added MAINTAINERS.md @ankushbhardwaj408 (#9365)
  - make isAnnotation update dynamic @MUzairS15 (#9366)
  * Meshery UI
  - fix width of connection chip @sudhanshutech (#9386)
  - Reuse connections chip @sudhanshutech (#9382)
  - Color of FavIcon in the footer is changed to keppel green
    @VivekBaldha0712 (#9039)
  - fixed prettier error @captain-Akshay (#9381)
  - [bug] Fix URL import @theBeginner86 (#9378)
  - Bump the npm_and_yarn at /ui security update group in /ui
    with 1 update @dependabot (#9234)
  * Maintenance
  - Bump the npm_and_yarn at /ui security update group in /ui
    with 1 update @dependabot (#9234)
  * Documentation
  - [Docs] Update connections.md @leecalcote (#9373)
* Thu Nov 16 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.176:
  * General
  - [Models] Update Component Updater to use new Spreadsheet
    column PublishToRegistry. @MUzairS15 (#9362)
  - add mehsery components back @aabidsofi19 (#9359)
  * Meshery CLI
  - [mesheryctl] cleanup golden response files @leecalcote
    (#9237)
  * Meshery UI
  - info modal opening issue fixed in table view @vaibhavpnimkar
    (#9361)
  - [connections] use default connection chip and fix bugs
    @sudhanshutech (#9356)
  - [UI] Connections Table enhancements and refactor @aabidsofi19
    (#9360)
  - Use Sistent components and packages @sudhanshutech (#9313)
  - [UI] Fix technology and type not showing in Info modal
    @Yashsharma1911 (#9337)
  - [Server] Clean applications from configuration subscription i
    @aabidsofi19 (#9354)
  * Maintenance
  - Bump github.com/nats-io/nkeys from 0.4.5 to 0.4.6 @dependabot
    (#9253)
  * Documentation
  - [DOCS] Build REST API docs @MUzairS15 (#9355)
* Tue Nov 14 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.175:
  * General
  - [Docker-Compose] Update playground docker-compose to include
    cilium adapter @MUzairS15 (#9342)
  * Meshery UI
  - Fix Setting page crash when adapter is deployed. @MUzairS15
    (#9353)
  - [connections] - UI enhancements @senali-d (#9349)
  - [Connections] Fix events for K8S context receipt @MUzairS15
    (#9345)
  * Documentation
  - [docs] Update Application Management @theBeginner86 (#9335)
* Mon Nov 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.174:
  * General
  - [chore] bump meshkit to v0.6.83 @theBeginner86 (#9338)
  - [Server] Fix K8S subscription repeated reinitialization issue
    @MUzairS15 (#9336)
  - [Extensions] Enhance Meshery Docker Extension UI @senali-d
    (#9323)
  - fix go.sum issue arisen due to conflicts @MUzairS15 (#9326)
  - Upgrade meshkit which also fixes comp generation. @MUzairS15
    (#9324)
  * Meshery CLI
  - removed requirements for k8s connections @EraKin575 (#8854)
  * Meshery UI
  - [pattern] Support for pattern_id in Deploy handler
    @theBeginner86 (#9334)
  - [UI] Add Formatted Kubernetes metadata to connections
    @aabidsofi19 (#9321)
  - [UI] Fix Registry Treeview @aabidsofi19 (#9331)
  - Fix RJSF form expanding on selecting multiple technologies in
    info modal @Yashsharma1911 (#9266)
  - Fix contrast issue @ptdatta (#9328)
  - Bump react-relay from 14.1.0 to 16.0.0 in /ui @dependabot
    (#9268)
  * Maintenance
  - Update meshmodel-generators.yml @Jougan-0 (#9327)
  - Generator @Jougan-0 (#9309)
  - Bump react-relay from 14.1.0 to 16.0.0 in /ui @dependabot
    (#9268)
  - Bump github.com/go-errors/errors from 1.4.2 to 1.5.1
    @dependabot (#9270)
  - Bump google.golang.org/api from 0.143.0 to 0.149.0 in
    /scripts/component_generation @dependabot (#9275)
* Thu Nov  9 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.173:
  * Meshery UI
  - Fix Dark mode @ptdatta (#9318)
  - Enable status col in connection and add ping check
    @sudhanshutech (#9317)
  - [bug] Fix broken UI @sudhanshutech (#9315)
  * Bug Fixes
  - [bug] Fix broken UI @sudhanshutech (#9315)
  * Documentation
  - [docs] Fix Redirection /platforms/page -> /page
    @theBeginner86 (#9316)
  - [bug/docs] Fix redirect from /platforms @theBeginner86
    (#9314)
* Thu Nov  9 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.172:
  * Meshery UI
  - [Server] K8s connection management @MUzairS15 (#9170)
  - Meshmodel new UI @ptdatta (#9184)
  - Bump billboard.js from 3.9.0 to 3.10.2 in /ui @dependabot
    (#9269)
  - Bump eslint-config-next from 13.5.3 to 14.0.1 in /provider-ui
    @dependabot (#9277)
  - Bump cypress from 13.3.0 to 13.4.0 in /provider-ui
    @dependabot (#9279)
  - Add sidecar icon @ShatilKhan (#9291)
  - [UI] Expose generic RJSF modal to meshery extension
    @Yashsharma1911 (#9304)
  * Maintenance
  - Bump billboard.js from 3.9.0 to 3.10.2 in /ui @dependabot
    (#9269)
  - Bump fortio.org/fortio from 1.57.5 to 1.60.3 @dependabot
    (#9272)
  - Bump eslint-config-next from 13.5.3 to 14.0.1 in /provider-ui
    @dependabot (#9277)
  - Bump cypress from 13.3.0 to 13.4.0 in /provider-ui
    @dependabot (#9279)
  * Documentation
  - added some svgs in docs @iArchitSharma (#9312)
  - [Docs] Exclude old versions from rendering in local builds
    @leecalcote (#9310)
  - Added description of Docs capability for "alerts"
    @Debaditya-Som (#9226)
  - [docs] Add docs for notification center @aabidsofi19 (#9303)
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- skip non-existent release 0.6.170
- update to 0.6.171:
  No nicely formatted changelog available
  Changes:
  * Bump @babel/eslint-parser from 7.22.11 to 7.22.15 in
    /provider-ui
  * Bump @cypress/code-coverage from 3.12.5 to 3.12.7 in
    /provider-ui
  * Bump @mui/material from 5.14.7 to 5.14.16 in /provider-ui
  * Merge pull request #9276 from
    meshery/dependabot/npm_and_yarn/provider-ui/mui/material-5.14.16
  * Merge pull request #9278 from
    meshery/dependabot/npm_and_yarn/provider-ui/babel/eslint-parser-7.22.15
  * Merge pull request #9280 from
    meshery/dependabot/npm_and_yarn/provider-ui/cypress/code-coverage-3.12.7
  * Merge pull request #9281 from
    theBeginner86/theBeginner86/chore/53
  * Merge pull request #9296 from
    meshery/leecalcote/docs/integration-formatting
  * Merge pull request #9297 from
    ritiksaxena124/ritiksaxena124/docs-logo
  * Merge pull request #9298 from meshery/chore
  * Merge pull request #9302 from meshery/revert-9243-resources
  * Merge remote-tracking branch 'upstream/master' into
    theBeginner86/chore/53
  * Meshmodel components updated
  * Revert "fix: Dashboard card missing title and background"
  * Update error-codes-updater.yaml
  * [Docs] Integrations page formatting
  * [Docs] Release Notes for Meshery
  * add events for publishing
  * add new catalog request construct
  * fix filters publish/unpublish
  * fix unpublish
  * update action
  * update go-testing-ci workflow
  * update message for patterns
  * updated meshery docs logo
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.169:
  * General
  - [Server] Pattern API response @MUzairS15 (#9292)
  * Meshery UI
  - [UI] Fixed styling of Unauthenticated Modal @captain-Akshay
    (#9290)
  - Fixes in Connections/MeshSync tables @sudhanshutech (#9265)
  - [UI] Make the eventActors avatar overlapping stack
    @aabidsofi19 (#9264)
  - fix: Dashboard card missing title and background @MeenuyD
    (#9243)
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.168:
  * no changelog for this release
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.166:
  * no changes in this release
- update to 0.6.167:
  * General
  - Update go base image version in Dockerfile @MUzairS15 (#9239)
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.165:
  * General
  - Bump google.golang.org/grpc from 1.54.0 to 1.56.3 in
    /scripts/component_updater @dependabot (#9207)
  - Fix links (kubernetes) in README.md @adityadeshpande09
    (#9229)
  - Add Section Component and Relationships @aabidsofi19 (#9231)
  - [bug] update github.com/hashicorp/golang-lru/v2
    @theBeginner86 (#9232)
  - feat: Update several packages in Meshery @nebula-aac (#9137)
  * Meshery CLI
  - [FIXED] mesheryctl app source type comparison bug is fixed
    @zakisk (#9230)
  * Meshery UI
  - [bug/CI] fix provider-lint @theBeginner86 (#9233)
  * Bug Fixes
  - [bug/CI] fix provider-lint @theBeginner86 (#9233)
  * Maintenance
  - Bump google.golang.org/grpc from 1.57.0 to 1.57.1 in
    /scripts/component_generation @dependabot (#9205)
  - Bump sigs.k8s.io/controller-runtime from 0.15.1 to 0.16.3
    @dependabot (#9223)
  * Documentation
  - Added New Script for Generating integration docs
    @aboobakersiddiqr63 (#9219)
* Fri Nov  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.164:
  * General
  - [Server] Fix MeshMap snapshot service @MUzairS15 (#9222)
  - [server] update styleoverrides to include default data and
    polygon-points @aabidsofi19 (#9217)
  - Broken link of kubernetes-minikube fixed in README
    @Kaushik080 (#9211)
  - add new relationship from pod to pod via networkpolicy
    @MUzairS15 (#9209)
  - [CI] fixed meshkit error util failure @zakisk (#9194)
  - Docker broken link fixed in README @Atharv0003 (#9202)
  - [Relationships] Update mount relationship. @MUzairS15 (#9197)
  - Broken link of SMP fixed in README @niranjan-kurhade (#9193)
  - Updated codespaces.md @aboobakersiddiqr63 (#9180)
  - [bug] Fix env component @theBeginner86 (#9186)
  * Meshery CLI
  - [mesheryctl] system start command bug of deployment of config
    components adapters @zakisk (#9188)
  - [CI] fixed golangci lint failure @zakisk (#9208)
  * Meshery UI
  - Bump browserify-sign from 4.2.1 to 4.2.2 in /ui @dependabot
    (#9218)
  - Sort data in connections @senali-d (#8902)
  - [CI] update dockerfile and set code-coverage cy plugin to
    devDep @MarioArriaga92 (#9191)
  - Fix Console error in Meshery cloud @coder12git (#9154)
  * Maintenance
  - Bump google.golang.org/grpc from 1.58.2 to 1.58.3 @dependabot
    (#9206)
  - Bump browserify-sign from 4.2.1 to 4.2.2 in /ui @dependabot
    (#9218)
  * Documentation
  - [Docs] v0.6 snapshot @leecalcote (#9215)
  - [docs] Update Workspaces/Environment @theBeginner86 (#9216)
  - [Docs] Final FAQ uplift @leecalcote (#9213)
  - [Docs]- Fix Flickering in Links @coder12git (#9198)
  - [Docs] Init Integrations Collection @leecalcote (#9212)
  - Standardization of kubernetes.md @aboobakersiddiqr63 (#9201)
  - fix: updtate twitter logo to x @akagami-harsh (#9155)
  - [Docs] Site index update; Projects section update @leecalcote
    (#9178)
  - Standardization of minikube.md @aboobakersiddiqr63 (#9187)
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.163:
  * General
  - Add new component text-box @aabidsofi19 (#9167)
  - [bug] fetch namespace GraphQL Query @theBeginner86 (#9144)
  * Meshery CLI
  - [mesheryctl] fixed meshery start command bug with adapter
    components @zakisk (#9160)
  - mesheryctl mesh tests @Philip-21 (#9063)
  * Meshery UI
  - [Meshery Performance] fixed one small bug @captain-Akshay
    (#9163)
  - [UI] Converted MesheryPerformanceComponent from class-based
    to functional component @captain-Akshay (#9075)
  - [UI] Dashboard workload chart @aabidsofi19 (#9159)
  - [UI] Disable credential in settings @Yashsharma1911 (#9152)
  * Bug Fixes
  - [docs/bug] Update index.md @theBeginner86 (#9164)
  * Maintenance
  - [Docs] discuss integration reinstatement @leecalcote (#9174)
  - Component genrator @Jougan-0 (#9153)
  - Component generator @Jougan-0 (#9151)
  * Documentation
  - Standaridization of gke installation docs @aboobakersiddiqr63
    (#9177)
  - Minor typo and format changes in Supported docs
    @aboobakersiddiqr63 (#9176)
  - [Docs] discuss integration reinstatement @leecalcote (#9174)
  - [Docs] Mesheryctl page: Eliminate cycical redirection /
    flicker @leecalcote (#9171)
  - Updated aks.md and added helm.md @aboobakersiddiqr63 (#9141)
  - Updated minikube.md @aboobakersiddiqr63 (#9140)
  - [Docs]: Add section describing the use of children and
    grandchildren @coder12git (#9168)
  - [chore] Support for Visibility in Content APIs | CU-85ztrgw1z
    @theBeginner86 (#9157)
  - [docs/bug] Update index.md @theBeginner86 (#9164)
  - [DOCS] added sending events section in docs @zakisk (#9064)
  - Fix Meshery Docs search @coder12git (#9148)
  - [WIP] Add docs for connection states @MUzairS15 (#9065)
  - [Docs] Restructure, Menu and TOC massage @leecalcote (#9147)
  - [MeshSync] Expose MeshSync Discovered Resources
    @theBeginner86 (#9143)
  - Added contents in FAQ.md. @Zubiii333 (#9126)
  - [Docs] Rewrite of Quick Start Guide @leecalcote (#9139)
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.162:
  * General
  - [MeshSync] Update MeshSync Tables + GO pkgs @theBeginner86
    (#9127)
  - Bump @babel/traverse from 7.17.3 to 7.23.2 in
    /install/docker-extension/ui @dependabot (#9132)
  - Update kubernetes components styles @aabidsofi19 (#9066)
  - Update Dockerfile @leecalcote (#9120)
  * Meshery UI
  - Bump @babel/traverse from 7.20.13 to 7.23.2 in /provider-ui
    @dependabot (#9131)
  - [UI] Add ordering in metadata @aabidsofi19 (#9121)
  - Bump @babel/traverse from 7.21.3 to 7.23.2 in /ui @dependabot
    (#9133)
  * Maintenance
  - Bump @babel/traverse from 7.20.13 to 7.23.2 in /provider-ui
    @dependabot (#9131)
  - Bump @babel/traverse from 7.21.3 to 7.23.2 in /ui @dependabot
    (#9133)
  * Documentation
  - Update load-generators.md @ValGrace (#9116)
  - feat:New endpoint for registrants w/signoff @Jougan-0 (#9040)
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.161:
  * 29425b6 Merge branch 'master' into theBeginner86/chore/41
  * 7a4ef2f Merge pull request #9118 from
    theBeginner86/theBeginner86/chore/40
  * f4a050d Merge pull request #9119 from
    theBeginner86/theBeginner86/chore/41
  * 220592c [Docs] Release Notes for Meshery
  * e2088d3 fix lock.json
  * 74f9dea rever react-redux
  * 7343f92 update package-lock.json
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.160:
  * Meshery UI
  - [bug] fix confirmation modal export @theBeginner86 (#9117)
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.159:
  * General
  - Revert to "notistack": "^1.0.10"
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.158:
  * General
  - Adjust link to attach properly to the 'catalog of curated
    design templates' text @MeenuyD (#9051)
  - meshery-operator v0.6.13 @leecalcote (#9099)
  - Upgrade asaskevich/govalidator @leecalcote (#9101)
  - cuelang.org/go v0.6.0 @leecalcote (#9097)
  - Bump golang.org/x/net from 0.9.0 to 0.17.0 in
    /scripts/component_updater @dependabot (#9081)
  - Upgrade lib/pq @leecalcote (#9102)
  - [Deps] Golang: golang.org/x/net upgrade @leecalcote (#9110)
  - [Dependency] Component Updater: x.net @leecalcote (#9109)
  - meshkit v0.6.72 @leecalcote (#9098)
  * Meshery UI
  - change k8s context switch background color @AkashKumar7902
    (#8727)
  - [UI] Upgrade to notistack v3 w/no MUI v5 dependency
    @leecalcote (#9112)
  - [UI] Deps: "react-redux": "^8.1.3", @leecalcote (#9111)
* Wed Oct 25 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.157:
  * General
  - [Docs] MeshSync @leecalcote (#9087)
  - Include doc link in K8s component registration event
    @leecalcote (#9009)
  - [meshmodel] Add Environment Component Def @theBeginner86
    (#9070)
  * Meshery UI
  - Added-icon-for-meshmodel-prometheus-component-Alertmanager
    @Ayush9026 (#9069)
  - Uploaded Icon for Kubernetes Component - Ingress
    @csengineer1990 (#9016)
  - Added Flow Schema Icons @nwanduka (#9083)
  - [UI]fix incorrect error message description @Shiva953 (#9071)
  - Bump graphql from 16.6.0 to 16.8.1 in /ui @dependabot (#8862)
  - chore: Remove lint-staged in package.json @nebula-aac (#9062)
  - Disable edit and create action button in credential and fix
    all lint warning and errors @Yashsharma1911 (#9074)
  * Maintenance
  - Bump fortio.org/fortio from 1.58.0 to 1.60.2 @dependabot
    (#8976)
  - Bump graphql from 16.6.0 to 16.8.1 in /ui @dependabot (#8862)
  - Bump golang.org/x/net from 0.15.0 to 0.17.0 in
    /scripts/component_generation @dependabot (#9079)
  * Documentation
  - [Docs] CSS removal and alert info background @leecalcote
    (#9092)
  - Updated EKS Docs @aboobakersiddiqr63 (#9089)
  - [Docs] MeshSync inclusion of component id label @leecalcote
    (#9090)
  - Add docs for Bulk Operations and Metadata Renderers @ptdatta
    (#9086)
* Tue Oct 10 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.156:
  * General
  - Revert commits added by mistake @MUzairS15 (#9068)
  * Meshery UI
  - [UI] Added helm connection Wizard @Yashsharma1911 (#8965)
  - Bulk Operations and Metadata Renderers @aabidsofi19 (#9018)
  * Documentation
  - [README.md] bold styling not applied to text @xiangpingjiang
    (#9054)
  - added links in MeshMap Documentation @ATREAY (#9059)
* Tue Oct 10 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.155:
  * Meshery CLI
  - tests for mesheryctl system package @Philip-21 (#8585)
  - [FIXED] mesheryctl error code conflicts solved @zakisk
    (#9014)
  * Meshery UI
  - fix lint error issue @sudhanshutech (#9056)
  - fixed the filter-dropdown component @captain-Akshay (#9021)
  - [UI] rename MeshModel Summary to Registry in Settings
    @Adaminite (#9046)
  - [UI] Add Menu colors to theme @aabidsofi19 (#9041)
  - Fix Hover @ptdatta (#8989)
  - Bump zod and next in /provider-ui @dependabot (#9037)
  - Bump postcss and next in /provider-ui @dependabot (#9038)
  - Fix ui issues @sudhanshutech (#9024)
  - Bump postcss from 8.4.21 to 8.4.31 in /ui @dependabot (#9035)
  - [UI] Fix darkmode issue in extentions @aabidsofi19 (#9025)
  - fix: Swap Table and Grid icons on Activity Toolbar
    @akhilender-bongirwar (#9028)
  * Maintenance
  - tests for mesheryctl system package @Philip-21 (#8585)
  - Bump zod and next in /provider-ui @dependabot (#9037)
  - Bump postcss and next in /provider-ui @dependabot (#9038)
  - Bump postcss from 8.4.21 to 8.4.31 in /ui @dependabot (#9035)
  * Documentation
  - Update Artifacts sub-section in documentation @ValGrace
    (#8997)
  - Deleted Duplicate line in Docs #9017 @aadityadike (#9047)
* Thu Oct  5 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.154:
  * General
  - [Server] Fix race cond in k8s comp registration @MUzairS15
    (#9015)
  * Meshery UI
  - [Server] Add APIs for bulk operations on events @MUzairS15
    (#8999)
  - Bump eslint-config-next from 13.4.19 to 13.5.3 in
    /provider-ui @dependabot (#8987)
  - UI enhancements and Standardized Data Tables @sudhanshutech
    (#8939)
  - Bump eslint-plugin-cypress from 2.14.0 to 2.15.1 in
    /provider-ui @dependabot (#8986)
  - Bump cypress from 13.1.0 to 13.3.0 in /provider-ui
    @dependabot (#8984)
  - Bump @fortawesome/fontawesome-svg-core from 6.2.0 to 6.4.2 in
    /ui @dependabot (#8983)
  - Bump @cypress/code-coverage from 3.11.0 to 3.12.1 in
    /provider-ui @dependabot (#8985)
  - Bump next from 13.4.12 to 13.5.3 in /provider-ui @dependabot
    (#8988)
  * Maintenance
  - refactor(server): remove redundant len check @Juneezee
    (#8992)
  - Bump eslint-config-next from 13.4.19 to 13.5.3 in
    /provider-ui @dependabot (#8987)
  - Bump eslint-plugin-cypress from 2.14.0 to 2.15.1 in
    /provider-ui @dependabot (#8986)
  - Bump cypress from 13.1.0 to 13.3.0 in /provider-ui
    @dependabot (#8984)
  - Bump @fortawesome/fontawesome-svg-core from 6.2.0 to 6.4.2 in
    /ui @dependabot (#8983)
  - Bump @cypress/code-coverage from 3.11.0 to 3.12.1 in
    /provider-ui @dependabot (#8985)
  - Bump next from 13.4.12 to 13.5.3 in /provider-ui @dependabot
    (#8988)
* Mon Oct  2 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.153:
  * Meshery UI
  - Added info modal in meshery @Yashsharma1911 (#8912)
  * Maintenance
  - Revert "Bump github.com/docker/cli from 20.10.21+incompatible
    to 24.0.6+incompatible" @theBeginner86 (#8990)
  - Bump google.golang.org/api from 0.128.0 to 0.143.0 in
    /scripts/component_generation @dependabot (#8982)
  - Bump github.com/layer5io/meshkit from 0.6.52 to 0.6.69 in
    /scripts/component_generation @dependabot (#8981)
  - Bump golang.org/x/oauth2 from 0.9.0 to 0.12.0 in
    /scripts/component_generation @dependabot (#8980)
  - Bump github.com/docker/cli from 20.10.21+incompatible to
    24.0.6+incompatible @dependabot (#8978)
* Mon Oct  2 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.152:
  * General
  - [Extension] Docker: Update docker-compose.yaml @leecalcote
    (#8969)
  * Meshery UI
  - fix: Updated format script to escape quotes @nebula-aac
    (#8967)
  - [UI] Integrating CASL into Meshery UI @Mohith234 (#8945)
  * Maintenance
  - Fix Failing End to End Meshctl test @KiptoonKipkurui (#8973)
  - [chore] Fix MeshModel models reterival @theBeginner86 (#8941)
  - [CI] Upgrade docker/setup-buildx-action and
    docker/setup-qemu-action @leecalcote (#8960)
  * Documentation
  - [Docs] Control the display of the intra-page navigator
    toolbar @leecalcote (#8947)
  - [Docs] Enhance docs for /api/user/token @coder12git (#8968)
  - Update URL with #anchor @goldfishdolphin (#8952)
  - [Docs] Preparation for moving from Apps to Designs
    @leecalcote (#8953)
  - [Docs] Added link for discussion forum @GLADI8R (#8955)
* Fri Sep 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.151:
  * Meshery CLI
  - comment out docker group check @leecalcote (#8958)
  * Meshery UI
  - equality changes @aabidsofi19 (#8959)
- update to 0.6.150:
  * Meshery UI
  - Revert "fix: select all button issue meshery" @aabidsofi19
    (#8957)
* Thu Sep 28 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.149:
  * Meshery UI
  - fix: Remove useTheme from emotion react, and call theme as
    props @nebula-aac (#8948)
* Thu Sep 28 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.148:
  * General
  - [Helm] Values descriptions @leecalcote (#8935)
  - [Docs] Update Helm Chart docs. @MUzairS15 (#8934)
  - [Playground] Increase max file upload size. @leecalcote
    (#8765)
  - [Server] Do not refresh token when status code returned is
    403. @MUzairS15 (#8900)
  * Meshery UI
  - Fix Dashboard Component @aabidsofi19 (#8888)
  - fix useeffect and fetching @aabidsofi19 (#8943)
  - fix: select all button issue meshery @captain-Akshay (#8933)
  - Add a nullish check @aabidsofi19 (#8937)
  - fix: Change prettier to error, and added eol to be LF
    @nebula-aac (#8916)
  - [extensions] Fix Collaborator Extension Point Re-rendering
    @theBeginner86 (#8904)
  - Fix for Navigation @Jougan-0 (#8877)
  - [UI] feat: Setup prettier and moved lint-staged to its own
    file @nebula-aac (#8827)
  - Revert "[extensions] Fix Collaborator Extension Point
    Re-rendering" @theBeginner86 (#8903)
  - [extensions] Fix Collaborator Extension Point Re-rendering
    @theBeginner86 (#8893)
  * Bug Fixes
  - [extensions] Fix Collaborator Extension Point Re-rendering
    @theBeginner86 (#8904)
  - add functionality to dynamically update the URL
    @goldfishdolphin (#8899)
  * Maintenance
  - fix useeffect and fetching @aabidsofi19 (#8943)
  - fix: Change prettier to error, and added eol to be LF
    @nebula-aac (#8916)
  * Documentation
  - fix: #8911 @Sumit21kumar (#8914)
  - Changed “pertainting” to “pertaining” @nwanduka (#8920)
  - Updated docs regarding linting/formatting in ui
    @akhilender-bongirwar (#8926)
  - fix: Typo in Contributing to Meshery Server documentation
    [#8924] @SAF2k (#8927)
  - Typo in Contributing to Meshery Server/signoff @Ayush9026
    (#8928)
  - [DOC] fix: all the typos @captain-Akshay (#8930)
  - add functionality to dynamically update the URL
    @goldfishdolphin (#8899)
* Sun Sep 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.147:
  * Meshery UI
  - Revert "[Fix] k8s-switcher select-all" @theBeginner86 (#8898)
* Sun Sep 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.146:
  * General
  - MeshKit v0.6.67 @leecalcote (#8897)
  * Meshery UI
  - [UI] Notification Center: Increase size of unread indicator
    @leecalcote (#8891)
  - [extensions] fix error msg @theBeginner86 (#8892)
  - changed smi_results.js @EraKin575 (#8868)
  - Connections row expand data with styling @senali-d (#8840)
  - [Fix] k8s-switcher select-all @aabidsofi19 (#8876)
  - [CI] e2e test job improvements @MarioArriaga92 (#8643)
  * Maintenance
  - updating node versions workflow actions @Philip-21 (#8856)
  - [CI] e2e test job improvements @MarioArriaga92 (#8643)
* Sun Sep 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.145:
  no changes apparently
* Sun Sep 24 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.144:
  * General
  - add docs for component generation and updater scripts
    @MUzairS15 (#8860)
  - Fixed Meshary Integration Updater @ptdatta (#8774)
  * Meshery UI
  - [Designs] Fixes And Enhancements @aabidsofi19 (#8861)
  - Fix Notification center bell icon toggle btn @aabidsofi19
    (#8875)
  - [UI] Enhancements :Notification center @aabidsofi19 (#8872)
  - [UI] Fix cluster resources dashboard not getting populated
    with data @MUzairS15 (#8873)
  - [chore] Improve events for Server @MUzairS15 (#8864)
  - [UI] Notification inverse read indicator @aabidsofi19 (#8865)
  - [UI] Remove old store for notification center @aabidsofi19
    (#8858)
  - Fix typo in `component-svg/_.txt` @eltociear (#8830)
  - [UI] Enhance Error Handling @aabidsofi19 (#8851)
  * Bug Fixes
  - [bug] Fix API docs build @theBeginner86 (#8852)
  * Documentation
  - [bug] Fix API docs build @theBeginner86 (#8852)
* Thu Sep 21 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.143:
  * General
  - Update messages and logs to designs from patterns @Chadha93
    (#8800)
  - handle nil checks @MUzairS15 (#8844)
  - watchtower label is added @zakisk (#8789)
  * Meshery CLI
  - run error util for mesheryctl error codes replacement
    @MUzairS15 (#8846)
  * Meshery UI
  - [chore] Make MeshSyncEvents GraphQL Subscription Configurable
    @theBeginner86 (#8841)
  - [Servre] Graphql/directives @MUzairS15 (#8836)
  - [UI] Add Validation and Error Boundaries @aabidsofi19 (#8833)
  - Added Debug log for extension component @senali-d (#8845)
  - fix pagination in meshmodel browser @sudhanshutech (#8838)
  - converted class based dashboard component to functional
    component @EraKin575 (#8724)
  * Bug Fixes
  - [bug] Fix failing API docs build @theBeginner86 (#8850)
  * Documentation
  - [bug] Fix failing API docs build @theBeginner86 (#8850)
  - [Server] Added environments in Meshery @Yashsharma1911
    (#8723)
* Wed Sep 20 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.142:
  * General
  - Remove adapter references in default env vars @leecalcote
    (#8810)
  - [Docker Extension] Remove adapters from default configuration
    @leecalcote (#8811)
  * Meshery UI
  - [chore] fix color undefined @theBeginner86 (#8832)
  - [UI] Notification Center: Update color of "No notifications
    to show" @leecalcote (#8828)
  - Fix repetitive api calls and UI issues in connections page
    @sudhanshutech (#8825)
  - changed LoadTestTimerConfig and MeshAdapterConfigComponent to
    functional component @EraKin575 (#8781)
  * Bug Fixes
  - [chore] fix color undefined @theBeginner86 (#8832)
  - Fix repetitive api calls and UI issues in connections page
    @sudhanshutech (#8825)
  * Maintenance
  - Meshery End-to-End Tests with mesheryctl @KiptoonKipkurui
    (#8808)
  * Documentation
  - Update "Meshery Deployment Incompatible" error docs
    @Mohith234 (#8824)
* Tue Sep 19 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.141:
  * Meshery CLI
  - [bug] Update healthcheck.go @theBeginner86 (#8770)
  * Meshery UI
  - [chore] Fix lint @theBeginner86 (#8821)
  - [UI] Added Connect Helm Repo button in connections page
    @Yashsharma1911 (#8816)
  - Format k8s response @MUzairS15 (#8775)
  - Notification Center @aabidsofi19 (#8733)
  - Bump @cypress/request and cypress in /ui @dependabot (#8792)
  - [UI] Prevent rjsf modal rerendering @Yashsharma1911 (#8787)
  * Bug Fixes
  - [bug] Update healthcheck.go @theBeginner86 (#8770)
  * Maintenance
  - [chore] Fix lint @theBeginner86 (#8821)
  - Bump @cypress/request and cypress in /ui @dependabot (#8792)
  * Documentation
  - Notification Center @aabidsofi19 (#8733)
  - Fixes the issue in Docs Search: Unwanted display of search
    result on separate line from bullet point in safari
    browser(7402) @phanithinks (#8690)
  - meshmodel docs @parth721 (#8656)
* Mon Sep 18 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.140:
  * Meshery UI
  - [UI] Convert Index.js and settings.js from class-based
    component to functional component @ShatilKhan (#8705)
  - Fix crash on saving applications @sudhanshutech (#8776)
  - updated filter.js to functional component @abhijeetgauravm
    (#8785)
  - Updated PromptComponent to support checkbox @Yashsharma1911
    (#8672)
  - chore: sort the technology list in alphabetical order
    @Yana-Gupta (#8708)
  - Refactor /management/index.js to functional component
    @dhiraj0911 (#8703)
  - [UI] Transparent "WA" Filter Icon @Chadha93 (#8793)
  - Fix infinite publish requests @aabidsofi19 (#8769)
  * Bug Fixes
  - Fix crash on saving applications @sudhanshutech (#8776)
  * Maintenance
  - Fix failing updater test @KiptoonKipkurui (#8791)
* Thu Sep 14 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.139:
  * General
  - [MeshModel] New shapes @leecalcote (#8762)
  - Remove Firewall Policy @leecalcote (#8759)
  - [server]Fix Index Out of Range Error Handling in Meshery
    Component Handler @Shiva953 (#8709)
  - Update events_persister.go @MUzairS15 (#8719)
  - [Events] Add API to return available event category and
    action. @MUzairS15 (#8715)
  * Features
  - Improve search functionality using debounce @sudhanshutech
    (#8720)
  * Meshery CLI
  - FIXED: adapter deployment permission denied error on docker
    platform @zakisk (#8694)
  * Meshery UI
  - Show duplicates meshmodels on toggle @sudhanshutech (#8704)
  - Improve search functionality using debounce @sudhanshutech
    (#8720)
  - created a folder @ritiksaxena124 (#8726)
  - change sort order from asc to desc as default @MUzairS15
    (#8725)
  - [UI] Converted UserPreferences and preferences form
    class-based to fun… @mukeshkuiry (#8707)
* Mon Sep 11 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.138:
  * Meshery UI
  - Revert "chore: Sort the technology list in alphabetical
    order" @Yashsharma1911 (#8706)
* Mon Sep 11 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.137:
  * General
  - [Enhancement] Add ability to docs updater to push to
    docs.meshery.io @Boombag0607 (#8521)
  * Meshery CLI
  - More Mesheryctl Error Wrappers @Philip-21 (#8588)
  * Meshery UI
  - chore: Sort the technology list in alphabetical order
    @Yana-Gupta (#8697)
  - Reduce unnecessary queries to remote provider. @MUzairS15
    (#8691)
  * Maintenance
  - [CI] Upgrade to Golang 1.21 @leecalcote (#8700)
  - Bump github.com/briandowns/spinner from 1.19.0 to 1.23.0
    @dependabot (#8538)
* Fri Sep  8 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.136:
  * General
  - Aggregate events by status. @MUzairS15 (#8669)
  * Meshery UI
  - Aabidsofi/k8s switcher @aabidsofi19 (#8663)
  - K8s context switcher ping redirected notify to
    useNotification. @ShailikaS (#8681)
  - Standard Toolbar and flexible Mui Data-tables @sudhanshutech
    (#8618)
  - [UI] Connections: Status | #8657 @senali-d (#8660)
  * Bug Fixes
  - Aabidsofi/k8s switcher @aabidsofi19 (#8663)
  - K8s context switcher ping redirected notify to
    useNotification. @ShailikaS (#8681)
  - [UI] Connections: Status | #8657 @senali-d (#8660)
  * Maintenance
  - Bump github.com/cyphar/filepath-securejoin from 0.2.3 to
    0.2.4 @dependabot (#8684)
  - Email will not be sent without any failure @VaibhavMalik4187
    (#8665)
  - [CI] Fix for failing meshkit error utility workflow @suhail34
    (#8659)
  * Documentation
  - [Docs] Logical Concepts: workspaces, env, designs @leecalcote
    (#8679)
  - Leecalcote/docs/mesh @leecalcote (#8678)
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.135:
  * General
  - REST APIs for events. @MUzairS15 (#8655)
  - Bump Meshkit version from 0.6.63 to 0.6.64 @Yashsharma1911
    (#8658)
  * Meshery CLI
  - [mesheryctl] handling default port in mesheryctl @suhail34
    (#8579)
  * Meshery UI
  - Update package.json @MUzairS15 (#8651)
  - Bump uuid from 8.3.2 to 9.0.0 in /ui @dependabot (#8532)
  - [Events] Notification / Operation Center @MUzairS15 (#8644)
  - [UI] Fix credential Icon color in settings @Yashsharma1911
    (#8646)
  * Maintenance
  - [CI] Playground: --remove-orphans in Meshery deployments
    @leecalcote (#8652)
  - Bump uuid from 8.3.2 to 9.0.0 in /ui @dependabot (#8532)
  - Bump gorm.io/gorm from 1.25.3 to 1.25.4 @dependabot (#8630)
  - [CI] Meskit Error Utility Workflow Does not fails for
    duplicacy @suhail34 (#8649)
  - Update MeshModel Issue Template @Boombag0607 (#8637)
  * Documentation
  - [Docs] Added how to use token for Meshery API in postman
    @Freedisch (#8122)
- update to 0.6.134:
  * General
  - Add visibility query param to the /api/filter endpoint
    @Aritra8438 (#8555)
  * Meshery CLI
  - [CI] MeshKit Error Util: duplicate errors causing failures
    @suhail34 (#8450)
  * Meshery UI
  - disable cypress fail on uncaught exception or unhandled
    promise rejec… @MarioArriaga92 (#8641)
  - Display notification according access of role on publish
    designs/filters @sudhanshutech (#8480)
  - [UI] Connections: External Link and Light Mode Issue
    @senali-d (#8540)
  - feat: added icon to show the current status of adapter
    deployement @Yana-Gupta (#8586)
  - Export RJSFWrapper to Extension Point @Yashsharma1911 (#8639)
  - fix: hide navbar and sidebar in fullscreen mode @Udit-takkar
    (#8611)
  - Bump cypress from 12.17.4 to 13.1.0 in /provider-ui
    @dependabot (#8631)
  - Bump @mui/material from 5.14.3 to 5.14.7 in /provider-ui
    @dependabot (#8634)
  * Maintenance
  - Bump cypress from 12.17.4 to 13.1.0 in /provider-ui
    @dependabot (#8631)
  - Bump @mui/material from 5.14.3 to 5.14.7 in /provider-ui
    @dependabot (#8634)
- update to 0.6.133:
  * General
  - [Server] Fix meshery server bottleneck issues @MUzairS15
    (#8622)
  - Bump gopkg.in/yaml.v3 from 3.0.0-20210107192922-496545a6307b
    to 3.0.0 in /install/docker-extension @dependabot (#8616)
  * Meshery UI
  - Bump @babel/eslint-parser from 7.19.1 to 7.22.11 in /ui
    @dependabot (#8626)
  - Bump @mui/icons-material from 5.14.3 to 5.14.7 in
    /provider-ui @dependabot (#8632)
  - Bump eslint from 8.47.0 to 8.48.0 in /provider-ui @dependabot
    (#8633)
  - Bump @babel/eslint-parser from 7.22.7 to 7.22.11 in
    /provider-ui @dependabot (#8635)
  - fix: Fixed the misspelling in connections page @tushh-codes
    (#8621)
  - Changed CustomTableFooter from class-based to functional
    component @Rajdip019 (#8610)
  - [RJSF][UI] Fixed type error and removed publish schema from
    Meshery UI @Yashsharma1911 (#8608)
  - Moved CustomToolbarSelect.js from class-based component to
    functional component @Rajdip019 (#8582)
  * Maintenance
  - Bump github.com/layer5io/meshsync from 0.6.11 to 0.6.14
    @dependabot (#8628)
  - Bump @babel/eslint-parser from 7.19.1 to 7.22.11 in /ui
    @dependabot (#8626)
  - Bump @mui/icons-material from 5.14.3 to 5.14.7 in
    /provider-ui @dependabot (#8632)
  - Bump eslint from 8.47.0 to 8.48.0 in /provider-ui @dependabot
    (#8633)
  - Bump @babel/eslint-parser from 7.22.7 to 7.22.11 in
    /provider-ui @dependabot (#8635)
  - Bump gonum.org/v1/gonum from 0.12.0 to 0.14.0 @dependabot
    (#8583)
  - Prevent MeshMap from running on forked repo @VaibhavMalik4187
    (#8598)
  - Updated email-on-failure job @VaibhavMalik4187 (#8578)
  * Documentation
  - Kuma dark mode logo resolve @lanzkrish (#8596)
- update to 0.6.132:
  * General
  - Enhanced error messages for kubeconfig access @abdullah1308
    (#8594)
  - [Server] Annotate comp with design file data. @MUzairS15
    (#8584)
  - update gqlgen and regenerated @nebula-aac (#8575)
  - [chore] removed storybook, and moved to sistent repo
    @nebula-aac (#8568)
  * Features
  - [Docs] Ensuring that all commands has usage examples
    @suhail34 (#8462)
  * Meshery CLI
  - adjusting all unit tests for mesheryctl to increase coverage
    @Philip-21 (#8501)
  - [Docs] Ensuring that all commands has usage examples
    @suhail34 (#8462)
  - [CI] Mesheryctl Meshkit error duplicacy @suhail34 (#8580)
  * Meshery UI
  - Error handling for collaborators extension point @senali-d
    (#8603)
  - Changed all the download notification from Success to info
    @Rajdip019 (#8600)
  - Fix webpack HMR websocket connection @MarioArriaga92 (#8498)
  - Add support for persistence @aabidsofi19 (#8573)
  - Convert patterns/applications file to functional components
    @sudhanshutech (#8574)
  - Convert class to function in performance profile pages
    @sudhanshutech (#8571)
  - converted 404.js to functional component @nebula-aac (#8569)
  - Change all Snackbars to notify in whole codebase @Rajdip019
    (#8516)
  - Bump eslint-config-next from 13.4.9 to 13.4.19 in
    /provider-ui @dependabot (#8559)
  * Maintenance
  - Fix webpack HMR websocket connection @MarioArriaga92 (#8498)
  - Bump eslint-config-next from 13.4.9 to 13.4.19 in
    /provider-ui @dependabot (#8559)
  * Documentation
  - [Docs] Fix spelling errors @FirePing32 (#8605)
  - [Docs] Ensuring that all commands has usage examples
    @suhail34 (#8462)
  - [Docs] Add Component Shape Guide @Boombag0607 (#8570)
- update to 0.6.131:
  * General
  - change the location where binded node info is captured
    @MUzairS15 (#8562)
  - [CI] Swagger docs build failing @suhail34 (#8551)
  * Meshery CLI
  - [Lifecycle] mesheryctl: slim profile with no adapters by
    default @leecalcote (#8566)
  * Meshery UI
  - [UI] Fix issue with button alignment @abhinandanudupa (#8539)
  - [connections] Migrate K8sCtx to Connections @theBeginner86
    (#8321)
  - Bump eslint from 8.46.0 to 8.47.0 in /provider-ui @dependabot
    (#8525)
  - Refactor drawer links @aabidsofi19 (#8558)
  - Bump cypress from 12.17.1 to 12.17.4 in /provider-ui
    @dependabot (#8529)
  - Bump eslint-plugin-cypress from 2.13.3 to 2.14.0 in
    /provider-ui @dependabot (#8523)
  - Meshmodel Browser @UsmanDev09 (#8466)
  - Fixed height consistency in design cards @EraKin575 (#8492)
  - [Notification Center] Refactor EVENT_TYPES and Icons
    @aabidsofi19 (#8546)
  * Bug Fixes
  - [Notification Center] Refactor EVENT_TYPES and Icons
    @aabidsofi19 (#8546)
  * Maintenance
  - Bump eslint from 8.46.0 to 8.47.0 in /provider-ui @dependabot
    (#8525)
  - Bump cypress from 12.17.1 to 12.17.4 in /provider-ui
    @dependabot (#8529)
  - Bump eslint-plugin-cypress from 2.13.3 to 2.14.0 in
    /provider-ui @dependabot (#8523)
  - Fixed email-on-failure job in stable release
    @VaibhavMalik4187 (#8554)
  * Documentation
  - Scrolling error in meshery docs for small screen fixed
    @Aayush987 (#8550)
  - Fixing Documentation issues @thisiskaransgit (#8128)
- there is no release 0.6.130
- update to 0.6.129:
  * General
  - MeshKit v0.6.59 @leecalcote (#8541)
  - Enhance policies endpoints @Freedisch (#8491)
  * Meshery UI
  - fix: fixed background color in meshmodel relationships tab
    @Yana-Gupta (#8549)
  - fix validation and deployment issue for comps marked
    isAnnotaion true @MUzairS15 (#8520)
  * Maintenance
  - Bump gorm.io/gorm from 1.25.2 to 1.25.3 @dependabot (#8536)
  * Documentation
  - [Docs] Remove unncessary file - Kuma.svg @abhinandanudupa
    (#8522)
  - Adding Customization of MeshMap Snapshot in docs @yash37158
    (#8452)
- update to 0.6.128:
  * Meshery CLI
  - Update errorutil in CI to looks for the right server
    directory @nebula-aac (#8517)
  * Maintenance
  - Update errorutil in CI to looks for the right server
    directory @nebula-aac (#8517)
- update to 0.6.127:
  * General
  - [Policies] Evaluation of OPA policies in server. @MUzairS15
    (#8416)
  * Meshery CLI
  - introduce pagination and search by filter name for filter
    list command @narharim (#8258)
  * Meshery UI
  - [UI][Schema] Change comment schema | Fix ImportModal crash in
    extension @Yashsharma1911 (#8514)
  * Documentation
  - [Server] Add server support to share WASM Filters @Chadha93
    (#8274)
- update to 0.6.126:
  * Meshery UI
  - [Notification Center] Add Support for Meshmap and little Ui
    changes @aabidsofi19 (#8510)
  - [UI] Send toaster informational notification upon save of
    design and send to notification center @Chadha93 (#8509)
  - Revert "[UI] Add Qanelas Soft as Global Font" @leecalcote
    (#8504)
- update to 0.6.125:
  * Meshery UI
  - Revert "[UI] Send toaster informational notification upon
    save of design" @leecalcote (#8499)
- update to 0.6.124:
  * General
  - updated link for contributor's journey map @abhijeetgauravm
    (#8476)
  - Add api/system/database/reset endpoint to reset database
    @Aritra8438 (#8433)
  - lastest enhance after meshkit release @Freedisch (#8437)
  - feat: updated smp link in readme and fixed typo
    infrastructure @abhijeetgauravm (#8474)
  - [chore] Update Playground Docker Compose @theBeginner86
    (#8459)
  * Meshery CLI
  - fix: test for delete filter command @Yana-Gupta (#8396)
  * Meshery UI
  - [UI] Send toaster informational notification upon save of
    design @Chadha93 (#8486)
  - [UI] Enhance Notification Center @aabidsofi19 (#8483)
  - import resources from schema, import filters from schema
    @Abhishek-kumar09 (#8097)
  - fix crash due to empty response of filter_resource file
    @sudhanshutech (#8494)
  - [UI] Add Qanelas Soft as Global Font @Chadha93 (#8481)
  - [UI] Connections @senali-d (#8316)
  - [UI] Use name instead of component in service mesh dashboard
    @Yashsharma1911 (#8484)
  - fixed inconsistency in meshery ui @EraKin575 (#8461)
  - Added Connection Stats Charts @aabidsofi19 (#8472)
  - Dry Run Support in Designs And Applications @aabidsofi19
    (#8471)
  - Add mesh version support in Lifecycle management. @MUzairS15
    (#8477)
  - [Extensions] Collaborators: Remove spinner @senali-d (#8464)
  * Maintenance
  - [CI] Update swagger docs workflow for rest api failing in
    edge and stable release @suhail34 (#8488)
  - Updated go mod sync workflow @abdullah1308 (#8489)
  - [CI] Meshkit error workflow committing on pull request
    @suhail34 (#8458)
  * Documentation
  - feat :removed duplication and fixed typo @Ghat0tkach (#8248)
  - Designs docs : meshmodel user guide @parth721 (#8353)
  - endpoints for user's keys @Freedisch (#8267)
- update to 0.6.123:
  * Meshery UI
  - Loader component for collaborators @senali-d (#8457)
- update to 0.6.122:
  * Meshery UI
  - [Extension] Add Collaborator Extension Point @senali-d
    (#8323)
  - Update logs.svg @ritiksaxena124 (#8448)
  - [Performance profile]- fix label on new certificate upload
    @sudhanshutech (#8421)
  * Bug Fixes
  - [bug] Fix cancelled ctx @theBeginner86 (#8453)
  * Maintenance
  - [CI] Workflow update of meshkit error docs @suhail34 (#8451)
  - Added new job to send emails on job failure @VaibhavMalik4187
    (#8449)
  - Update build-and-release-stable.yml @theBeginner86 #8455
  * Documentation
  - [CI] Workflow update of meshkit error docs @suhail34 (#8451)
  - [Extension] Add Collaborator Extension Point @senali-d
    (#8323)
- update to 0.6.121:
  * Meshery UI
  - [Extension] Add Collaborator Extension Point @senali-d
    (#8323)
  - Update logs.svg @ritiksaxena124 (#8448)
  - [Performance profile]- fix label on new certificate upload
    @sudhanshutech (#8421)
  * Bug Fixes
  - [bug] Fix cancelled ctx @theBeginner86 (#8453)
  * Maintenance
  - [CI] Workflow update of meshkit error docs @suhail34 (#8451)
  - Added new job to send emails on job failure @VaibhavMalik4187
    (#8449)
  * Documentation
  - [CI] Workflow update of meshkit error docs @suhail34 (#8451)
  - [Extension] Add Collaborator Extension Point @senali-d
    (#8323)
- update to 0.6.120:
  * General
  - Revert "Revert "Add endpoint to update connection by Id""
    @leecalcote (#8446)
  - Revert "Add endpoint to update connection by Id" @leecalcote
    (#8444)
  - Add endpoint to update connection by Id @abdullah1308 (#8434)
  - add core comp @MUzairS15 (#8435)
  - Update policy_relationship_handler.go @MUzairS15 (#8415)
  * Meshery CLI
  - Show menu in subcommands under mesheryctl system @nebula-aac
    (#8374)
  - Revert "[CI] MeshKit Error Util: duplicate errors causing
    failures" @leecalcote (#8445)
  - Removed extra single quotes from make commands
    @VaibhavMalik4187 (#8383)
  - [CI] MeshKit Error Util: duplicate errors causing failures
    @suhail34 (#8402)
  - [mesheryctl] perf apply docs fix @suhail34 (#8428)
  - Pattern Unit test @Philip-21 (#8324)
  * Meshery UI
  - [lifecycle] Manage Un/Deployment of Meshery Adapters
    @theBeginner86 (#8393)
  - Revert "Leecalcote/templates/go-meshkit" @leecalcote (#8443)
  - Leecalcote/templates/go-meshkit @leecalcote (#8442)
  - fix validate modal light/dark mode color issues
    @sudhanshutech (#8438)
  * Maintenance
  - Revert "Leecalcote/templates/go-meshkit" @leecalcote (#8443)
  - Leecalcote/templates/go-meshkit @leecalcote (#8442)
  * Documentation
  - Revert "Leecalcote/templates/go-meshkit" @leecalcote (#8443)
  - Leecalcote/templates/go-meshkit @leecalcote (#8442)
  - feat: typo fixed 'tags' @abhijeetgauravm (#8431)
  - [mesheryctl] perf apply docs fix @suhail34 (#8428)
- update to 0.6.119:
  * General
  - update comp_updater script @MUzairS15 (#8411)
  - Fix /api/integrations/connections/{connectionKind}
    @abdullah1308 (#8397)
  - Update meshmodel search by name @abdullah1308 (#8249)
  - fix relationships @MUzairS15 (#8409)
  * Meshery CLI
  - fixed context switching abort @EraKin575 (#8392)
  - Shortened the User ID in app list @gopivaibhav (#8395)
  - Add load generator options flag to mesheryctl perf
    @abdullah1308 (#8403)
  * Meshery UI
  - Implement conditional rendering of Model Selector based on
    selected category @ShravaniAK (#8407)
  - Bump tough-cookie and @cypress/request in /provider-ui
    @dependabot (#8404)
  - [UI] - Handled configuration pages responsiveness @UsmanDev09
    (#8408)
  - Bump tough-cookie and @cypress/request in /ui @dependabot
    (#8405)
  - Revert "[UI] Add Connection Stats Chart" @MUzairS15 (#8410)
  - [UI] Add Connection Stats Chart @aabidsofi19 (#8171)
  * Maintenance
  - Bump tough-cookie and @cypress/request in /provider-ui
    @dependabot (#8404)
  - Bump tough-cookie and @cypress/request in /ui @dependabot
    (#8405)
  * Documentation
  - solved the issue of unresponsiveness of header
    @AdityaRaimec22 (#8352)
  - Bump commonmarker from 0.23.9 to 0.23.10 in /docs @dependabot
    (#8413)
- update to 0.6.118:
  * General
  - Remove old components dir @MUzairS15 (#8398)
  * Meshery CLI
  - filter Unit test @Philip-21 (#8111)
  * Meshery UI
  - [UI] Fix MeshModel Chart empty when one of the contructs
    count is 0 @aabidsofi19 (#8388)
  * Bug Fixes
  - [UI] Fix MeshModel Chart empty when one of the contructs
    count is 0 @aabidsofi19 (#8388)
  * Maintenance
  - [chore] bump meshkit to v0.6.52 @MUzairS15 (#8386)
- update to 0.6.117:
  * General
  - [Meshmodel] Restructure file system for meshmodels.
    @MUzairS15 (#8372)
  - [helm] revert to "namespace: {{ .Release.Namespace }}"
    @leecalcote (#8382)
  - Add endpoint for all connections @abdullah1308 (#8356)
  * Features
  - [feat] Add Support for Comments @theBeginner86 (#8315)
  * Meshery CLI
  - [chore] Removed OSM @nebula-aac (#8375)
  - [chore] Fix Filter Upload @theBeginner86 (#8370)
  * Meshery UI
  - [chore] Removed OSM @nebula-aac (#8375)
  - Speed dial color update @Shivam-AfA (#8380)
  - [chore] Fix Filter Upload @theBeginner86 (#8370)
  - Downgrade react-dom to 17.0.2 @aabidsofi19 (#8369)
  - [UI] Added new colors in Theme @Yashsharma1911 (#8366)
  * Documentation
  - Remove multiple instances of Layer5 and fix indentation of
    bulleted list @Aritra8438 (#8361)
  - feat: images are aligned now @abhijeetgauravm (#8326)
  - [Docs] Add Integrations List Docs @Boombag0607 (#8373)
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.116:
  * Meshery CLI
  - Revert "Specify additional specific load generator options in
    mesheryctl perf" @leecalcote (#8363)
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.115:
  * General
  - Update README.md @theBeginner86 (#8358)
  - Fix connection status endpoint @abdullah1308 (#8354)
  - Bump github.com/docker/docker from 20.10.21+incompatible to
    20.10.24+incompatible in /scripts/component_updater
    @dependabot (#8153)
  - update relationship def and policy @MUzairS15 (#8327)
  - [MeshSync] Package update v0.6.11 @leecalcote (#8325)
  * Meshery CLI
  - Specify additional specific load generator options in
    mesheryctl perf @abdullah1308 (#8148)
  * Meshery UI
  - [Performance Profile] - Specify flags in performance profile
    @UsmanDev09 (#8219)
  - [bug] Fix broken filters page @theBeginner86 (#8359)
  - [Meshmodels] - Displaying duplicate components and models
    @UsmanDev09 (#8275)
  - [Responsiveness] - Made Configurations design page responsive
    @UsmanDev09 (#8357)
  - [UI] Added required prop in Publish Modal to publish catalog
    from MeshMap @Yashsharma1911 (#8349)
  - Bump word-wrap from 1.2.3 to 1.2.4 in /ui @dependabot (#8213)
  - Bump @mui/material from 5.13.7 to 5.14.3 in /provider-ui
    @dependabot (#8336)
  - Bump react-dom from 17.0.2 to 18.2.0 in /ui @dependabot
    (#8329)
  - Bump eslint from 8.45.0 to 8.46.0 in /provider-ui @dependabot
    (#8337)
  - Bump @cypress/code-coverage from 3.10.7 to 3.11.0 in
    /provider-ui @dependabot (#8334)
  - Bump @babel/types from 7.21.3 to 7.22.5 in /ui @dependabot
    (#8330)
  - Bump tar from 6.1.12 to 6.1.15 in /ui @dependabot (#8328)
  - Bump next from 13.4.7 to 13.4.12 in /provider-ui @dependabot
    (#8333)
  - Bump @mui/styles from 5.12.0 to 5.14.3 in /ui @dependabot
    (#8331)
  - Bump @mui/icons-material from 5.11.16 to 5.14.3 in
    /provider-ui @dependabot (#8335)
  - Update MeshMap Snapshot Service @Abhishek-kumar09 (#8332)
  * Bug Fixes
  - [bug] Fix broken filters page @theBeginner86 (#8359)
  - [CI] Update Meshery Helm Chart @theBeginner86 (#8355)
  * Maintenance
  - Bump word-wrap from 1.2.3 to 1.2.4 in /ui @dependabot (#8213)
  - Bump @mui/material from 5.13.7 to 5.14.3 in /provider-ui
    @dependabot (#8336)
  - Bump react-dom from 17.0.2 to 18.2.0 in /ui @dependabot
    (#8329)
  - Bump eslint from 8.45.0 to 8.46.0 in /provider-ui @dependabot
    (#8337)
  - Bump @cypress/code-coverage from 3.10.7 to 3.11.0 in
    /provider-ui @dependabot (#8334)
  - Bump github.com/layer5io/service-mesh-performance from 0.3.4
    to 0.6.1 @dependabot (#8338)
  - Bump @babel/types from 7.21.3 to 7.22.5 in /ui @dependabot
    (#8330)
  - Bump tar from 6.1.12 to 6.1.15 in /ui @dependabot (#8328)
  - Bump next from 13.4.7 to 13.4.12 in /provider-ui @dependabot
    (#8333)
  - Bump @mui/styles from 5.12.0 to 5.14.3 in /ui @dependabot
    (#8331)
  - Bump @mui/icons-material from 5.11.16 to 5.14.3 in
    /provider-ui @dependabot (#8335)
  - Bump github.com/onsi/ginkgo/v2 from 2.9.5 to 2.11.0
    @dependabot (#8341)
  - Update MeshMap Snapshot Service @Abhishek-kumar09 (#8332)
  * Documentation
  - [CI] Enhance Edge Release Channel with Versioning @vaibhav-xt
    (#8259)
  - Update MeshMap Snapshot Service @Abhishek-kumar09 (#8332)
* Tue Aug  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.114:
  * General
  - Removed smi section in readme.md file @Modern-artist (#8280)
  - [README] Swap star charts @jamieplu (#8308)
  - add logic to treat some comps special @MUzairS15 (#8306)
  * Meshery CLI
  - [Unit test] delete_test in filter package @Philip-21 (#8220)
  - Added instructions to update error codes @abdullah1308
    (#8251)
  - Removed system checks before login @EraKin575 (#8297)
  * Meshery UI
  - [bug] Fix K8s Ctx Selector @theBeginner86 (#8314)
  - fix display config on row click in filters @sudhanshutech
    (#8281)
  - Remove Meshery Adapter for Meshery Octarine entry from
    adaptersList @supzi-del (#8302)
  * Patterns, Filters, Applications
  - fix display config on row click in filters @sudhanshutech
    (#8281)
  * Bug Fixes
  - [bug] Fix K8s Ctx Selector @theBeginner86 (#8314)
  * Maintenance
  - feat: Removed "above" from label-commenter-config.yml
    @abhijeetgauravm (#8317)
  - [Readme] Swap Slack image @jamieplu (#8309)
  * Documentation
  - description added using CURL @spacemc2 (#8265)
  - [Docs] Update Relationship Screenshots @Boombag0607 (#8320)
  - updated the video with the new one @Debjyoti0404 (#8322)
* Tue Aug  1 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.113:
  * General
  - Add endpoint for connections status @abdullah1308 (#8277)
  - [component-updater-script] update paths for icons for
    remote-provider @theBeginner86 (#8304)
  - Update affiliation on MAINTAINERS table @alphaX86 (#8290)
  * Features
  - [UI] Change switch paradigm for grid and table view
    @duckling69 (#8300)
  * Meshery CLI
  - Refactor/diviz11/mesheryctl-filter-import-update @diviz11
    (#8254)
  - [mesheryctl] Shortened USER ID in mesheryctl filter list
    @kunxl-gg (#8282)
  * Meshery UI
  - [UI] Fix publish modal for meshmap and added type as enum in
    publish modal schema @Yashsharma1911 (#8273)
  - [UI] Change switch paradigm for grid and table view
    @duckling69 (#8300)
  - fix filter update and filter name provided not being
    respected @MUzairS15 (#8283)
  - Fix: remove wildcard check by *, and use full string
    @Abhishek-kumar09 (#8296)
  - [MeshModels] Add support for wildcard versions
    @Abhishek-kumar09 (#8285)
  - Enhancement: Dont crash the UI on RJSF Form Errors
    @Abhishek-kumar09 (#8288)
  * Documentation
  - [MeshModel][Docs] Add supported relationships screenshots
    @Boombag0607 (#8287)
* Thu Jul 27 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.112:
  * Meshery CLI
  - FIXED: [mesheryctl] mesheryctl system check checks wrong
    platform @zakisk (#8272)
  * Meshery UI
  - Add support to provision CRDs/operators. @MUzairS15 (#8255)
  - [OPA] Add namespace-hierarchichal policy @Abhishek-kumar09
    (#7897)
* Wed Jul 26 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.111:
  * General
  - [scripts] fix svgs paths for remote provider components
    generation @theBeginner86 (#8266)
  * Meshery UI
  - [Filters] A quick dirty fix for uploading filters config
    @Abhishek-kumar09 (#7993)
  - [UI] Memoized Charts And Graph Components @aabidsofi19
    (#8217)
  * Documentation
  - Adding [Docs] Meshery Cloud Team Management and Notifications
    @yash37158 (#8212)
* Wed Jul 26 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.110:
  * General
  - update wasm filter metdata @Abhishek-kumar09 (#8252)
  - [chore] Fix go.sum entry @MUzairS15 (#8243)
  - Update hierarchical_inv_wasm_filters.json @MUzairS15 (#8239)
  - remove hardcoded filter name @MUzairS15 (#8236)
  - Bump word-wrap from 1.2.3 to 1.2.4 in /storybook @dependabot
    (#8230)
  * Documentation
  - [Docs] reverting lockfile update @thisiskaransgit (#8237)
  - docs: updated command reference for mesheryctl filter
    @Yana-Gupta (#8235)
* Fri Jul 21 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.109:
  * General
  - [chore] Fix missing remote provider prefs @theBeginner86
    (#8234)
  - [chore] bump meshkit to v0.6.49 @MUzairS15 (#8233)
  - Update go.mod @theBeginner86 (#8231)
  - Use meshkit function @MUzairS15 (#8215)
  - Bump word-wrap from 1.2.3 to 1.2.4 in
    /install/docker-extension/ui @dependabot (#8218)
  - Add duplicate count for meshmodel model, component
    @abdullah1308 (#8168)
  - Changed server request for Publishing Catalog Content
    @Player256 (#8197)
  - Bump meshery-operator version to the latest(v0.6.10) @Aisuko
    (#8187)
  - [Playground] Use Nginx daemon not container @leecalcote
    (#8201)
  - Fix core component not getting updated by component_updater
    script. @MUzairS15 (#8192)
  * Features
  - Common search view for grid and data-table @sudhanshutech
    (#8157)
  * Meshery CLI
  - [mesheryctl] Pattern Subcommand dysfunctional @suhail34
    (#8177)
  - [CI] Adding a make target for mesheryctl docs and add in the
    worflow file @suhail34 (#8185)
  * Meshery UI
  - [CI] fix eslint @theBeginner86 (#8232)
  - Fix visibility bug in catalog @sudhanshutech (#8214)
  - Apply default icon style to all the mui icons
    @Abhishek-kumar09 (#8229)
  - [chore] fix the checkboxes label capitalization in dark mode
    @harkiratsm (#8222)
  - [RJSF] UI enhancement in publish to catalog modal
    @Yashsharma1911 (#8141)
  - Common search view for grid and data-table @sudhanshutech
    (#8157)
  - Updated Performance icon in Meshery UI @vednp (#8189)
  - [Deps]ui and provider ui @leecalcote (#8186)
  - [chore] fix the usage of publish modal @harkiratsm (#8180)
  * Bug Fixes
  - [CI] fix eslint @theBeginner86 (#8232)
  * Maintenance
  - [CI] Send out email in case of meshmodel component
    generation/updater failure. @suhail34 (#8216)
  - [CI] Update playground-cleanup.sh script @theBeginner86
    (#8209)
  - [CI] Job to update REST and GraphQL docs #7956 @suhail34
    (#8076)
  - [CI] Adding a make target for mesheryctl docs and add in the
    worflow file @suhail34 (#8185)
  * Documentation
  - [Docs] Minor MeshModel Changes @Boombag0607 (#8183)
  - Added Build and Release Meeting time and minutes link
    @ranjanmangla1 (#8114)
  - Update meshmodel docs @abdullah1308 (#8206)
  - Bring search bar back @vishalvivekm (#8210)
  - [Docs] Kubernetes installations @leecalcote (#8190)
  - Add Concept Docs for MeshModel @Boombag0607 (#8182)
* Mon Jul 17 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.108:
  * General
  - [Server] API for dynamic component registration @MUzairS15
    (#8132)
  - Fix: the schema doesn't have model name correctly depicted
    @Abhishek-kumar09 (#8155)
  * Meshery CLI
  - Remove mesheryctl filter from experimental @abdullah1308
    (#8169)
  * Meshery UI
  - [chore] custom annotations to grid differently , rjsf custom
    select widget @harkiratsm (#8165)
  * Maintenance
  - chore: update link to wireframes and designs for Meshery UI
    in Figma @rupeshshandilya (#8166)
  - Add SVG in meshmodel docs @Boombag0607 (#8160)
  - [CI] Update workflow usage of component_updater script
    @theBeginner86 (#8152)
  * Documentation
  - Fixing intra-page anchor issue in meshery docs @yash37158
    (#8151)
  - [mesheryctl] Docs: Remove apply, add import, promote from
    experimental @leecalcote (#8170)
  - Add SVG in meshmodel docs @Boombag0607 (#8160)
* Thu Jul 13 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.107:
  * General
  - Bump semver from 6.3.0 to 6.3.1 in
    /install/docker-extension/ui @dependabot (#8131)
  - [Extensions] Remote Provider: Model and Category Registration
    @theBeginner86 (#8145)
  - Bump semver from 5.7.1 to 5.7.2 in /storybook @dependabot
    (#8140)
  - Add unique count to meshmodel models, components
    @abdullah1308 (#8139)
  - Update hierarchical-wallet.rego @MUzairS15 (#8136)
  - fix user prefs @MUzairS15 (#8121)
  - Update package-lock.json @Ritish134 (#8113)
  - fix * available as version @MUzairS15 (#8123)
  * Meshery CLI
  - Created mesheryctl filter import and mesheryctl filter audit
    @abdullah1308 (#8063)
  - [mesheryctl] App subcommand list and view dysfunctional
    @suhail34 (#8118)
  - Fix/filter logs @jinronga (#8067)
  * Meshery UI
  - Bump @mui/lab from 5.0.0-alpha.128 to 5.0.0-alpha.135 in /ui
    @dependabot (#8102)
  - Bump @storybook/react from 7.0.7 to 7.0.26 in /ui @dependabot
    (#8100)
  - Bump semver from 6.3.0 to 6.3.1 in /provider-ui @dependabot
    (#8135)
  - [UI] Filters Table : Add Save Button To Filter Edit Modal
    @aabidsofi19 (#8146)
  - Fix recursive API calls when multiple page changes
    immediately in configurations @HarshDobariya79 (#8032)
  - Fix public tag filter in dark mode @VishwaRaval247 (#8134)
  - Bump semver from 5.7.1 to 5.7.2 in /ui @dependabot (#8133)
  - [UI] Fixed pagination issue in database overview @Meyazhagan
    (#8064)
  - fixed extension infinite loading issue @vaibhav135 (#8058)
  - [UI] Added filter config | CU-#85ztdxf0d @vaibhav135 (#8107)
  - [UI] Navigator : Remove Conformance and fix extentions
    indentation @aabidsofi19 (#8127)
  - removing unwanted console from rjsf #85zteqydm @duckling69
    (#8120)
  - [UI] Add MeshModel Charts in Dashboard @aabidsofi19 (#8110)
  - Bump @mui/material from 5.11.15 to 5.13.7 in /provider-ui
    @dependabot (#8112)
  - Fix/filter logs @jinronga (#8067)
  - [UI] MesheryFilters/FilterCard : Add Download Button to
    Filter Card @aabidsofi19 (#8073)
  * Maintenance
  - Bump @mui/lab from 5.0.0-alpha.128 to 5.0.0-alpha.135 in /ui
    @dependabot (#8102)
  - Bump golang.org/x/oauth2 from 0.8.0 to 0.10.0 @dependabot
    (#8089)
  - Bump @storybook/react from 7.0.7 to 7.0.26 in /ui @dependabot
    (#8100)
  - Bump semver from 6.3.0 to 6.3.1 in /provider-ui @dependabot
    (#8135)
  - [Docs][WIP] Add contribution docs for MeshModel @Boombag0607
    (#8119)
  - Bump semver from 5.7.1 to 5.7.2 in /ui @dependabot (#8133)
  - Bump @mui/material from 5.11.15 to 5.13.7 in /provider-ui
    @dependabot (#8112)
  * Documentation
  - Add Details/Summary for General Contribution Flow @ankur0904
    (#7838)
  - [Docs] Fixed responsiveness @Ghat0tkach (#8117)
  - Table display issue resolved @jayeshuk (#8068)
  - [Docs][WIP] Add contribution docs for MeshModel @Boombag0607
    (#8119)
  - Fixed [UI] table in meshery docs @yash37158 (#8060)
  - Update architecture.md @abdellani (#8116)
  - Closes #8050 Added Build and Release: Stable Release Channel
    now includes automate… @ranjanmangla1 (#8115)
* Sun Jul  9 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.106:
  * Meshery UI
  - [chore] fix import error @theBeginner86 (#8106)
  * Maintenance
  - [chore] fix import error @theBeginner86 (#8106)
* Sun Jul  9 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.105:
  * General
  - Bump tough-cookie from 4.0.0 to 4.1.3 in
    /install/docker-extension/ui @dependabot (#8099)
  - Helm Chart to have the "meshery" namespace @Freedisch (#8044)
  - [Server] Fix published filters not appearing @Meyazhagan
    (#8083)
  - [Meshmodel] Update WASMFilter component @MUzairS15 (#8085)
  - [Meshmodel] Add support for
    x-kubernetes-preserve-unknown-fields @MUzairS15 (#8081)
  - [Meshmodel] Add new relationship inventory_wallet. @MUzairS15
    (#8088)
  - Revert "[Maintenance] Component Updater: Go package upgrades"
    @MUzairS15 (#8036)
  - Revert "[Maintenance] Go package upgrades" @leecalcote
    (#8030)
  - Storybook drawer component @senali-d (#7967)
  * Meshery CLI
  - Remove apply subcommand from mesheryctl exp filter
    @Boombag0607 (#8012)
  - [mesheryctl] Filter: View not accepting name; requiring ID?
    @suhail34 (#8061)
  - [mesheryctl] Filter: List subcommand dysfunctional @suhail34
    (#8033)
  * Meshery UI
  - [UI] Filter publish, unpublish, clone @Chadha93 (#8035)
  - Bump eslint-config-next from 13.2.4 to 13.4.9 in /provider-ui
    @dependabot (#8101)
  - [chore] fix grid view action btns @theBeginner86 (#8103)
  - Bump @babel/eslint-parser from 7.21.8 to 7.22.7 in
    /provider-ui @dependabot (#8075)
  - Bump cypress from 12.15.0 to 12.16.0 in /provider-ui
    @dependabot (#8018)
  - [e2e Tests] error in github workflow by increasing the
    timeout in the test @codingmickey (#8082)
  - Fix: Use Publish Modal and send it to extensions
    @Abhishek-kumar09 (#8098)
  - Fix filter page crash on publishing filter @Yashsharma1911
    (#8094)
  - [fix] add custom textarea to have uniformity of textfield
    across rjsf @harkiratsm (#8086)
  - Add Support for Credentials @harkiratsm (#7634)
  - Bump @emotion/react from 11.11.0 to 11.11.1 in /provider-ui
    @dependabot (#8014)
  - [UI] Settings: Added white background in Metrics
    @Yashsharma1911 (#8062)
  - [Performance] Add support to use SSL certs for load testing.
    @MUzairS15 (#8023)
  - [UI] - Added count to tabs for meshmodel browser @UsmanDev09
    (#8053)
  - [chore] Fix eslint Err @theBeginner86 (#8057)
  - Bump lint-staged from 13.1.0 to 13.2.3 in /ui @dependabot
    (#8025)
  - feat: add a custom native select widget in rjsf @harkiratsm
    (#7930)
  - added adapters in extensions @vaibhav135 (#8013)
  - Bump autoprefixer from 10.4.13 to 10.4.14 in /ui @dependabot
    (#8026)
  - Bump @fortawesome/free-solid-svg-icons from 6.2.0 to 6.4.0 in
    /ui @dependabot (#8027)
  * Patterns, Filters, Applications
  - update core wasm filter svg with height and width
    @Abhishek-kumar09 (#8096)
  - [Filters] Store filter as comp instance @MUzairS15 (#7963)
  - [chore] Fix Download of Filters @theBeginner86 (#8055)
  * Maintenance
  - Bump eslint-config-next from 13.2.4 to 13.4.9 in /provider-ui
    @dependabot (#8101)
  - Update meshmodel issue template with label @leecalcote
    (#8105)
  - [chore] fix grid view action btns @theBeginner86 (#8103)
  - Bump @babel/eslint-parser from 7.21.8 to 7.22.7 in
    /provider-ui @dependabot (#8075)
  - Bump cypress from 12.15.0 to 12.16.0 in /provider-ui
    @dependabot (#8018)
  - Bump @emotion/react from 11.11.0 to 11.11.1 in /provider-ui
    @dependabot (#8014)
  - [chore] Fix Download of Filters @theBeginner86 (#8055)
  - [chore] Fix eslint Err @theBeginner86 (#8057)
  - Bump lint-staged from 13.1.0 to 13.2.3 in /ui @dependabot
    (#8025)
  - Bump google.golang.org/grpc from 1.55.0 to 1.56.1 @dependabot
    (#8020)
  - Bump github.com/prometheus/client_golang from 1.15.1 to
    1.16.0 @dependabot (#8021)
  - Bump autoprefixer from 10.4.13 to 10.4.14 in /ui @dependabot
    (#8026)
  - Bump @fortawesome/free-solid-svg-icons from 6.2.0 to 6.4.0 in
    /ui @dependabot (#8027)
  - [CI] Stable Release Channel: Reference Git Tag Name
    @leecalcote (#8011)
  * Documentation
  - changes in elements.scss @Rajivkumawat3 (#8065)
  - [Docs] Remove Ruby version mandate @leecalcote (#8046)
  - DOCS: update contributing guide with one addition of error
    while running make server @samyakshah3008 (#7961)
* Mon Jul  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.104:
  * General
  - [Maintenance] Component Updater: Go package upgrades
    @leecalcote (#8008)
  - [Maintenance] Go package upgrades @leecalcote (#8007)
  * Features
  - [CI] Stable Release Channel: Release Notes Mailer @leecalcote
    (#8010)
  * Meshery CLI
  - added tests for healthcheck @Freedisch (#7896)
  * Meshery UI
  - Reusable Tooltip and added missing tooltips @sudhanshutech
    (#7615)
  - Added a white helm logo for dark mode @souravpy (#7598)
  - Bump @paciolan/remote-component from 2.12.1 to 2.13.0 in /ui
    @dependabot (#7244)
  - Published icon fix in design card @duckling69 (#7808)
  - fix-rows-per-page-in-mesh-model-summary @HarshDobariya79
    (#7988)
  - Fix: crash of Form on ui:widget checkbox @Abhishek-kumar09
    (#7997)
  * Maintenance
  - [CI] Stable Release Channel: Release Notes Mailer @leecalcote
    (#8010)
  - Bump @paciolan/remote-component from 2.12.1 to 2.13.0 in /ui
    @dependabot (#7244)
  - [CI] Move Goreleaser to latest version - Update
    build-and-release-stable.yml @leecalcote (#8006)
  - Using conditions to control job execution [Fixes #7754]
    @anshgoyalevil (#7787)
  - [chore] feat: add test plan sheets @Ghat0tkach (#7836)
  - [Governance] Document update to include role descriptions
    @leecalcote (#7968)
  * Documentation
  - [Docs] Fix position of buttons in the code snippets on quick
    start page. @chinu-anand (#7264)
  - [Docs] Documentation Enhancement @thisiskaransgit (#7914)
* Mon Jul  3 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.103 (skipping .101 and .102, that do not exist):
  * General
  - [CI] mesheryctl: replace goreleaser deprecations @leecalcote
    (#8004)
  * Meshery UI
  - [chore] Add save button in edit modal for filters
    @theBeginner86 (#7992)
  - [UI] Remove deploy/undeploy from UI @theBeginner86 (#7991)
  - [UI] Add support to download, publish, unpublish, and clone
    wasm support @Chadha93 (#7969)
  * Maintenance
  - Fix: goreleaser halting the release process @Abhishek-kumar09
    (#8003)
  - Bump github.com/jinzhu/copier from
    0.0.0-20190924061706-b57f9002281a to 0.3.5 @dependabot
    (#7942)
* Fri Jun 30 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.10a:
  * Meshery CLI
  - Fix operator check in system check @alphaX86 (#7977)
  - [Filters] Fix wasm filter binary upload issues
    @Abhishek-kumar09 (#7975)
  * Meshery UI
  - [bug] Fix GraphQL Query for Catalog content @theBeginner86
    (#7985)
  - [UI] Dark mode toggle switch text fix in user preferences
    section @HarshDobariya79 (#7962)
  * Patterns, Filters, Applications
  - [Filters] Add Support For Unpublish Filters in Server
    @theBeginner86 (#7970)
  * Bug Fixes
  - [bug] Fix GraphQL Query for Catalog content @theBeginner86
    (#7985)
  * Maintenance
  - [CI] Update build-ui-and-server.yml @theBeginner86 (#7987)
  - [CI] Update build-ui-and-server.yml @theBeginner86 (#7986)
  * Documentation
  - [Docs] Meshery Operator Update @leecalcote (#7983)
  - [Filters] Add Support For Unpublish Filters in Server
    @theBeginner86 (#7970)
* Thu Jun 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.99:
  * General
  - [MeshModel] Update relationship schema @MUzairS15 (#7966)
  - Added tabs component to storybook @senali-d (#7860)
  - [Filters] Change filter file download endpoint @MUzairS15
    (#7964)
  - [Remote Provider] Support for pagesize and count
    @abdullah1308 (#7892)
  - Update WASMFilter.json @MUzairS15 (#7959)
  - [MeshModel] Add WASM Filter component @MUzairS15 (#7955)
  - [MeshModel] Add WASM Filter as a core component. @MUzairS15
    (#7929)
  * Meshery CLI
  - Resource endpoints audit @abdullah1308 (#7917)
  - Parsing the relative path correctly @suhail34 (#7951)
  * Meshery UI
  - Resource endpoints audit @abdullah1308 (#7917)
  - Bump relay-compiler from 14.1.0 to 15.0.0 in /ui @dependabot
    (#7945)
  - Fix dropdown input border color in dark mode @HarshDobariya79
    (#7923)
  - Bump @cypress/code-coverage from 3.10.1 to 3.10.7 in /ui
    @dependabot (#7935)
  - Bump cypress from 12.9.0 to 12.15.0 in /provider-ui
    @dependabot (#7941)
  - Bump @emotion/server from 11.10.0 to 11.11.0 in /provider-ui
    @dependabot (#7936)
  - Bump webpack-cli from 5.0.1 to 5.1.4 in /ui @dependabot
    (#7937)
  - Bump next from 13.3.4 to 13.4.7 in /provider-ui @dependabot
    (#7938)
  - Bump eslint-plugin-cypress from 2.13.2 to 2.13.3 in
    /provider-ui @dependabot (#7944)
  - Bump eslint from 8.39.0 to 8.43.0 in /provider-ui @dependabot
    (#7934)
  * Maintenance
  - Bump relay-compiler from 14.1.0 to 15.0.0 in /ui @dependabot
    (#7945)
  - Bump @cypress/code-coverage from 3.10.1 to 3.10.7 in /ui
    @dependabot (#7935)
  - Bump cypress from 12.9.0 to 12.15.0 in /provider-ui
    @dependabot (#7941)
  - Updated redocly workflow to update swagger files
    @abdullah1308 (#7957)
  - Bump @emotion/server from 11.10.0 to 11.11.0 in /provider-ui
    @dependabot (#7936)
  - Bump webpack-cli from 5.0.1 to 5.1.4 in /ui @dependabot
    (#7937)
  - Bump github.com/spf13/viper from 1.15.0 to 1.16.0 @dependabot
    (#7940)
  - Bump next from 13.3.4 to 13.4.7 in /provider-ui @dependabot
    (#7938)
  - Bump eslint-plugin-cypress from 2.13.2 to 2.13.3 in
    /provider-ui @dependabot (#7944)
  - Bump golang.org/x/oauth2 from
    0.0.0-20221014153046-6fdb5e3db783 to 0.9.0 in
    /scripts/component_generation @dependabot (#7947)
  - Bump eslint from 8.39.0 to 8.43.0 in /provider-ui @dependabot
    (#7934)
  - Bump google.golang.org/api from 0.103.0 to 0.128.0 in
    /scripts/component_generation @dependabot (#7948)
  - Bump github.com/layer5io/meshkit from 0.6.37 to 0.6.46 in
    /scripts/component_generation @dependabot (#7949)
  - Bump github.com/layer5io/meshkit from 0.6.38 to 0.6.46 in
    /scripts/component_updation @dependabot (#7946)
  - Change ruby version and Adapter Documentation @Boombag0607
    (#7933)
  * Documentation
  - Resource endpoints audit @abdullah1308 (#7917)
  - Change ruby version and Adapter Documentation @Boombag0607
    (#7933)
* Thu Jun 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.98:
  * General
  - Add config attribute to meshery filter @MUzairS15 (#7910)
  * Meshery UI
  - [UI]: style fix of few components in dark theme
    @samyakshah3008 (#7907)
  - Bump @rjsf/material-ui from 5.8.1 to 5.8.2 in /ui @dependabot
    (#7906)
  - Refactor/dashboard Remove Connection Status Section
    @aabidsofi19 (#7881)
  - Extentions/GitHub/meshmap : Add GitHub Action for MeshMap
    Snapshot @aabidsofi19 (#7888)
  - Fix bug in flipcard for filters @sudhanshutech (#7911)
  - upgrade rjsf -> 5.8.1 @harkiratsm (#7901)
  - [UI]: Fix responsiveness of profile card for mobile view
    @samyakshah3008 (#7895)
  - [UI] RJSF Fixes styles for "name" and "namespace" input
    fields labels @Chadha93 (#7889)
  - refactor: replaced CreateTable with CreateSelect @vaibhav135
    (#7884)
  - [UI] Fixes Notification Center Sneak Peak Behavior onClick
    @Chadha93 (#7886)
  - Database summary - Add table size/record count to System
    Reset screen @Meyazhagan (#7686)
  - fix: remove mapping navigator @Udit-takkar (#7806)
  * Patterns, Filters, Applications
  - Fix Cytoscape-to-design conversion process @MUzairS15 (#7922)
  * Bug Fixes
  - Fix bug in flipcard for filters @sudhanshutech (#7911)
  * Maintenance
  - [CI] Update build-and-release-edge.yml @theBeginner86 (#7927)
  - [CI] Update build-and-release-edge.yml @theBeginner86 (#7926)
  - [CI] Update build-and-release-edge.yml @theBeginner86 (#7925)
  - Bump @rjsf/material-ui from 5.8.1 to 5.8.2 in /ui @dependabot
    (#7906)
  - [CI] Support Edge Releases with Remote Provider
    @theBeginner86 (#7913)
  - Update MeshMap-Snapshot workflow to v0.0.5 @MUzairS15 (#7899)
  - fix: remove mapping navigator @Udit-takkar (#7806)
  - [Update Dockerfile] Add comment for future reference
    @Abhishek-kumar09 (#7876)
  * Documentation
  - Adding Catalog page in docs @yash37158 (#7732)
  - [CI] GraphQL: Docs Build Target @leecalcote (#7924)
  - Server.go file missing #7887 @vaibhav-xt (#7902)
  - fixed: meshery-docs hover tabs and focus on sidebar option
    @vaibhav135 (#7831)
  - [Docs] Initialize Extension's user facing documentation |
    CU-85zrzt5fg @Chadha93 (#7807)
* Thu Jun 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.97:
  * General
  - Changed docs for catalog APIs @abdullah1308 (#7882)
  - Fixed unmarshal error due to catalog API change @abdullah1308
    (#7875)
  - fix: Return error instead of nil client connection in gRPC
    err @Revolyssup (#7878)
  - fix crash in docker env due to GLIBC_2.34 not found
    @MUzairS15 (#7873)
  * Maintenance
  - add workflow dispatch for edge-release action @MUzairS15
    (#7874)
* Thu Jun 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.96:
  * General
  - Update nighthawk binary verison @MUzairS15 (#7872)
  * toolbox Maintenance
  - Update cncf-playground-deploy-meshery.yaml @leecalcote
    (#7871)
* Thu Jun 29 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.95:
  * General
  - [performance] add support for labels @MUzairS15 (#7870)
  - policies: Fix the detection of the relationship in existing
    policy @Abhishek-kumar09 (#7864)
  * Meshery CLI
  - [Mesheryctl] Support tailing logs in Kubernetes platform
    @Meyazhagan (#7801)
  - Change adapter API callback argument for mesheryctl check
    @alphaX86 (#7862)
  * Meshery UI
  - [Catalog] make all the fields required in the RJSF form while
    submitting the catalog request @Abhishek-kumar09 (#7868)
  - [UI] - disable deploy and undeploy @UsmanDev09 (#7858)
  * Maintenance
  - Bump github.com/jarcoal/httpmock from 1.2.0 to 1.3.0
    @dependabot (#7776)
  - [CI] Only release when called by stable release workflow
    @leecalcote (#7855)
  * Documentation
  - updated architecture page @thisiskaransgit (#7842)
* Wed Jun 28 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.94:
  * Meshery UI
  - [Fix GQL] add the gql subscriptions @Abhishek-kumar09 (#7857)
* Wed Jun 28 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 0.6.93:
  * General
  - [Docker Extension] Contributor instructions @leecalcote
    (#7837)
  - [Server] Enhance Kubernetes missing context error message
    @leecalcote (#7852)
  * Meshery UI
  - Bump relay-runtime from 14.1.0 to 15.0.0 in /ui @dependabot
    (#7773)
  - [Performance] revert the subscription delete change
    @Abhishek-kumar09 (#7853)
  - fix settings page title is not updating @Meyazhagan (#7793)
  * Maintenance
  - Bump relay-runtime from 14.1.0 to 15.0.0 in /ui @dependabot
    (#7773)
  - Update cncf-playground-deploy-meshery.yaml @leecalcote
    (#7854)
* Wed Jun 28 2023 kastl@b1-systems.de
- Update to version 0.6.92:
  * General
  - [performance] Final changes for nighthawk @MUzairS15 (#7847)
  - [Performance] fix nighthawk @MUzairS15 (#7846)
  - [chore] Update API for auto archive meshery server
    @theBeginner86 (#7719)
  - [chore] Error codes cleanup @nebula-aac (#7789)
  * Meshery CLI
  - Add golden files back, because they are required by the other
    pakcages' test cases @Aisuko (#7834)
  * Meshery UI
  - [Performance] Fix issues with Performance profiles
    @Abhishek-kumar09 (#7830)
  - [Catalog] Support Unpublish Catalog Content @theBeginner86
    (#7753)
  * Bug Fixes
  - [bug] Remove False check for ValidPatternfile @theBeginner86
    (#7835)
  * Maintenance
  - [chore] Update APIs @theBeginner86 (#7844)
  - trigger workflow run on Pull request @Abhishek-kumar09
    (#7841)
  - change permission to test the action yaml @Abhishek-kumar09
    (#7840)
  - [Snapshot] test on pull_request target @Abhishek-kumar09
    (#7839)
  - [Snapshot Action] Update MeshMap Snapshot github action
    @Abhishek-kumar09 (#7833)
  - Bump github.com/prometheus/common from 0.42.0 to 0.44.0
    @dependabot (#7780)
  - [playground] Adding workflow to Update K8s Cleanup Script
    @suhail34 (#7825)
  * Documentation
  - [Catalog] Support Unpublish Catalog Content @theBeginner86
    (#7753)
  - [chore] Update APIs @theBeginner86 (#7844)
* Wed Jun 28 2023 kastl@b1-systems.de
- Update to version 0.6.91:
  * General
  - Added status to connection @abdullah1308 (#7814)
  - [Performance] Fix NightHawk load generator @MUzairS15 (#7832)
  - [events] Track SystemID @theBeginner86 (#7802)
  - [Performance] Nighthawk: Upgrade to v0.7.0 @leecalcote
    (#7826)
  - Remove core model reference from the relationship json
    @Abhishek-kumar09 (#7822)
  - fix golang-ci lint test @ayushthe1 (#7810)
  - Add Paper component to storybook @senali-d (#7809)
  - [playground] Update docker based deployment @theBeginner86
    (#7757)
  - [Devops] Updated the nginx.conf @kunal-gg (#7747)
  - fix: check if the pattern upload, is valid @harkiratsm
    (#7784)
  - Add PITS Global Data Recovery Services in the list of
    adopters @ghost (#7785)
  * Meshery CLI
  - Update filter usage in docs @alphaX86 (#7824)
  - [mesheryctl] Fix Preflight Check for Remote Endpoints
    @PiyushRaj927 (#7737)
  - feat: make test cases in for utils more simple and
    effectively @Aisuko (#7783)
  * Meshery UI
  - [CI] Fix ESOCKETTIMEDOUT intermittent CI run cypress settings
    and user pref integration tests failures @MarioArriaga92
    (#7829)
  - Bump @storybook/addon-styling from 0.3.2 to 1.0.8 in /ui
    @dependabot (#7772)
  - Bump @babel/eslint-parser from 7.19.1 to 7.21.8 in
    /provider-ui @dependabot (#7771)
  - [bug] Fix Dereferencing bug @theBeginner86 (#7819)
  - Bump @emotion/react from 11.10.8 to 11.11.0 in /provider-ui
    @dependabot (#7774)
  - Bump @cypress/code-coverage from 3.10.0 to 3.10.7 in
    /provider-ui @dependabot (#7777)
  - Meshery Management Page: Fixes Dark Mode Dialog Bug
    @ciradu2204 (#7707)
  - Removing one extra closing bracket from the README.md
    @yuvrajrathva (#7786)
  - Bump @emotion/styled from 11.10.6 to 11.11.0 in /provider-ui
    @dependabot (#7778)
  - Bump start-server-and-test from 1.15.3 to 2.0.0 in
    /provider-ui @dependabot (#7779)
  - Bump @emotion/styled from 11.10.5 to 11.11.0 in /ui
    @dependabot (#7782)
  * Bug Fixes
  - [bug] Fix Dereferencing bug @theBeginner86 (#7819)
  * Maintenance
  - Bump @storybook/addon-styling from 0.3.2 to 1.0.8 in /ui
    @dependabot (#7772)
  - Bump @babel/eslint-parser from 7.19.1 to 7.21.8 in
    /provider-ui @dependabot (#7771)
  - [CI] Add golangci.yml for ignore file @Aisuko (#7820)
  - Update cncf-playground-reset.yaml @Revolyssup (#7813)
  - Update meshmodel issue template @leecalcote (#7812)
  - Fix failing cluster cleanup workflow @Revolyssup (#7799)
  - [MeshModel] add references to Meshmodel template @MUzairS15
    (#7811)
  - Bump github.com/onsi/gomega from 1.23.0 to 1.27.7 @dependabot
    (#7781)
  - Bump @emotion/react from 11.10.8 to 11.11.0 in /provider-ui
    @dependabot (#7774)
  - Bump @cypress/code-coverage from 3.10.0 to 3.10.7 in
    /provider-ui @dependabot (#7777)
  - Bump @emotion/styled from 11.10.6 to 11.11.0 in /provider-ui
    @dependabot (#7778)
  - Bump start-server-and-test from 1.15.3 to 2.0.0 in
    /provider-ui @dependabot (#7779)
  - Bump @emotion/styled from 11.10.5 to 11.11.0 in /ui
    @dependabot (#7782)
  - feat: make test cases in for utils more simple and
    effectively @Aisuko (#7783)
  * Documentation
  - Update filter usage in docs @alphaX86 (#7824)
  - Playground page @goldfishdolphin (#7763)
  - [Docs] Broaden description of managed infra @jamieplu (#7798)
  - Connections crud @Azanul (#7581)
* Wed Jun 28 2023 kastl@b1-systems.de
- Update to version 0.6.90:
  * Adapters Component added
  * Add Meshery Extensions Issue_Template
  * Add test cases for closest_arg
  * Add two test cases for meshery auth
  * Added a helper function to debounce when searching
  * Added a tab to display relationships
  * Added an endpoint for fetching relationships
  * Added constants for referencing components, models,
    relationships
  * Change Contributor Reference
  * Delete a file accidentally pushed to the PR
  * Fix eslint warning typeof warning
  * Fix no-useful test case
  * Inplemented search functionality and a tab to display
    relationships
  * New Meshmodel components generated
  * Remove no useful test cases and add new testcase
  * Update config.yml
  * Update docs/pages/concepts/architecture/meshsync.md
  * Update install/playground/docker/nginx.conf
  * [Docs] Release Notes for Meshery
  * [Docs] Test status of adapter
  * add endpoint to download the application with :id
  * add endpoint to download the patterns
  * add theme color reference
  * added service for playground using metallb
  * chore: fix desc
  * feat: add Beta badge on meshmap title
  * fix incorrect API for user prefs
  * fix the content-type and add support to download for design
  * fix the key-spacing error
  * latest discussion data files added
  * meshsync update documented
  * move dark mode under preferences
  * no error from platform detection
  * platform detection independent of DOCKER_HOST
  * rm console.log
  * styling changes
  * unused 2nd var
  * update app.js in meshery/ui/themes/
  * update defaultTheme to dark
  * update nginx.conf to upgrade http to https
  * update theme colors
  * use the download endpoint to mesheryUI
* Thu May 25 2023 kastl@b1-systems.de
- Update to version 0.6.89:
  * New Meshmodel components generated
  * latest discussion data files added
  * skip some e2e tests until fixed
  * remove unused comments
  * fix: publish dashboard component
  * add missing restart policy
  * add policies in docker images
  * New Meshmodel components generated
  * latest discussion data files added
  * Update server/internal/graphql/resolver/schema.resolvers.go
  * save and delete for grid view
  * Fixed import path
  * New Meshmodel components generated
  * latest discussion data files added
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * Add subsection for index
  * new topo
  * adding docker-compose file for 01 server
  * display topology
  * update for single node k8s cluster
  * New Meshmodel components generated
  * latest discussion data files added
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * updated file
  * feat: updated fille
  * feat: added sidebar menu  image
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * New Meshmodel components generated
  * latest discussion data files added
  * remove some dubugging logs
  * lock and unlock struct map using mutex
  * Fix GrapqhQL subscription memory leak
  * Modify CLI guide for docs
  * nginx config
  * fix lint
  * New Meshmodel components generated
  * latest discussion data files added
  * lifecycle graphql req alias, more mesh adapter url data-cy and
    anon user stats retries
  * fix 3
  * add support for query param in remote provider
  * emfore query param in default local provider
  * enfore query params in server handler
  * add support for query param to fetch all users
  * remove unused
  * enhanc-2
  * enhancements
  * Update ui/components/MesheryApplications/ApplicationsCard.js
  * added dark mode enhancements
  * Updated go.mod and go.sum
  * Added padding to the options
  * Update readme.md
  * New Meshmodel components generated
  * latest discussion data files added
  * feat:Added new page in Docs
  * add network policy as a relationship
  * Removed config file accidently pushed to this PR
  * Removed config file accidently pushed to this PR
  * Added a margin
  * Added a z-index value to the selector so that it does not push
    the content
  * Removed button
  * Changed button position
  * Added a margin
  * latest discussion data files added
  * Fixed pagination issue in meshery design page
  * Update meshkit version
  * Fixed swagger docs for meshmodel api
  * [Docs] Release Notes for Meshery
  * timeouts
  * add data-cy for mesh adapter url element
  * update
  * updated pref route
  * removed consol
  * e2e test
  * Updated meshkit version
  * Update comments for handlers returning total_count
  * Fix linting in server/handlers
  * Fix search and add counts to meshmodel APIs
  * fix build failure
  * Update ui/components/MesherySettings.js
  * Update ui/components/MesherySettings.js
  * Update ui/components/MesherySettings.js
  * Removed comments
  * Removed console.log and renamed constructs
  * Implemented the logic for rendering components and models
  * Commented the code that is no longer used
  * Added 2 new endpoints
  * fix 2
  * fix 1
  * Changed patternServiceForm header background
  * fixed eslint errors
  * Fix dark mode issue in create pattern setting accordion
  * Made performance card text dark mode suportable
  * Tabs of notification now supports dark mode
  * Update .github/workflows/label-tweet.yml
  * Update .github/workflows/label-tweet.yml
  * Updated the status and token names
  * consumer-key and            consumer-secret added to org
  * Updated CI for PR and maintainers
  * Restricted action to members
  * Action to tweet when labeled
* Thu May 18 2023 kastl@b1-systems.de
- Update to version 0.6.88:
  * New Meshmodel components generated
  * latest discussion data files added
  * minor change
  * fix: mui datatables warning for scrollMaxHeight
  * fix gloang ci lint
  * update go mod and sum
  * use latest meshkit
  * Updated the application icon with the one from figma files
  * New Meshmodel components generated
  * latest discussion data files added
  * New Meshmodel components generated
  * latest discussion data files added
  * lint fix golang
  * fix UI lint
  * fix eslint
  * lint fix
  * New Meshmodel components generated
  * rm harcoding of remote provider API, instead use capability
  * gen docs
  * add missing API summary
  * gen docs
  * add support for query param in docs
  * latest discussion data files added
  * gen docs
  * add annotation and create modal for docs
  * add support for remote_provider and define capabilities const
  * add new /api/identity/users API
  * removed
  * New Meshmodel components generated
  * latest discussion data files added
  * combine workflows
  * meshery-playground-reset
  * Update community.md
  * Bump github.com/docker/distribution
  * helm logo dark mode
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * Adapters Component added
  * New Meshmodel components generated
  * latest discussion data files added
  * redoc html
  * added custom template
  * Bump github.com/docker/distribution in
    /scripts/component_updation
  * Bump github.com/docker/distribution in
    /scripts/component_generation
  * push the swagger changes
  * New Meshmodel components generated
  * latest discussion data files added
  * [Docs] Update mesheryctl docs
  * dark-mode-color-extensions-ref
  * Deleted previous stories in ui directory
  * Deleted previous Avatar components inside ui directory
  * Added Avatar Component inside stories
  * Created an Avatar component for storybook
  * fix table view
  * use text/plain for fitlers
  * pass type of config
  * New Meshmodel components generated
  * latest discussion data files added
  * mionr: rename handler function
  * Update README.md as per review
  * move the policy handler logic to backend, pick the directory,
    add meshkit error code
  * Update node version in README.md
  * New Meshmodel components generated
  * latest discussion data files added
  * Created an Avatar component for storybook
  * add id to meshmap traits
  * application-to-design-conversion: add ID to each component
  * comments: add more comments to go funcs
  * handlers: refactor json marshalling response obj
  * handlers: refactor to throw error on response header
  * correct opa policy logic
  * New Meshmodel components generated
  * latest discussion data files added
  * Refactor operator disabling in meshconfig
  * New Meshmodel components generated
  * latest discussion data files added
  * New Meshmodel components generated
  * latest discussion data files added
  * add api policy in the server router
  * put service port in network policy
  * put service port in network policy
  * Policy handler returning the list of policies together
  * crash-fix
  * New Meshmodel components generated
  * latest discussion data files added
  * update rego policy, use not has_key, add more comments
  * Update the rego policy to be more accurate to establish
    relationships based on port mapping
  * Update mesheryctl/internal/cli/root/root.go
  * Fix evaluation engine and show evaluation result as o/p
  * Duplicate cypress tag FIX
  * OPA: draft: initialise OPA policy evaluation engine
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * Adapters Component added
  * New Meshmodel components generated
  * latest discussion data files added
  * created code editor story
  * Fix concurrent map writes #7386
  * removed console.log
  * Tooltip added for each adapter in settings#meshmodel-summary
  * Revert "uncomment include files"
  * uncomment include files
  * New Meshmodel components generated
  * latest discussion data files added
  * [Docs] Release Notes for Meshery
  * update Maintainer.MD
  * Removed Storybook from ui directory, and created new storybook
    project in root project
  * Update .github/config.yml
  * resolved requested changes
  * resolved changes
  * feat: updated docs instances
  * feat: updated description
  * feat: updated description instances
  * docker extension user profile section refactored
  * Update main logo with srcset
  * Update README with picture element and srcset
  * fixed table header and updated overview link
  * Update config.yml
  * updating header for mobile view
  * Server work is done
  * Corrected blunder
  * Made Server ready to return Error messages on k8s
    configurations failures
  * Update the broken link and Change Meshery logo
  * Replace Meshery logo
  * Add Meshery logos
  * update workflow
  * added redocly config file
  * redocly docs generation
  * [feat] : smooth notification modal appearance
  * fix errors
  * Fixed bug in config_test.go
  * Rename config to meshConfigCtx in config_test.go
  * Update mesheryctl/pkg/utils/helpers.go
  * Added ok pattern to check if operator is disabled
  * Update server/models/remote_provider.go
  * Update server/models/remote_provider.go
  * fix lint issue
  * fix error
  * fix skipped nil checks
  * Add ability to disable operator through meshconfig
* Thu May  4 2023 kastl@b1-systems.de
- Update to version 0.6.87:
  * Bump @emotion/react from 11.10.5 to 11.10.8 in /ui
  * Bump next from 13.1.5 to 13.3.4 in /provider-ui
  * Bump @mui/icons-material from 5.11.11 to 5.11.16 in /provider-ui
  * Bump eslint-plugin-cypress from 2.12.1 to 2.13.3 in /ui
  * New Meshmodel components generated
  * latest discussion data files added
  * faqs
  * diminish service mesh centric focus
  * Update index.md
  * Bump github.com/layer5io/meshery-operator from 0.6.6 to 0.6.8
  * Bump @storybook/react from 6.5.16 to 7.0.7 in /ui
  * Bump eslint from 8.32.0 to 8.39.0 in /provider-ui
  * Bump @emotion/react from 11.10.6 to 11.10.8 in /provider-ui
  * remove traits
  * New Meshmodel components generated
  * latest discussion data files added
  * rjsf more code cleanup
  * pluralize, checkboxes dark mode, cleanup
  * Increase testing coverage and fix defer error
  * New Meshmodel components generated
  * latest discussion data files added
  * Adapters Component added
  * New Meshmodel components generated
  * latest discussion data files added
  * fix typo in summary
  * [Docs] Release Notes for Meshery
  * add ingress to service relationship
  * Increase test coverage for mesheryctl
  * Update ui/remote-component.config.js
  * Update ui/components/NavigatorExtension.js
  * add-publish-feature-forextensions
* Tue May  2 2023 kastl@b1-systems.de
- Update to version 0.6.86:
  * Add instruction to reinstall Meshery in playground
  * New Meshmodel components generated
  * latest discussion data files added
  * New Meshmodel components generated
  * latest discussion data files added
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * [Docs] Test status of adapter
  * Flatten kubeconfig for E2E tests
  * Update test_adaptersv2.yaml
  * Update test_adaptersv2.yaml
  * Upgrade minikube version and fix meshconfig in E2E workflow
  * meshkit error ADD
  * extra  removed
  * docker client init update
  * New Meshmodel components generated
  * latest discussion data files added
  * rename playground workflows
  * workflow rename
  * Update docs/v0.5/index.html
  * enforce
  * lints
  * fix the fetching
  * Minor tweak in description of make-link command
  * udate
  * dark
  * update
  * New Meshmodel components generated
  * latest discussion data files added
  * update
  * [Docs] Release Notes for Meshery
  * remove the log
  * updated slack and discuss link
  * query the userDetails from remoteProvider /api/user
* Tue Apr 25 2023 kastl@b1-systems.de
- Update to version 0.6.85:
  * Update config.yml
  * [Docs] Update mesheryctl docs
  * updated opengraph image's address
  * updated opengraph image
  * New Meshmodel components generated
  * latest discussion data files added
  * Update multiple-of-the-same-adapter.md
  * [Docs] Generated documentation for GraphQL API
  * New Meshmodel components generated
  * latest discussion data files added
  * New Meshmodel components generated
  * latest discussion data files added
  * Update .github/workflows/reboot-playground-machines.yaml
  * Adapters Component added
  * Add workflow to reboot equinix metal servers every 20 hours
  * fix logic for kubernetes version
  * Adapters Component added
  * Adapters Component added
  * latest discussion data files added
  * [Docs] Release Notes for Meshery
  * Enable toggling of theme in Meshery-extensions
  * fix:remove unwanted codes
  * fix: adding support for operator health check
* Sat Apr 22 2023 Johannes Kastl <kastl@b1-systems.de>
- new package mesheryctl: CLI for meshery, the cloud native manager
